/*
 * Copyright (c) 2018, NVIDIA CORPORATION. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef COMMON_LOG_H
#define COMMON_LOG_H

enum nvlink_log_type {
	nvlink_log_err,	/* Error prints will be printed unconditionally */
	nvlink_log_dbg,	/* Debug prints */
};

#define nvlink_err(fmt, arg...)						\
		nvlink_log_msg(NVLINK_MODULE_NAME, __func__, __LINE__,	\
		nvlink_log_err, fmt, ##arg)
#define nvlink_dbg(fmt, arg...)						\
		nvlink_log_msg(NVLINK_MODULE_NAME, __func__, __LINE__,	\
		nvlink_log_dbg, fmt, ##arg)

/*
 * APIs or variables listed below should be implemented per-OS in a
 * separate library.
 */

void nvlink_log_msg(const char *module_name, const char *func_name, int line,
		int type, const char *fmt, ...);

#endif /* COMMON_LOG_H */
