/*
 * Copyright (c) 2018, NVIDIA CORPORATION. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef COMMON_NVLINK_CORE_H
#define COMMON_NVLINK_CORE_H

#include <nvlink/common/timer.h>
#include <nvlink/common/log.h>
#ifdef __KERNEL__
#include <linux/module.h>
#else
#endif

#define NVLINK_TRANSITION_HS_TIMEOUT_MS		2000
#define NVLINK_TRANSITION_SAFE_TIMEOUT_MS	5

struct nvlink_intranode_conn {
	struct nvlink_device *ndev0;
	struct nvlink_device *ndev1;
};

struct topology {
	int slave_dev_id;
	int master_dev_id;
	int slave_link_id;
	int master_link_id;
};

struct nvlink_core {
	struct nvlink_device *ndevs[NVLINK_MAX_DEVICES];
	struct nvlink_link *nlinks[NVLINK_MAX_LINKS];
	struct topology topology;
	struct nvlink_intranode_conn intranode_conn;
	struct nvlink_mutex mutex;
};

/*
 * APIs or variables listed below should be implemented per-OS in a
 * separate library.
 */

#endif /* COMMON_NVLINK_CORE_H */
