/*
 * Copyright (c) 2018, NVIDIA CORPORATION. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

/*
 * nvlink-hw.h:
 * This header contains register definitions and HW related macros for the
 * NVLINK driver stack.
 */

#ifndef NVLINK_REGS_H
#define NVLINK_REGS_H

/* NVLINK APERTURES - START */


/* TIOCTRL MACROS */
/* TODO: Confirm this delay is correct for Tegra */
#define NVLW_POST_RESET_DELAY_US				8

/* MINION Registers */
#define CMINION_FALCON_OS_MINOR_VER_MASK			0xffff
#define CMINION_FALCON_OS_MINOR_VER_SHIFT			0
#define CMINION_FALCON_OS_MAJOR_VER_MASK			0xffff0000
#define CMINION_FALCON_OS_MAJOR_VER_SHIFT			16

#define MINION_NVLINK_DL_CMD_COMMAND_INITRXTERM			5
#define MINION_NVLINK_DL_CMD_COMMAND_LANESHUTDOWN		12
#define MINION_NVLINK_DL_CMD_COMMAND_INITPLL_8			40
#define MINION_NVLINK_DL_CMD_COMMAND_INITPLL_9			41
#define MINION_NVLINK_DL_CMD_COMMAND_SETNEA			65


/* NVLINK APERTURES - END */

/* NON-NVLINK APERTURES - START */


/* CPU System Registers */
#define SCF_NVLINK_CFG_TOM_MB_F(x)			(((x) & 0xfffff) << 0)
#define SCF_NVLINK_CFG_EN				31


/*
 * TODO: Currently the MC driver is disabled for T194. Therefore we can't use
 * the MC driver's register read/write APIs (i.e. mc_writel()/mc_readl()). The
 * WAR for this is to introduce a temporary API to access MC registers. We're
 * using MCB_BASE for this WAR. Remove this WAR once the MC driver gets enabled
 * for T194.
 */
/* MC Registers */
#define MCB_BASE					0x2c10000


/* NON-NVLINK APERTURES - END */

#endif /* NVLINK_REGS_H */
