/*
 * Copyright (c) 2018-2019, NVIDIA CORPORATION.  All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
/*
 * Function naming determines intended use:
 *
 *     <x>_r(void) : Returns the offset for register <x>.
 *
 *     <x>_o(void) : Returns the offset for element <x>.
 *
 *     <x>_w(void) : Returns the word offset for word (4 byte) element <x>.
 *
 *     <x>_<y>_s(void) : Returns size of field <y> of register <x> in bits.
 *
 *     <x>_<y>_f(u32 v) : Returns a value based on 'v' which has been shifted
 *         and masked to place it at field <y> of register <x>.  This value
 *         can be |'d with others to produce a full register value for
 *         register <x>.
 *
 *     <x>_<y>_m(void) : Returns a mask for field <y> of register <x>.  This
 *         value can be ~'d and then &'d to clear the value of field <y> for
 *         register <x>.
 *
 *     <x>_<y>_<z>_f(void) : Returns the constant value <z> after being shifted
 *         to place it at field <y> of register <x>.  This value can be |'d
 *         with others to produce a full register value for <x>.
 *
 *     <x>_<y>_v(u32 r) : Returns the value of field <y> from a full register
 *         <x> value 'r' after being shifted to place its LSB at bit 0.
 *         This value is suitable for direct comparison with other unshifted
 *         values appropriate for use in field <y> of register <x>.
 *
 *     <x>_<y>_<z>_v(void) : Returns the constant value for <z> defined for
 *         field <y> of register <x>.  This value is suitable for direct
 *         comparison with unshifted values appropriate for use in field <y>
 *         of register <x>.
 */
#ifndef NVLINK_HW_MSSNVLINK_T19X_H
#define NVLINK_HW_MSSNVLINK_T19X_H

#include <nvlink/common/types.h>

static inline u32 mssnvlink_clk_slcg_r(void)
{
	return 0x00000004U;
}
static inline u32 mssnvlink_clk_slcg_mcf_master_clk_enbl_f(u32 v)
{
	return (v & 0x1U) << 1U;
}
static inline u32 mssnvlink_clk_slcg_mcf_master_clk_enbl_m(void)
{
	return U32(0x1U) << 1U;
}
static inline u32 mssnvlink_clk_slcg_mcf_master_clk_enbl_v(u32 r)
{
	return (r >> 1U) & 0x1U;
}
static inline u32 mssnvlink_clk_slcg_mcf_master_clk_enbl_on_v(void)
{
	return 0x00000001U;
}
static inline u32 mssnvlink_clk_slcg_mcf_master_clk_enbl_on_f(void)
{
	return 0x2U;
}
static inline u32 mssnvlink_clk_slcg_mcf_master_clk_enbl_off_v(void)
{
	return 0x00000000U;
}
static inline u32 mssnvlink_clk_slcg_mcf_master_clk_enbl_off_f(void)
{
	return 0x0U;
}
static inline u32 mssnvlink_clk_slcg_mcf_slave_clk_enbl_f(u32 v)
{
	return (v & 0x1U) << 2U;
}
static inline u32 mssnvlink_clk_slcg_mcf_slave_clk_enbl_m(void)
{
	return U32(0x1U) << 2U;
}
static inline u32 mssnvlink_clk_slcg_mcf_slave_clk_enbl_v(u32 r)
{
	return (r >> 2U) & 0x1U;
}
static inline u32 mssnvlink_clk_slcg_mcf_slave_clk_enbl_on_v(void)
{
	return 0x00000001U;
}
static inline u32 mssnvlink_clk_slcg_mcf_slave_clk_enbl_on_f(void)
{
	return 0x4U;
}
static inline u32 mssnvlink_clk_slcg_mcf_slave_clk_enbl_off_v(void)
{
	return 0x00000000U;
}
static inline u32 mssnvlink_clk_slcg_mcf_slave_clk_enbl_off_f(void)
{
	return 0x0U;
}
static inline u32 mssnvlink_clk_slcg_core_clk_update_enbl_f(u32 v)
{
	return (v & 0x1U) << 15U;
}
static inline u32 mssnvlink_clk_slcg_core_clk_update_enbl_m(void)
{
	return U32(0x1U) << 15U;
}
static inline u32 mssnvlink_clk_slcg_core_clk_update_enbl_v(u32 r)
{
	return (r >> 15U) & 0x1U;
}
static inline u32 mssnvlink_clk_slcg_core_clk_update_enbl_on_v(void)
{
	return 0x00000001U;
}
static inline u32 mssnvlink_clk_slcg_core_clk_update_enbl_on_f(void)
{
	return 0x8000U;
}
static inline u32 mssnvlink_clk_slcg_core_clk_update_enbl_off_v(void)
{
	return 0x00000000U;
}
static inline u32 mssnvlink_clk_slcg_core_clk_update_enbl_off_f(void)
{
	return 0x0U;
}
static inline u32 mssnvlink_master_credit_transinfo_r(void)
{
	return 0x00000010U;
}
static inline u32 mssnvlink_master_credit_ingr_data_r(void)
{
	return 0x00000014U;
}
static inline u32 mssnvlink_slave_credit_transinfo_r(void)
{
	return 0x00000020U;
}
static inline u32 mssnvlink_slave_credit_ingr_data_r(void)
{
	return 0x00000024U;
}
static inline u32 mssnvlink_mcf_memory_type_control_r(void)
{
	return 0x00000040U;
}
static inline u32 mssnvlink_mcf_memory_type_control_mem_type_override_m(void)
{
	return U32(0x3U) << 0U;
}
static inline u32 mssnvlink_mcf_memory_type_control_mem_type_override_force_coh_snp_f(void)
{
	return 0x3U;
}
static inline u32 mssnvlink_master_act_transinfo_r(void)
{
	return 0x00000200U;
}
static inline u32 mssnvlink_master_act_transinfo_cnt_current_f(u32 v)
{
	return (v & 0x1ffU) << 0U;
}
static inline u32 mssnvlink_master_act_transinfo_cnt_current_m(void)
{
	return U32(0x1ffU) << 0U;
}
static inline u32 mssnvlink_master_act_transinfo_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0x1ffU;
}
static inline u32 mssnvlink_master_act_transinfo_rmw_r(void)
{
	return 0x00000204U;
}
static inline u32 mssnvlink_master_act_transinfo_rmw_cnt_current_f(u32 v)
{
	return (v & 0x1ffU) << 0U;
}
static inline u32 mssnvlink_master_act_transinfo_rmw_cnt_current_m(void)
{
	return U32(0x1ffU) << 0U;
}
static inline u32 mssnvlink_master_act_transinfo_rmw_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0x1ffU;
}
static inline u32 mssnvlink_master_act_ingr_data_r(void)
{
	return 0x00000208U;
}
static inline u32 mssnvlink_master_act_ingr_data_cnt_current_f(u32 v)
{
	return (v & 0xffU) << 0U;
}
static inline u32 mssnvlink_master_act_ingr_data_cnt_current_m(void)
{
	return U32(0xffU) << 0U;
}
static inline u32 mssnvlink_master_act_ingr_data_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0xffU;
}
static inline u32 mssnvlink_master_act_egr_data_r(void)
{
	return 0x0000020cU;
}
static inline u32 mssnvlink_master_act_egr_data_cnt_current_f(u32 v)
{
	return (v & 0x1ffU) << 0U;
}
static inline u32 mssnvlink_master_act_egr_data_cnt_current_m(void)
{
	return U32(0x1ffU) << 0U;
}
static inline u32 mssnvlink_master_act_egr_data_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0x1ffU;
}
static inline u32 mssnvlink_master_reserved_egr_data_r(void)
{
	return 0x00000210U;
}
static inline u32 mssnvlink_master_reserved_egr_data_cnt_current_f(u32 v)
{
	return (v & 0x1ffU) << 0U;
}
static inline u32 mssnvlink_master_reserved_egr_data_cnt_current_m(void)
{
	return U32(0x1ffU) << 0U;
}
static inline u32 mssnvlink_master_reserved_egr_data_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0x1ffU;
}
static inline u32 mssnvlink_master_act_transdone_r(void)
{
	return 0x00000214U;
}
static inline u32 mssnvlink_master_act_transdone_cnt_current_f(u32 v)
{
	return (v & 0x3fU) << 0U;
}
static inline u32 mssnvlink_master_act_transdone_cnt_current_m(void)
{
	return U32(0x3fU) << 0U;
}
static inline u32 mssnvlink_master_act_transdone_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0x3fU;
}
static inline u32 mssnvlink_master_ingr_cmd_queue_r(void)
{
	return 0x00000218U;
}
static inline u32 mssnvlink_master_ingr_cmd_queue_cnt_current_f(u32 v)
{
	return (v & 0x1ffU) << 0U;
}
static inline u32 mssnvlink_master_ingr_cmd_queue_cnt_current_m(void)
{
	return U32(0x1ffU) << 0U;
}
static inline u32 mssnvlink_master_ingr_cmd_queue_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0x1ffU;
}
static inline u32 mssnvlink_master_egr_cmd_queue_r(void)
{
	return 0x0000021cU;
}
static inline u32 mssnvlink_master_egr_cmd_queue_cnt_current_f(u32 v)
{
	return (v & 0x1ffU) << 0U;
}
static inline u32 mssnvlink_master_egr_cmd_queue_cnt_current_m(void)
{
	return U32(0x1ffU) << 0U;
}
static inline u32 mssnvlink_master_egr_cmd_queue_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0x1ffU;
}
static inline u32 mssnvlink_slave_act_transinfo_r(void)
{
	return 0x00000240U;
}
static inline u32 mssnvlink_slave_act_transinfo_cnt_current_f(u32 v)
{
	return (v & 0x1ffU) << 0U;
}
static inline u32 mssnvlink_slave_act_transinfo_cnt_current_m(void)
{
	return U32(0x1ffU) << 0U;
}
static inline u32 mssnvlink_slave_act_transinfo_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0x1ffU;
}
static inline u32 mssnvlink_slave_act_ingr_data_r(void)
{
	return 0x00000244U;
}
static inline u32 mssnvlink_slave_act_ingr_data_cnt_current_f(u32 v)
{
	return (v & 0x3ffU) << 0U;
}
static inline u32 mssnvlink_slave_act_ingr_data_cnt_current_m(void)
{
	return U32(0x3ffU) << 0U;
}
static inline u32 mssnvlink_slave_act_ingr_data_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0x3ffU;
}
static inline u32 mssnvlink_slave_act_egr_data_r(void)
{
	return 0x0000024cU;
}
static inline u32 mssnvlink_slave_act_egr_data_cnt_current_f(u32 v)
{
	return (v & 0x7fU) << 0U;
}
static inline u32 mssnvlink_slave_act_egr_data_cnt_current_m(void)
{
	return U32(0x7fU) << 0U;
}
static inline u32 mssnvlink_slave_act_egr_data_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0x7fU;
}
static inline u32 mssnvlink_slave_act_tag_table_r(void)
{
	return 0x00000250U;
}
static inline u32 mssnvlink_slave_act_tag_table_cnt_current_f(u32 v)
{
	return (v & 0x3ffU) << 0U;
}
static inline u32 mssnvlink_slave_act_tag_table_cnt_current_m(void)
{
	return U32(0x3ffU) << 0U;
}
static inline u32 mssnvlink_slave_act_tag_table_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0x3ffU;
}
static inline u32 mssnvlink_slave_transdone_mcf_req_r(void)
{
	return 0x00000254U;
}
static inline u32 mssnvlink_slave_transdone_mcf_req_cnt_current_f(u32 v)
{
	return (v & 0x1ffU) << 0U;
}
static inline u32 mssnvlink_slave_transdone_mcf_req_cnt_current_m(void)
{
	return U32(0x1ffU) << 0U;
}
static inline u32 mssnvlink_slave_transdone_mcf_req_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0x1ffU;
}
static inline u32 mssnvlink_slave_transdone_mcf_dat_r(void)
{
	return 0x00000258U;
}
static inline u32 mssnvlink_slave_transdone_mcf_dat_cnt_current_f(u32 v)
{
	return (v & 0x3ffU) << 0U;
}
static inline u32 mssnvlink_slave_transdone_mcf_dat_cnt_current_m(void)
{
	return U32(0x3ffU) << 0U;
}
static inline u32 mssnvlink_slave_transdone_mcf_dat_cnt_current_v(u32 r)
{
	return (r >> 0U) & 0x3ffU;
}
static inline u32 mssnvlink_pm_mode_r(void)
{
	return 0x00000e04U;
}
static inline u32 mssnvlink_pm_mode_lock_ila_f(u32 v)
{
	return (v & 0x1U) << 22U;
}
static inline u32 mssnvlink_pm_mode_lock_ila_m(void)
{
	return U32(0x1U) << 22U;
}
static inline u32 mssnvlink_pm_mode_lock_ila_v(u32 r)
{
	return (r >> 22U) & 0x1U;
}
static inline u32 mssnvlink_pm_mode_lock_ila_locked_v(void)
{
	return 0x00000001U;
}
static inline u32 mssnvlink_pm_mode_lock_ila_locked_f(void)
{
	return 0x400000U;
}
static inline u32 mssnvlink_clk_control_r(void)
{
	return 0x00000008U;
}
static inline u32 mssnvlink_clk_control_pm_clk_enbl_f(u32 v)
{
	return (v & 0x1U) << 17U;
}
static inline u32 mssnvlink_clk_control_pm_clk_enbl_m(void)
{
	return U32(0x1U) << 17U;
}
static inline u32 mssnvlink_clk_control_pm_clk_enbl_v(u32 r)
{
	return (r >> 17U) & 0x1U;
}
static inline u32 mssnvlink_clk_control_pm_clk_enbl_on_v(void)
{
	return 0x00000001U;
}
static inline u32 mssnvlink_clk_control_pm_clk_enbl_on_f(void)
{
	return 0x20000U;
}
static inline u32 mssnvlink_clk_control_pm_clk_enbl_off_v(void)
{
	return 0x00000000U;
}
static inline u32 mssnvlink_clk_control_pm_clk_enbl_off_f(void)
{
	return 0x0U;
}
#endif
