/*
 * Copyright (c) 2018-2020, NVIDIA CORPORATION.  All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
/*
 * Function/Macro naming determines intended use:
 *
 *     <x>_r(void) : Returns the offset for register <x>.
 *
 *     <x>_o(void) : Returns the offset for element <x>.
 *
 *     <x>_w(void) : Returns the word offset for word (4 byte) element <x>.
 *
 *     <x>_<y>_s(void) : Returns size of field <y> of register <x> in bits.
 *
 *     <x>_<y>_f(u32 v) : Returns a value based on 'v' which has been shifted
 *         and masked to place it at field <y> of register <x>.  This value
 *         can be |'d with others to produce a full register value for
 *         register <x>.
 *
 *     <x>_<y>_m(void) : Returns a mask for field <y> of register <x>.  This
 *         value can be ~'d and then &'d to clear the value of field <y> for
 *         register <x>.
 *
 *     <x>_<y>_<z>_f(void) : Returns the constant value <z> after being shifted
 *         to place it at field <y> of register <x>.  This value can be |'d
 *         with others to produce a full register value for <x>.
 *
 *     <x>_<y>_v(u32 r) : Returns the value of field <y> from a full register
 *         <x> value 'r' after being shifted to place its LSB at bit 0.
 *         This value is suitable for direct comparison with other unshifted
 *         values appropriate for use in field <y> of register <x>.
 *
 *     <x>_<y>_<z>_v(void) : Returns the constant value for <z> defined for
 *         field <y> of register <x>.  This value is suitable for direct
 *         comparison with unshifted values appropriate for use in field <y>
 *         of register <x>.
 */
#ifndef NVLINK_HW_NVL_T19X_H
#define NVLINK_HW_NVL_T19X_H

#include <nvlink/common/types.h>

static inline u32 nvl_link_state_r(void)
{
	return 0x00000000U;
}
static inline u32 nvl_link_state_state_f(u32 v)
{
	return (v & 0xffU) << 0U;
}
static inline u32 nvl_link_state_state_m(void)
{
	return U32(0xffU) << 0U;
}
static inline u32 nvl_link_state_state_v(u32 r)
{
	return (r >> 0U) & 0xffU;
}
static inline u32 nvl_link_state_state_shift_v(void)
{
	return 0x00000000U;
}
static inline u32 nvl_link_state_state_shift_f(void)
{
	return 0x0U;
}
static inline u32 nvl_link_state_state_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvl_link_state_state_init_f(void)
{
	return 0x0U;
}
static inline u32 nvl_link_state_state_hwcfg_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_link_state_state_hwcfg_f(void)
{
	return 0x1U;
}
static inline u32 nvl_link_state_state_swcfg_v(void)
{
	return 0x00000002U;
}
static inline u32 nvl_link_state_state_swcfg_f(void)
{
	return 0x2U;
}
static inline u32 nvl_link_state_state_active_v(void)
{
	return 0x00000003U;
}
static inline u32 nvl_link_state_state_active_f(void)
{
	return 0x3U;
}
static inline u32 nvl_link_state_state_fault_v(void)
{
	return 0x00000004U;
}
static inline u32 nvl_link_state_state_fault_f(void)
{
	return 0x4U;
}
static inline u32 nvl_link_state_state_rcvy_ac_v(void)
{
	return 0x00000008U;
}
static inline u32 nvl_link_state_state_rcvy_ac_f(void)
{
	return 0x8U;
}
static inline u32 nvl_link_state_state_rcvy_sw_v(void)
{
	return 0x00000009U;
}
static inline u32 nvl_link_state_state_rcvy_sw_f(void)
{
	return 0x9U;
}
static inline u32 nvl_link_state_state_rcvy_rx_v(void)
{
	return 0x0000000aU;
}
static inline u32 nvl_link_state_state_rcvy_rx_f(void)
{
	return 0xaU;
}
static inline u32 nvl_link_config_r(void)
{
	return 0x00000018U;
}
static inline u32 nvl_link_config_link_en_f(u32 v)
{
	return (v & 0x1U) << 31U;
}
static inline u32 nvl_link_config_link_en_m(void)
{
	return U32(0x1U) << 31U;
}
static inline u32 nvl_link_config_link_en_v(u32 r)
{
	return (r >> 31U) & 0x1U;
}
static inline u32 nvl_link_config_link_en_on_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_link_config_link_en_on_f(void)
{
	return 0x80000000U;
}
static inline u32 nvl_link_change_r(void)
{
	return 0x00000040U;
}
static inline u32 nvl_link_change_action_f(u32 v)
{
	return (v & 0x3U) << 2U;
}
static inline u32 nvl_link_change_action_m(void)
{
	return U32(0x3U) << 2U;
}
static inline u32 nvl_link_change_action_v(u32 r)
{
	return (r >> 2U) & 0x3U;
}
static inline u32 nvl_link_change_action_ltssm_change_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_link_change_action_ltssm_change_f(void)
{
	return 0x4U;
}
static inline u32 nvl_link_change_newstate_f(u32 v)
{
	return (v & 0xfU) << 4U;
}
static inline u32 nvl_link_change_newstate_m(void)
{
	return U32(0xfU) << 4U;
}
static inline u32 nvl_link_change_newstate_v(u32 r)
{
	return (r >> 4U) & 0xfU;
}
static inline u32 nvl_link_change_newstate_hwcfg_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_link_change_newstate_hwcfg_f(void)
{
	return 0x10U;
}
static inline u32 nvl_link_change_newstate_swcfg_v(void)
{
	return 0x00000002U;
}
static inline u32 nvl_link_change_newstate_swcfg_f(void)
{
	return 0x20U;
}
static inline u32 nvl_link_change_newstate_active_v(void)
{
	return 0x00000003U;
}
static inline u32 nvl_link_change_newstate_active_f(void)
{
	return 0x30U;
}
static inline u32 nvl_link_change_newstate_rcvy_ac_v(void)
{
	return 0x00000008U;
}
static inline u32 nvl_link_change_newstate_rcvy_ac_f(void)
{
	return 0x80U;
}
static inline u32 nvl_link_change_oldstate_mask_f(u32 v)
{
	return (v & 0xfU) << 16U;
}
static inline u32 nvl_link_change_oldstate_mask_m(void)
{
	return U32(0xfU) << 16U;
}
static inline u32 nvl_link_change_oldstate_mask_v(u32 r)
{
	return (r >> 16U) & 0xfU;
}
static inline u32 nvl_link_change_oldstate_mask_dontcare_v(void)
{
	return 0x0000000fU;
}
static inline u32 nvl_link_change_oldstate_mask_dontcare_f(void)
{
	return 0xf0000U;
}
static inline u32 nvl_sublink_change_r(void)
{
	return 0x00000044U;
}
static inline u32 nvl_sublink_change_status_f(u32 v)
{
	return (v & 0x3U) << 0U;
}
static inline u32 nvl_sublink_change_status_m(void)
{
	return U32(0x3U) << 0U;
}
static inline u32 nvl_sublink_change_status_v(u32 r)
{
	return (r >> 0U) & 0x3U;
}
static inline u32 nvl_sublink_change_status_done_v(void)
{
	return 0x00000000U;
}
static inline u32 nvl_sublink_change_status_done_f(void)
{
	return 0x0U;
}
static inline u32 nvl_sublink_change_status_fault_v(void)
{
	return 0x00000002U;
}
static inline u32 nvl_sublink_change_status_fault_f(void)
{
	return 0x2U;
}
static inline u32 nvl_sublink_change_action_f(u32 v)
{
	return (v & 0x3U) << 2U;
}
static inline u32 nvl_sublink_change_action_m(void)
{
	return U32(0x3U) << 2U;
}
static inline u32 nvl_sublink_change_action_v(u32 r)
{
	return (r >> 2U) & 0x3U;
}
static inline u32 nvl_sublink_change_action_slsm_change_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_sublink_change_action_slsm_change_f(void)
{
	return 0x4U;
}
static inline u32 nvl_sublink_change_newstate_f(u32 v)
{
	return (v & 0xfU) << 4U;
}
static inline u32 nvl_sublink_change_newstate_m(void)
{
	return U32(0xfU) << 4U;
}
static inline u32 nvl_sublink_change_newstate_v(u32 r)
{
	return (r >> 4U) & 0xfU;
}
static inline u32 nvl_sublink_change_newstate_hs_v(void)
{
	return 0x00000000U;
}
static inline u32 nvl_sublink_change_newstate_hs_f(void)
{
	return 0x0U;
}
static inline u32 nvl_sublink_change_newstate_safe_v(void)
{
	return 0x00000006U;
}
static inline u32 nvl_sublink_change_newstate_safe_f(void)
{
	return 0x60U;
}
static inline u32 nvl_sublink_change_sublink_f(u32 v)
{
	return (v & 0xfU) << 12U;
}
static inline u32 nvl_sublink_change_sublink_m(void)
{
	return U32(0xfU) << 12U;
}
static inline u32 nvl_sublink_change_sublink_v(u32 r)
{
	return (r >> 12U) & 0xfU;
}
static inline u32 nvl_sublink_change_sublink_tx_v(void)
{
	return 0x00000000U;
}
static inline u32 nvl_sublink_change_sublink_tx_f(void)
{
	return 0x0U;
}
static inline u32 nvl_intr_r(void)
{
	return 0x00000050U;
}
static inline u32 nvl_intr_rx_short_error_rate_f(u32 v)
{
	return (v & 0x1U) << 21U;
}
static inline u32 nvl_intr_rx_short_error_rate_m(void)
{
	return U32(0x1U) << 21U;
}
static inline u32 nvl_intr_rx_short_error_rate_v(u32 r)
{
	return (r >> 21U) & 0x1U;
}
static inline u32 nvl_intr_sw2_r(void)
{
	return 0x00000054U;
}
static inline u32 nvl_intr_stall_en_r(void)
{
	return 0x00000058U;
}
static inline u32 nvl_intr_stall_en_tx_recovery_long_f(u32 v)
{
	return (v & 0x1U) << 2U;
}
static inline u32 nvl_intr_stall_en_tx_recovery_long_m(void)
{
	return U32(0x1U) << 2U;
}
static inline u32 nvl_intr_stall_en_tx_recovery_long_v(u32 r)
{
	return (r >> 2U) & 0x1U;
}
static inline u32 nvl_intr_stall_en_tx_recovery_long_enable_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_intr_stall_en_tx_recovery_long_enable_f(void)
{
	return 0x4U;
}
static inline u32 nvl_intr_stall_en_tx_fault_ram_f(u32 v)
{
	return (v & 0x1U) << 4U;
}
static inline u32 nvl_intr_stall_en_tx_fault_ram_m(void)
{
	return U32(0x1U) << 4U;
}
static inline u32 nvl_intr_stall_en_tx_fault_ram_v(u32 r)
{
	return (r >> 4U) & 0x1U;
}
static inline u32 nvl_intr_stall_en_tx_fault_ram_enable_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_intr_stall_en_tx_fault_ram_enable_f(void)
{
	return 0x10U;
}
static inline u32 nvl_intr_stall_en_tx_fault_interface_f(u32 v)
{
	return (v & 0x1U) << 5U;
}
static inline u32 nvl_intr_stall_en_tx_fault_interface_m(void)
{
	return U32(0x1U) << 5U;
}
static inline u32 nvl_intr_stall_en_tx_fault_interface_v(u32 r)
{
	return (r >> 5U) & 0x1U;
}
static inline u32 nvl_intr_stall_en_tx_fault_interface_enable_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_intr_stall_en_tx_fault_interface_enable_f(void)
{
	return 0x20U;
}
static inline u32 nvl_intr_stall_en_rx_fault_sublink_change_f(u32 v)
{
	return (v & 0x1U) << 16U;
}
static inline u32 nvl_intr_stall_en_rx_fault_sublink_change_m(void)
{
	return U32(0x1U) << 16U;
}
static inline u32 nvl_intr_stall_en_rx_fault_sublink_change_v(u32 r)
{
	return (r >> 16U) & 0x1U;
}
static inline u32 nvl_intr_stall_en_rx_fault_sublink_change_enable_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_intr_stall_en_rx_fault_sublink_change_enable_f(void)
{
	return 0x10000U;
}
static inline u32 nvl_intr_stall_en_rx_fault_dl_protocol_f(u32 v)
{
	return (v & 0x1U) << 20U;
}
static inline u32 nvl_intr_stall_en_rx_fault_dl_protocol_m(void)
{
	return U32(0x1U) << 20U;
}
static inline u32 nvl_intr_stall_en_rx_fault_dl_protocol_v(u32 r)
{
	return (r >> 20U) & 0x1U;
}
static inline u32 nvl_intr_stall_en_rx_fault_dl_protocol_enable_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_intr_stall_en_rx_fault_dl_protocol_enable_f(void)
{
	return 0x100000U;
}
static inline u32 nvl_intr_stall_en_ltssm_fault_f(u32 v)
{
	return (v & 0x1U) << 28U;
}
static inline u32 nvl_intr_stall_en_ltssm_fault_m(void)
{
	return U32(0x1U) << 28U;
}
static inline u32 nvl_intr_stall_en_ltssm_fault_v(u32 r)
{
	return (r >> 28U) & 0x1U;
}
static inline u32 nvl_intr_stall_en_ltssm_fault_enable_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_intr_stall_en_ltssm_fault_enable_f(void)
{
	return 0x10000000U;
}
static inline u32 nvl_intr_stall_en_ltssm_protocol_f(u32 v)
{
	return (v & 0x1U) << 29U;
}
static inline u32 nvl_intr_stall_en_ltssm_protocol_m(void)
{
	return U32(0x1U) << 29U;
}
static inline u32 nvl_intr_stall_en_ltssm_protocol_v(u32 r)
{
	return (r >> 29U) & 0x1U;
}
static inline u32 nvl_intr_stall_en_ltssm_protocol_enable_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_intr_stall_en_ltssm_protocol_enable_f(void)
{
	return 0x20000000U;
}
static inline u32 nvl_intr_stall_en_rx_short_error_rate_f(u32 v)
{
	return (v & 0x1U) << 21U;
}
static inline u32 nvl_intr_stall_en_rx_short_error_rate_m(void)
{
	return U32(0x1U) << 21U;
}
static inline u32 nvl_intr_stall_en_rx_short_error_rate_v(u32 r)
{
	return (r >> 21U) & 0x1U;
}
static inline u32 nvl_intr_nonstall_en_r(void)
{
	return 0x0000005cU;
}
static inline u32 nvl_intr_nonstall_en_rx_short_error_rate_f(u32 v)
{
	return (v & 0x1U) << 21U;
}
static inline u32 nvl_intr_nonstall_en_rx_short_error_rate_m(void)
{
	return U32(0x1U) << 21U;
}
static inline u32 nvl_intr_nonstall_en_rx_short_error_rate_v(u32 r)
{
	return (r >> 21U) & 0x1U;
}
static inline u32 nvl_intr_nonstall_en_rx_short_error_rate_enable_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_intr_nonstall_en_rx_short_error_rate_enable_f(void)
{
	return 0x200000U;
}
static inline u32 nvl_br0_cfg_ctl_cal_r(void)
{
	return 0x0000281cU;
}
static inline u32 nvl_br0_cfg_ctl_cal_rxcal_f(u32 v)
{
	return (v & 0x1U) << 0U;
}
static inline u32 nvl_br0_cfg_ctl_cal_rxcal_m(void)
{
	return U32(0x1U) << 0U;
}
static inline u32 nvl_br0_cfg_ctl_cal_rxcal_v(u32 r)
{
	return (r >> 0U) & 0x1U;
}
static inline u32 nvl_br0_cfg_ctl_cal_rxcal_on_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_br0_cfg_ctl_cal_rxcal_on_f(void)
{
	return 0x1U;
}
static inline u32 nvl_br0_cfg_ctl_cal_init_train_done_f(u32 v)
{
	return (v & 0x1U) << 1U;
}
static inline u32 nvl_br0_cfg_ctl_cal_init_train_done_m(void)
{
	return U32(0x1U) << 1U;
}
static inline u32 nvl_br0_cfg_ctl_cal_init_train_done_v(u32 r)
{
	return (r >> 1U) & 0x1U;
}
static inline u32 nvl_br0_cfg_ctl_cal_init_train_done_unblocked_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_br0_cfg_ctl_cal_init_train_done_unblocked_f(void)
{
	return 0x2U;
}
static inline u32 nvl_br0_cfg_status_cal_r(void)
{
	return 0x00002838U;
}
static inline u32 nvl_br0_cfg_status_cal_rxcal_done_f(u32 v)
{
	return (v & 0x1U) << 2U;
}
static inline u32 nvl_br0_cfg_status_cal_rxcal_done_m(void)
{
	return U32(0x1U) << 2U;
}
static inline u32 nvl_br0_cfg_status_cal_rxcal_done_v(u32 r)
{
	return (r >> 2U) & 0x1U;
}
static inline u32 nvl_sl1_config_rx_r(void)
{
	return 0x00003000U;
}
static inline u32 nvl_sl1_config_rx_hw_lane_reverse_f(u32 v)
{
	return (v & 0x1U) << 8U;
}
static inline u32 nvl_sl1_config_rx_hw_lane_reverse_m(void)
{
	return U32(0x1U) << 8U;
}
static inline u32 nvl_sl1_config_rx_hw_lane_reverse_v(u32 r)
{
	return (r >> 8U) & 0x1U;
}
static inline u32 nvl_sl1_config_rx_lane_reverse_f(u32 v)
{
	return (v & 0x1U) << 8U;
}
static inline u32 nvl_sl1_config_rx_lane_reverse_m(void)
{
	return U32(0x1U) << 8U;
}
static inline u32 nvl_sl1_config_rx_lane_reverse_v(u32 r)
{
	return (r >> 8U) & 0x1U;
}
static inline u32 nvl_sl1_config_rx_reversal_override_f(u32 v)
{
	return (v & 0x1U) << 29U;
}
static inline u32 nvl_sl1_config_rx_reversal_override_m(void)
{
	return U32(0x1U) << 29U;
}
static inline u32 nvl_sl1_config_rx_reversal_override_v(u32 r)
{
	return (r >> 29U) & 0x1U;
}
static inline u32 nvl_sl1_slsm_status_rx_r(void)
{
	return 0x00003014U;
}
static inline u32 nvl_sl1_slsm_status_rx_primary_state_f(u32 v)
{
	return (v & 0xfU) << 4U;
}
static inline u32 nvl_sl1_slsm_status_rx_primary_state_m(void)
{
	return U32(0xfU) << 4U;
}
static inline u32 nvl_sl1_slsm_status_rx_primary_state_v(u32 r)
{
	return (r >> 4U) & 0xfU;
}
static inline u32 nvl_sl1_slsm_status_rx_primary_state_shift_v(void)
{
	return 0x00000004U;
}
static inline u32 nvl_sl1_slsm_status_rx_primary_state_shift_f(void)
{
	return 0x40U;
}
static inline u32 nvl_sl1_slsm_status_rx_primary_state_hs_v(void)
{
	return 0x00000000U;
}
static inline u32 nvl_sl1_slsm_status_rx_primary_state_hs_f(void)
{
	return 0x0U;
}
static inline u32 nvl_sl1_slsm_status_rx_primary_state_eighth_v(void)
{
	return 0x00000004U;
}
static inline u32 nvl_sl1_slsm_status_rx_primary_state_eighth_f(void)
{
	return 0x40U;
}
static inline u32 nvl_sl1_slsm_status_rx_primary_state_safe_v(void)
{
	return 0x00000006U;
}
static inline u32 nvl_sl1_slsm_status_rx_primary_state_safe_f(void)
{
	return 0x60U;
}
static inline u32 nvl_sl1_slsm_status_rx_primary_state_off_v(void)
{
	return 0x00000007U;
}
static inline u32 nvl_sl1_slsm_status_rx_primary_state_off_f(void)
{
	return 0x70U;
}
static inline u32 nvl_sl0_slsm_status_tx_r(void)
{
	return 0x00002024U;
}
static inline u32 nvl_sl0_slsm_status_tx_primary_state_f(u32 v)
{
	return (v & 0xfU) << 4U;
}
static inline u32 nvl_sl0_slsm_status_tx_primary_state_m(void)
{
	return U32(0xfU) << 4U;
}
static inline u32 nvl_sl0_slsm_status_tx_primary_state_v(u32 r)
{
	return (r >> 4U) & 0xfU;
}
static inline u32 nvl_sl0_slsm_status_tx_primary_state_shift_v(void)
{
	return 0x00000004U;
}
static inline u32 nvl_sl0_slsm_status_tx_primary_state_shift_f(void)
{
	return 0x40U;
}
static inline u32 nvl_sl0_slsm_status_tx_primary_state_hs_v(void)
{
	return 0x00000000U;
}
static inline u32 nvl_sl0_slsm_status_tx_primary_state_hs_f(void)
{
	return 0x0U;
}
static inline u32 nvl_sl0_slsm_status_tx_primary_state_eighth_v(void)
{
	return 0x00000004U;
}
static inline u32 nvl_sl0_slsm_status_tx_primary_state_eighth_f(void)
{
	return 0x40U;
}
static inline u32 nvl_sl0_slsm_status_tx_primary_state_safe_v(void)
{
	return 0x00000006U;
}
static inline u32 nvl_sl0_slsm_status_tx_primary_state_safe_f(void)
{
	return 0x60U;
}
static inline u32 nvl_sl0_slsm_status_tx_primary_state_off_v(void)
{
	return 0x00000007U;
}
static inline u32 nvl_sl0_slsm_status_tx_primary_state_off_f(void)
{
	return 0x70U;
}
static inline u32 nvl_txiobist_config_r(void)
{
	return 0x00002e10U;
}
static inline u32 nvl_txiobist_config_dpg_prbsseedld_f(u32 v)
{
	return (v & 0x1U) << 2U;
}
static inline u32 nvl_txiobist_config_dpg_prbsseedld_m(void)
{
	return U32(0x1U) << 2U;
}
static inline u32 nvl_txiobist_config_dpg_prbsseedld_v(u32 r)
{
	return (r >> 2U) & 0x1U;
}
static inline u32 nvl_txiobist_config_dpg_prbsseedld_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvl_txiobist_config_dpg_prbsseedld_init_f(void)
{
	return 0x0U;
}
static inline u32 nvl_sl1_rxslsm_timeout_2_r(void)
{
	return 0x00003034U;
}
static inline u32 nvl_sl1_rxslsm_timeout_2_sym_lock_f(u32 v)
{
	return (v & 0xffffU) << 0U;
}
static inline u32 nvl_sl1_rxslsm_timeout_2_sym_lock_m(void)
{
	return U32(0xffffU) << 0U;
}
static inline u32 nvl_sl1_rxslsm_timeout_2_sym_lock_v(u32 r)
{
	return (r >> 0U) & 0xffffU;
}
static inline u32 nvl_sl1_error_count_ctrl_r(void)
{
	return 0x00003280U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_flit_crc_f(u32 v)
{
	return (v & 0x1U) << 0U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_flit_crc_m(void)
{
	return U32(0x1U) << 0U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_flit_crc_v(u32 r)
{
	return (r >> 0U) & 0x1U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_flit_crc_clear_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_flit_crc_clear_f(void)
{
	return 0x1U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_lane_crc_f(u32 v)
{
	return (v & 0x1U) << 1U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_lane_crc_m(void)
{
	return U32(0x1U) << 1U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_lane_crc_v(u32 r)
{
	return (r >> 1U) & 0x1U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_lane_crc_clear_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_lane_crc_clear_f(void)
{
	return 0x2U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_rates_f(u32 v)
{
	return (v & 0x1U) << 2U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_rates_m(void)
{
	return U32(0x1U) << 2U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_rates_v(u32 r)
{
	return (r >> 2U) & 0x1U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_rates_clear_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_sl1_error_count_ctrl_clear_rates_clear_f(void)
{
	return 0x4U;
}
static inline u32 nvl_sl1_error_count_ctrl_short_rate_f(u32 v)
{
	return (v & 0x1U) << 8U;
}
static inline u32 nvl_sl1_error_count_ctrl_short_rate_m(void)
{
	return U32(0x1U) << 8U;
}
static inline u32 nvl_sl1_error_count_ctrl_short_rate_v(u32 r)
{
	return (r >> 8U) & 0x1U;
}
static inline u32 nvl_sl1_error_count_ctrl_short_rate_enable_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_sl1_error_count_ctrl_short_rate_enable_f(void)
{
	return 0x100U;
}
static inline u32 nvl_sl1_error_count_ctrl_rate_count_mode_f(u32 v)
{
	return (v & 0x1U) << 10U;
}
static inline u32 nvl_sl1_error_count_ctrl_rate_count_mode_m(void)
{
	return U32(0x1U) << 10U;
}
static inline u32 nvl_sl1_error_count_ctrl_rate_count_mode_v(u32 r)
{
	return (r >> 10U) & 0x1U;
}
static inline u32 nvl_sl1_error_count_ctrl_rate_count_mode_flit_v(void)
{
	return 0x00000000U;
}
static inline u32 nvl_sl1_error_count_ctrl_rate_count_mode_flit_f(void)
{
	return 0x0U;
}
static inline u32 nvl_sl1_error_rate_ctrl_r(void)
{
	return 0x00003284U;
}
static inline u32 nvl_sl1_error_rate_ctrl_short_threshold_man_f(u32 v)
{
	return (v & 0x7U) << 0U;
}
static inline u32 nvl_sl1_error_rate_ctrl_short_threshold_man_m(void)
{
	return U32(0x7U) << 0U;
}
static inline u32 nvl_sl1_error_rate_ctrl_short_threshold_man_v(u32 r)
{
	return (r >> 0U) & 0x7U;
}
static inline u32 nvl_sl1_error_rate_ctrl_short_threshold_exp_f(u32 v)
{
	return (v & 0x1U) << 3U;
}
static inline u32 nvl_sl1_error_rate_ctrl_short_threshold_exp_m(void)
{
	return U32(0x1U) << 3U;
}
static inline u32 nvl_sl1_error_rate_ctrl_short_threshold_exp_v(u32 r)
{
	return (r >> 3U) & 0x1U;
}
static inline u32 nvl_sl1_error_rate_ctrl_short_timescale_man_f(u32 v)
{
	return (v & 0x7U) << 4U;
}
static inline u32 nvl_sl1_error_rate_ctrl_short_timescale_man_m(void)
{
	return U32(0x7U) << 4U;
}
static inline u32 nvl_sl1_error_rate_ctrl_short_timescale_man_v(u32 r)
{
	return (r >> 4U) & 0x7U;
}
static inline u32 nvl_sl1_error_rate_ctrl_short_timescale_exp_f(u32 v)
{
	return (v & 0xfU) << 8U;
}
static inline u32 nvl_sl1_error_rate_ctrl_short_timescale_exp_m(void)
{
	return U32(0xfU) << 8U;
}
static inline u32 nvl_sl1_error_rate_ctrl_short_timescale_exp_v(u32 r)
{
	return (r >> 8U) & 0xfU;
}
static inline u32 nvl_sl0_error_count_ctrl_r(void)
{
	return 0x00002280U;
}
static inline u32 nvl_sl0_error_count_ctrl_clear_replay_f(u32 v)
{
	return (v & 0x1U) << 8U;
}
static inline u32 nvl_sl0_error_count_ctrl_clear_replay_m(void)
{
	return U32(0x1U) << 8U;
}
static inline u32 nvl_sl0_error_count_ctrl_clear_replay_v(u32 r)
{
	return (r >> 8U) & 0x1U;
}
static inline u32 nvl_sl0_error_count_ctrl_clear_replay_clear_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_sl0_error_count_ctrl_clear_replay_clear_f(void)
{
	return 0x100U;
}
static inline u32 nvl_error_count_ctrl_r(void)
{
	return 0x00000080U;
}
static inline u32 nvl_error_count_ctrl_clear_recovery_f(u32 v)
{
	return (v & 0x1U) << 2U;
}
static inline u32 nvl_error_count_ctrl_clear_recovery_m(void)
{
	return U32(0x1U) << 2U;
}
static inline u32 nvl_error_count_ctrl_clear_recovery_v(u32 r)
{
	return (r >> 2U) & 0x1U;
}
static inline u32 nvl_error_count_ctrl_clear_recovery_clear_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_error_count_ctrl_clear_recovery_clear_f(void)
{
	return 0x4U;
}
static inline u32 nvl_sl1_error_count1_r(void)
{
	return 0x00003288U;
}
static inline u32 nvl_sl1_error_count1_flit_crc_errors_f(u32 v)
{
	return (v & 0xffffU) << 0U;
}
static inline u32 nvl_sl1_error_count1_flit_crc_errors_m(void)
{
	return U32(0xffffU) << 0U;
}
static inline u32 nvl_sl1_error_count1_flit_crc_errors_v(u32 r)
{
	return (r >> 0U) & 0xffffU;
}
static inline u32 nvl_sl1_error_count2_lanecrc_r(void)
{
	return 0x0000328cU;
}
static inline u32 nvl_sl1_error_count2_lanecrc_l0_f(u32 v)
{
	return (v & 0xffU) << 0U;
}
static inline u32 nvl_sl1_error_count2_lanecrc_l0_m(void)
{
	return U32(0xffU) << 0U;
}
static inline u32 nvl_sl1_error_count2_lanecrc_l0_v(u32 r)
{
	return (r >> 0U) & 0xffU;
}
static inline u32 nvl_sl1_error_count2_lanecrc_l1_f(u32 v)
{
	return (v & 0xffU) << 0U;
}
static inline u32 nvl_sl1_error_count2_lanecrc_l1_m(void)
{
	return U32(0xffU) << 0U;
}
static inline u32 nvl_sl1_error_count2_lanecrc_l1_v(u32 r)
{
	return (r >> 0U) & 0xffU;
}
static inline u32 nvl_sl1_error_count2_lanecrc_l2_f(u32 v)
{
	return (v & 0xffU) << 16U;
}
static inline u32 nvl_sl1_error_count2_lanecrc_l2_m(void)
{
	return U32(0xffU) << 16U;
}
static inline u32 nvl_sl1_error_count2_lanecrc_l2_v(u32 r)
{
	return (r >> 16U) & 0xffU;
}
static inline u32 nvl_sl1_error_count2_lanecrc_l3_f(u32 v)
{
	return (v & 0xffU) << 24U;
}
static inline u32 nvl_sl1_error_count2_lanecrc_l3_m(void)
{
	return U32(0xffU) << 24U;
}
static inline u32 nvl_sl1_error_count2_lanecrc_l3_v(u32 r)
{
	return (r >> 24U) & 0xffU;
}
static inline u32 nvl_sl1_error_count3_lanecrc_r(void)
{
	return 0x00003290U;
}
static inline u32 nvl_sl1_error_count3_lanecrc_l4_f(u32 v)
{
	return (v & 0xffU) << 0U;
}
static inline u32 nvl_sl1_error_count3_lanecrc_l4_m(void)
{
	return U32(0xffU) << 0U;
}
static inline u32 nvl_sl1_error_count3_lanecrc_l4_v(u32 r)
{
	return (r >> 0U) & 0xffU;
}
static inline u32 nvl_sl1_error_count3_lanecrc_l5_f(u32 v)
{
	return (v & 0xffU) << 8U;
}
static inline u32 nvl_sl1_error_count3_lanecrc_l5_m(void)
{
	return U32(0xffU) << 8U;
}
static inline u32 nvl_sl1_error_count3_lanecrc_l5_v(u32 r)
{
	return (r >> 8U) & 0xffU;
}
static inline u32 nvl_sl1_error_count3_lanecrc_l6_f(u32 v)
{
	return (v & 0xffU) << 16U;
}
static inline u32 nvl_sl1_error_count3_lanecrc_l6_m(void)
{
	return U32(0xffU) << 16U;
}
static inline u32 nvl_sl1_error_count3_lanecrc_l6_v(u32 r)
{
	return (r >> 16U) & 0xffU;
}
static inline u32 nvl_sl1_error_count3_lanecrc_l7_f(u32 v)
{
	return (v & 0xffU) << 24U;
}
static inline u32 nvl_sl1_error_count3_lanecrc_l7_m(void)
{
	return U32(0xffU) << 24U;
}
static inline u32 nvl_sl1_error_count3_lanecrc_l7_v(u32 r)
{
	return (r >> 24U) & 0xffU;
}
static inline u32 nvl_sl0_error_count4_r(void)
{
	return 0x00002288U;
}
static inline u32 nvl_sl0_error_count4_replay_events_f(u32 v)
{
	return (v & 0xffffU) << 16U;
}
static inline u32 nvl_sl0_error_count4_replay_events_m(void)
{
	return U32(0xffffU) << 16U;
}
static inline u32 nvl_sl0_error_count4_replay_events_v(u32 r)
{
	return (r >> 16U) & 0xffffU;
}
static inline u32 nvl_error_count1_r(void)
{
	return 0x0000008cU;
}
static inline u32 nvl_error_count1_recovery_events_f(u32 v)
{
	return (v & 0x3ffU) << 0U;
}
static inline u32 nvl_error_count1_recovery_events_m(void)
{
	return U32(0x3ffU) << 0U;
}
static inline u32 nvl_error_count1_recovery_events_v(u32 r)
{
	return (r >> 0U) & 0x3ffU;
}
static inline u32 nvl_stats_a_r(void)
{
	return 0x00000198U;
}
static inline u32 nvl_stats_a_count_tx_state_nvhs_f(u32 v)
{
	return (v & 0xffffU) << 0U;
}
static inline u32 nvl_stats_a_count_tx_state_nvhs_m(void)
{
	return U32(0xffffU) << 0U;
}
static inline u32 nvl_stats_a_count_tx_state_nvhs_v(u32 r)
{
	return (r >> 0U) & 0xffffU;
}
static inline u32 nvl_stats_a_count_tx_state_eighth_f(u32 v)
{
	return (v & 0xffffU) << 16U;
}
static inline u32 nvl_stats_a_count_tx_state_eighth_m(void)
{
	return U32(0xffffU) << 16U;
}
static inline u32 nvl_stats_a_count_tx_state_eighth_v(u32 r)
{
	return (r >> 16U) & 0xffffU;
}
static inline u32 nvl_stats_b_r(void)
{
	return 0x0000019cU;
}
static inline u32 nvl_stats_b_count_tx_state_other_f(u32 v)
{
	return (v & 0xffffU) << 0U;
}
static inline u32 nvl_stats_b_count_tx_state_other_m(void)
{
	return U32(0xffffU) << 0U;
}
static inline u32 nvl_stats_b_count_tx_state_other_v(u32 r)
{
	return (r >> 0U) & 0xffffU;
}
static inline u32 nvl_stats_d_r(void)
{
	return 0x000001a4U;
}
static inline u32 nvl_stats_d_num_tx_lp_enter_f(u32 v)
{
	return (v & 0xffffU) << 0U;
}
static inline u32 nvl_stats_d_num_tx_lp_enter_m(void)
{
	return U32(0xffffU) << 0U;
}
static inline u32 nvl_stats_d_num_tx_lp_enter_v(u32 r)
{
	return (r >> 0U) & 0xffffU;
}
static inline u32 nvl_stats_d_num_tx_lp_exit_f(u32 v)
{
	return (v & 0xffffU) << 16U;
}
static inline u32 nvl_stats_d_num_tx_lp_exit_m(void)
{
	return U32(0xffffU) << 16U;
}
static inline u32 nvl_stats_d_num_tx_lp_exit_v(u32 r)
{
	return (r >> 16U) & 0xffffU;
}
static inline u32 nvl_stats_ctrl_r(void)
{
	return 0x00000190U;
}
static inline u32 nvl_stats_ctrl_clear_all_f(u32 v)
{
	return (v & 0x1U) << 0U;
}
static inline u32 nvl_stats_ctrl_clear_all_m(void)
{
	return U32(0x1U) << 0U;
}
static inline u32 nvl_stats_ctrl_clear_all_v(u32 r)
{
	return (r >> 0U) & 0x1U;
}
static inline u32 nvl_stats_ctrl_clear_all_clear_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_stats_ctrl_clear_all_clear_f(void)
{
	return 0x1U;
}
static inline u32 nvl_sl0_r4tx_command_r(void)
{
	return 0x00002140U;
}
static inline u32 nvl_sl0_r4tx_command_request_f(u32 v)
{
	return (v & 0x7U) << 0U;
}
static inline u32 nvl_sl0_r4tx_command_request_m(void)
{
	return U32(0x7U) << 0U;
}
static inline u32 nvl_sl0_r4tx_command_request_v(u32 r)
{
	return (r >> 0U) & 0x7U;
}
static inline u32 nvl_sl0_r4tx_command_request_write_v(void)
{
	return 0x00000002U;
}
static inline u32 nvl_sl0_r4tx_command_request_write_f(void)
{
	return 0x2U;
}
static inline u32 nvl_sl0_r4tx_command_ready_f(u32 v)
{
	return (v & 0x1U) << 3U;
}
static inline u32 nvl_sl0_r4tx_command_ready_m(void)
{
	return U32(0x1U) << 3U;
}
static inline u32 nvl_sl0_r4tx_command_ready_v(u32 r)
{
	return (r >> 3U) & 0x1U;
}
static inline u32 nvl_sl0_r4tx_command_waddr_f(u32 v)
{
	return (v & 0x7fU) << 8U;
}
static inline u32 nvl_sl0_r4tx_command_waddr_m(void)
{
	return U32(0x7fU) << 8U;
}
static inline u32 nvl_sl0_r4tx_command_waddr_v(u32 r)
{
	return (r >> 8U) & 0x7fU;
}
static inline u32 nvl_sl0_r4tx_command_waddr_ii_v(void)
{
	return 0x00000000U;
}
static inline u32 nvl_sl0_r4tx_command_waddr_ii_f(void)
{
	return 0x0U;
}
static inline u32 nvl_sl0_r4tx_command_waddr_sc_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_sl0_r4tx_command_waddr_sc_f(void)
{
	return 0x100U;
}
static inline u32 nvl_sl0_r4tx_command_complete_f(u32 v)
{
	return (v & 0x1U) << 24U;
}
static inline u32 nvl_sl0_r4tx_command_complete_m(void)
{
	return U32(0x1U) << 24U;
}
static inline u32 nvl_sl0_r4tx_command_complete_v(u32 r)
{
	return (r >> 24U) & 0x1U;
}
static inline u32 nvl_sl0_r4tx_command_complete_ready_clear_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_sl0_r4tx_command_complete_ready_clear_f(void)
{
	return 0x1000000U;
}
static inline u32 nvl_sl0_r4tx_wdata0_r(void)
{
	return 0x00002150U;
}
static inline u32 nvl_sl0_r4tx_wdata1_r(void)
{
	return 0x00002154U;
}
static inline u32 nvl_sl1_r4local_command_r(void)
{
	return 0x00003140U;
}
static inline u32 nvl_sl1_r4local_command_request_f(u32 v)
{
	return (v & 0x7U) << 0U;
}
static inline u32 nvl_sl1_r4local_command_request_m(void)
{
	return U32(0x7U) << 0U;
}
static inline u32 nvl_sl1_r4local_command_request_v(u32 r)
{
	return (r >> 0U) & 0x7U;
}
static inline u32 nvl_sl1_r4local_command_request_read_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_sl1_r4local_command_request_read_f(void)
{
	return 0x1U;
}
static inline u32 nvl_sl1_r4local_command_ready_f(u32 v)
{
	return (v & 0x1U) << 3U;
}
static inline u32 nvl_sl1_r4local_command_ready_m(void)
{
	return U32(0x1U) << 3U;
}
static inline u32 nvl_sl1_r4local_command_ready_v(u32 r)
{
	return (r >> 3U) & 0x1U;
}
static inline u32 nvl_sl1_r4local_command_raddr_f(u32 v)
{
	return (v & 0x7fU) << 16U;
}
static inline u32 nvl_sl1_r4local_command_raddr_m(void)
{
	return U32(0x7fU) << 16U;
}
static inline u32 nvl_sl1_r4local_command_raddr_v(u32 r)
{
	return (r >> 16U) & 0x7fU;
}
static inline u32 nvl_sl1_r4local_command_raddr_ii_v(void)
{
	return 0x00000000U;
}
static inline u32 nvl_sl1_r4local_command_raddr_ii_f(void)
{
	return 0x0U;
}
static inline u32 nvl_sl1_r4local_command_raddr_sc_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_sl1_r4local_command_raddr_sc_f(void)
{
	return 0x10000U;
}
static inline u32 nvl_sl1_r4local_command_complete_f(u32 v)
{
	return (v & 0x1U) << 24U;
}
static inline u32 nvl_sl1_r4local_command_complete_m(void)
{
	return U32(0x1U) << 24U;
}
static inline u32 nvl_sl1_r4local_command_complete_v(u32 r)
{
	return (r >> 24U) & 0x1U;
}
static inline u32 nvl_sl1_r4local_command_complete_ready_clear_v(void)
{
	return 0x00000001U;
}
static inline u32 nvl_sl1_r4local_command_complete_ready_clear_f(void)
{
	return 0x1000000U;
}
static inline u32 nvl_sl1_r4local_rdata0_r(void)
{
	return 0x00003158U;
}
static inline u32 nvl_sl1_r4local_rdata1_r(void)
{
	return 0x0000315cU;
}
#endif
