/*
 * Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
/*
 * Function naming determines intended use:
 *
 *     <x>_r(void) : Returns the offset for register <x>.
 *
 *     <x>_o(void) : Returns the offset for element <x>.
 *
 *     <x>_w(void) : Returns the word offset for word (4 byte) element <x>.
 *
 *     <x>_<y>_s(void) : Returns size of field <y> of register <x> in bits.
 *
 *     <x>_<y>_f(u32 v) : Returns a value based on 'v' which has been shifted
 *         and masked to place it at field <y> of register <x>.  This value
 *         can be |'d with others to produce a full register value for
 *         register <x>.
 *
 *     <x>_<y>_m(void) : Returns a mask for field <y> of register <x>.  This
 *         value can be ~'d and then &'d to clear the value of field <y> for
 *         register <x>.
 *
 *     <x>_<y>_<z>_f(void) : Returns the constant value <z> after being shifted
 *         to place it at field <y> of register <x>.  This value can be |'d
 *         with others to produce a full register value for <x>.
 *
 *     <x>_<y>_v(u32 r) : Returns the value of field <y> from a full register
 *         <x> value 'r' after being shifted to place its LSB at bit 0.
 *         This value is suitable for direct comparison with other unshifted
 *         values appropriate for use in field <y> of register <x>.
 *
 *     <x>_<y>_<z>_v(void) : Returns the constant value for <z> defined for
 *         field <y> of register <x>.  This value is suitable for direct
 *         comparison with unshifted values appropriate for use in field <y>
 *         of register <x>.
 */
#ifndef NVLINK_HW_NVLTLC_T19X_H
#define NVLINK_HW_NVLTLC_T19X_H

#include <nvlink/common/types.h>

static inline u32 nvltlc_tx_ctrl_buffer_sz_vc0_r(void)
{
	return 0x00000200U;
}
static inline u32 nvltlc_tx_ctrl_buffer_sz_vc1_r(void)
{
	return 0x00000204U;
}
static inline u32 nvltlc_tx_ctrl_buffer_sz_vc2_r(void)
{
	return 0x00000208U;
}
static inline u32 nvltlc_tx_ctrl_buffer_sz_vc3_r(void)
{
	return 0x0000020cU;
}
static inline u32 nvltlc_tx_ctrl_buffer_sz_vc4_r(void)
{
	return 0x00000210U;
}
static inline u32 nvltlc_tx_ctrl_buffer_sz_vc5_r(void)
{
	return 0x00000214U;
}
static inline u32 nvltlc_tx_ctrl_buffer_sz_vc6_r(void)
{
	return 0x00000218U;
}
static inline u32 nvltlc_tx_ctrl_buffer_sz_vc7_r(void)
{
	return 0x0000021cU;
}
static inline u32 nvltlc_tx_ctrl_buffer_credits_vc0_r(void)
{
	return 0x00000300U;
}
static inline u32 nvltlc_tx_ctrl_buffer_credits_vc1_r(void)
{
	return 0x00000304U;
}
static inline u32 nvltlc_tx_ctrl_buffer_credits_vc2_r(void)
{
	return 0x00000308U;
}
static inline u32 nvltlc_tx_ctrl_buffer_credits_vc3_r(void)
{
	return 0x0000030cU;
}
static inline u32 nvltlc_tx_ctrl_buffer_credits_vc4_r(void)
{
	return 0x00000310U;
}
static inline u32 nvltlc_tx_ctrl_buffer_credits_vc5_r(void)
{
	return 0x00000314U;
}
static inline u32 nvltlc_tx_ctrl_buffer_credits_vc6_r(void)
{
	return 0x00000318U;
}
static inline u32 nvltlc_tx_ctrl_buffer_credits_vc7_r(void)
{
	return 0x0000031cU;
}
static inline u32 nvltlc_tx_ctrl_buffer_ready_r(void)
{
	return 0x00000400U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_r(void)
{
	return 0x00000430U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_softwaredesired_f(u32 v)
{
	return (v & 0x1U) << 2U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_softwaredesired_m(void)
{
	return U32(0x1U) << 2U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_softwaredesired_v(u32 r)
{
	return (r >> 2U) & 0x1U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_softwaredesired_lp_v(void)
{
	return 0x00000001U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_softwaredesired_lp_f(void)
{
	return 0x4U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_softwaredesired_fb_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_softwaredesired_fb_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_hardwaredisable_f(u32 v)
{
	return (v & 0x1U) << 3U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_hardwaredisable_m(void)
{
	return U32(0x1U) << 3U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_hardwaredisable_v(u32 r)
{
	return (r >> 3U) & 0x1U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_hardwaredisable_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_hardwaredisable_init_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_countstart_f(u32 v)
{
	return (v & 0x1U) << 5U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_countstart_m(void)
{
	return U32(0x1U) << 5U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_countstart_v(u32 r)
{
	return (r >> 5U) & 0x1U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_countstart_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_tx_pwrm_ic_sw_ctrl_countstart_init_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_tx_pwrm_ic_inc_r(void)
{
	return 0x00000438U;
}
static inline u32 nvltlc_tx_pwrm_ic_inc_fbinc_f(u32 v)
{
	return (v & 0xffffU) << 0U;
}
static inline u32 nvltlc_tx_pwrm_ic_inc_fbinc_m(void)
{
	return U32(0xffffU) << 0U;
}
static inline u32 nvltlc_tx_pwrm_ic_inc_fbinc_v(u32 r)
{
	return (r >> 0U) & 0xffffU;
}
static inline u32 nvltlc_tx_pwrm_ic_inc_lpinc_f(u32 v)
{
	return (v & 0xffffU) << 16U;
}
static inline u32 nvltlc_tx_pwrm_ic_inc_lpinc_m(void)
{
	return U32(0xffffU) << 16U;
}
static inline u32 nvltlc_tx_pwrm_ic_inc_lpinc_v(u32 r)
{
	return (r >> 16U) & 0xffffU;
}
static inline u32 nvltlc_tx_pwrm_ic_dec_r(void)
{
	return 0x0000043cU;
}
static inline u32 nvltlc_tx_pwrm_ic_dec_fbdec_f(u32 v)
{
	return (v & 0xffffU) << 0U;
}
static inline u32 nvltlc_tx_pwrm_ic_dec_fbdec_m(void)
{
	return U32(0xffffU) << 0U;
}
static inline u32 nvltlc_tx_pwrm_ic_dec_fbdec_v(u32 r)
{
	return (r >> 0U) & 0xffffU;
}
static inline u32 nvltlc_tx_pwrm_ic_dec_lpdec_f(u32 v)
{
	return (v & 0xffffU) << 16U;
}
static inline u32 nvltlc_tx_pwrm_ic_dec_lpdec_m(void)
{
	return U32(0xffffU) << 16U;
}
static inline u32 nvltlc_tx_pwrm_ic_dec_lpdec_v(u32 r)
{
	return (r >> 16U) & 0xffffU;
}
static inline u32 nvltlc_tx_pwrm_ic_lp_enter_threshold_r(void)
{
	return 0x00000440U;
}
static inline u32 nvltlc_tx_pwrm_ic_lp_exit_threshold_r(void)
{
	return 0x00000444U;
}
static inline u32 nvltlc_tx_pwrm_ic_limit_r(void)
{
	return 0x00000448U;
}
static inline u32 nvltlc_tx_err_status_0_r(void)
{
	return 0x00000700U;
}
static inline u32 nvltlc_tx_err_log_en_0_r(void)
{
	return 0x00000704U;
}
static inline u32 nvltlc_tx_err_log_en_0_txhdrcreditovferr_f(u32 v)
{
	return (v & 0xffU) << 0U;
}
static inline u32 nvltlc_tx_err_log_en_0_txhdrcreditovferr_m(void)
{
	return U32(0xffU) << 0U;
}
static inline u32 nvltlc_tx_err_log_en_0_txhdrcreditovferr_v(u32 r)
{
	return (r >> 0U) & 0xffU;
}
static inline u32 nvltlc_tx_err_log_en_0_txdatacreditovferr_f(u32 v)
{
	return (v & 0xffU) << 8U;
}
static inline u32 nvltlc_tx_err_log_en_0_txdatacreditovferr_m(void)
{
	return U32(0xffU) << 8U;
}
static inline u32 nvltlc_tx_err_log_en_0_txdatacreditovferr_v(u32 r)
{
	return (r >> 8U) & 0xffU;
}
static inline u32 nvltlc_tx_err_log_en_0_txdlcreditovferr_f(u32 v)
{
	return (v & 0x1U) << 16U;
}
static inline u32 nvltlc_tx_err_log_en_0_txdlcreditovferr_m(void)
{
	return U32(0x1U) << 16U;
}
static inline u32 nvltlc_tx_err_log_en_0_txdlcreditovferr_v(u32 r)
{
	return (r >> 16U) & 0x1U;
}
static inline u32 nvltlc_tx_err_log_en_0_txdlcreditparityerr_f(u32 v)
{
	return (v & 0x1U) << 17U;
}
static inline u32 nvltlc_tx_err_log_en_0_txdlcreditparityerr_m(void)
{
	return U32(0x1U) << 17U;
}
static inline u32 nvltlc_tx_err_log_en_0_txdlcreditparityerr_v(u32 r)
{
	return (r >> 17U) & 0x1U;
}
static inline u32 nvltlc_tx_err_log_en_0_txramhdrparityerr_f(u32 v)
{
	return (v & 0x1U) << 18U;
}
static inline u32 nvltlc_tx_err_log_en_0_txramhdrparityerr_m(void)
{
	return U32(0x1U) << 18U;
}
static inline u32 nvltlc_tx_err_log_en_0_txramhdrparityerr_v(u32 r)
{
	return (r >> 18U) & 0x1U;
}
static inline u32 nvltlc_tx_err_log_en_0_txramdataparityerr_f(u32 v)
{
	return (v & 0x1U) << 19U;
}
static inline u32 nvltlc_tx_err_log_en_0_txramdataparityerr_m(void)
{
	return U32(0x1U) << 19U;
}
static inline u32 nvltlc_tx_err_log_en_0_txramdataparityerr_v(u32 r)
{
	return (r >> 19U) & 0x1U;
}
static inline u32 nvltlc_tx_err_log_en_0_txunsupvcovferr_f(u32 v)
{
	return (v & 0x1U) << 20U;
}
static inline u32 nvltlc_tx_err_log_en_0_txunsupvcovferr_m(void)
{
	return U32(0x1U) << 20U;
}
static inline u32 nvltlc_tx_err_log_en_0_txunsupvcovferr_v(u32 r)
{
	return (r >> 20U) & 0x1U;
}
static inline u32 nvltlc_tx_err_log_en_0_txstompdet_f(u32 v)
{
	return (v & 0x1U) << 22U;
}
static inline u32 nvltlc_tx_err_log_en_0_txstompdet_m(void)
{
	return U32(0x1U) << 22U;
}
static inline u32 nvltlc_tx_err_log_en_0_txstompdet_v(u32 r)
{
	return (r >> 22U) & 0x1U;
}
static inline u32 nvltlc_tx_err_log_en_0_txpoisondet_f(u32 v)
{
	return (v & 0x1U) << 23U;
}
static inline u32 nvltlc_tx_err_log_en_0_txpoisondet_m(void)
{
	return U32(0x1U) << 23U;
}
static inline u32 nvltlc_tx_err_log_en_0_txpoisondet_v(u32 r)
{
	return (r >> 23U) & 0x1U;
}
static inline u32 nvltlc_tx_err_log_en_0_targeterr_f(u32 v)
{
	return (v & 0x1U) << 24U;
}
static inline u32 nvltlc_tx_err_log_en_0_targeterr_m(void)
{
	return U32(0x1U) << 24U;
}
static inline u32 nvltlc_tx_err_log_en_0_targeterr_v(u32 r)
{
	return (r >> 24U) & 0x1U;
}
static inline u32 nvltlc_tx_err_log_en_0_unsupportedrequesterr_f(u32 v)
{
	return (v & 0x1U) << 25U;
}
static inline u32 nvltlc_tx_err_log_en_0_unsupportedrequesterr_m(void)
{
	return U32(0x1U) << 25U;
}
static inline u32 nvltlc_tx_err_log_en_0_unsupportedrequesterr_v(u32 r)
{
	return (r >> 25U) & 0x1U;
}
static inline u32 nvltlc_tx_err_report_en_0_r(void)
{
	return 0x00000708U;
}
static inline u32 nvltlc_tx_err_report_en_0_txhdrcreditovferr_f(u32 v)
{
	return (v & 0xffU) << 0U;
}
static inline u32 nvltlc_tx_err_report_en_0_txhdrcreditovferr_m(void)
{
	return U32(0xffU) << 0U;
}
static inline u32 nvltlc_tx_err_report_en_0_txhdrcreditovferr_v(u32 r)
{
	return (r >> 0U) & 0xffU;
}
static inline u32 nvltlc_tx_err_report_en_0_txdatacreditovferr_f(u32 v)
{
	return (v & 0xffU) << 8U;
}
static inline u32 nvltlc_tx_err_report_en_0_txdatacreditovferr_m(void)
{
	return U32(0xffU) << 8U;
}
static inline u32 nvltlc_tx_err_report_en_0_txdatacreditovferr_v(u32 r)
{
	return (r >> 8U) & 0xffU;
}
static inline u32 nvltlc_tx_err_report_en_0_txdlcreditovferr_f(u32 v)
{
	return (v & 0x1U) << 16U;
}
static inline u32 nvltlc_tx_err_report_en_0_txdlcreditovferr_m(void)
{
	return U32(0x1U) << 16U;
}
static inline u32 nvltlc_tx_err_report_en_0_txdlcreditovferr_v(u32 r)
{
	return (r >> 16U) & 0x1U;
}
static inline u32 nvltlc_tx_err_report_en_0_txdlcreditparityerr_f(u32 v)
{
	return (v & 0x1U) << 17U;
}
static inline u32 nvltlc_tx_err_report_en_0_txdlcreditparityerr_m(void)
{
	return U32(0x1U) << 17U;
}
static inline u32 nvltlc_tx_err_report_en_0_txdlcreditparityerr_v(u32 r)
{
	return (r >> 17U) & 0x1U;
}
static inline u32 nvltlc_tx_err_report_en_0_txramhdrparityerr_f(u32 v)
{
	return (v & 0x1U) << 18U;
}
static inline u32 nvltlc_tx_err_report_en_0_txramhdrparityerr_m(void)
{
	return U32(0x1U) << 18U;
}
static inline u32 nvltlc_tx_err_report_en_0_txramhdrparityerr_v(u32 r)
{
	return (r >> 18U) & 0x1U;
}
static inline u32 nvltlc_tx_err_report_en_0_txramdataparityerr_f(u32 v)
{
	return (v & 0x1U) << 19U;
}
static inline u32 nvltlc_tx_err_report_en_0_txramdataparityerr_m(void)
{
	return U32(0x1U) << 19U;
}
static inline u32 nvltlc_tx_err_report_en_0_txramdataparityerr_v(u32 r)
{
	return (r >> 19U) & 0x1U;
}
static inline u32 nvltlc_tx_err_report_en_0_txunsupvcovferr_f(u32 v)
{
	return (v & 0x1U) << 20U;
}
static inline u32 nvltlc_tx_err_report_en_0_txunsupvcovferr_m(void)
{
	return U32(0x1U) << 20U;
}
static inline u32 nvltlc_tx_err_report_en_0_txunsupvcovferr_v(u32 r)
{
	return (r >> 20U) & 0x1U;
}
static inline u32 nvltlc_tx_err_report_en_0_txstompdet_f(u32 v)
{
	return (v & 0x1U) << 22U;
}
static inline u32 nvltlc_tx_err_report_en_0_txstompdet_m(void)
{
	return U32(0x1U) << 22U;
}
static inline u32 nvltlc_tx_err_report_en_0_txstompdet_v(u32 r)
{
	return (r >> 22U) & 0x1U;
}
static inline u32 nvltlc_tx_err_report_en_0_txpoisondet_f(u32 v)
{
	return (v & 0x1U) << 23U;
}
static inline u32 nvltlc_tx_err_report_en_0_txpoisondet_m(void)
{
	return U32(0x1U) << 23U;
}
static inline u32 nvltlc_tx_err_report_en_0_txpoisondet_v(u32 r)
{
	return (r >> 23U) & 0x1U;
}
static inline u32 nvltlc_tx_err_report_en_0_targeterr_f(u32 v)
{
	return (v & 0x1U) << 24U;
}
static inline u32 nvltlc_tx_err_report_en_0_targeterr_m(void)
{
	return U32(0x1U) << 24U;
}
static inline u32 nvltlc_tx_err_report_en_0_targeterr_v(u32 r)
{
	return (r >> 24U) & 0x1U;
}
static inline u32 nvltlc_tx_err_report_en_0_unsupportedrequesterr_f(u32 v)
{
	return (v & 0x1U) << 25U;
}
static inline u32 nvltlc_tx_err_report_en_0_unsupportedrequesterr_m(void)
{
	return U32(0x1U) << 25U;
}
static inline u32 nvltlc_tx_err_report_en_0_unsupportedrequesterr_v(u32 r)
{
	return (r >> 25U) & 0x1U;
}
static inline u32 nvltlc_tx_err_contain_en_0_r(void)
{
	return 0x0000070cU;
}
static inline u32 nvltlc_tx_err_contain_en_0_txhdrcreditovferr_f(u32 v)
{
	return (v & 0xffU) << 0U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txhdrcreditovferr_m(void)
{
	return U32(0xffU) << 0U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txhdrcreditovferr_v(u32 r)
{
	return (r >> 0U) & 0xffU;
}
static inline u32 nvltlc_tx_err_contain_en_0_txdatacreditovferr_f(u32 v)
{
	return (v & 0xffU) << 8U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txdatacreditovferr_m(void)
{
	return U32(0xffU) << 8U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txdatacreditovferr_v(u32 r)
{
	return (r >> 8U) & 0xffU;
}
static inline u32 nvltlc_tx_err_contain_en_0_txdlcreditovferr_f(u32 v)
{
	return (v & 0x1U) << 16U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txdlcreditovferr_m(void)
{
	return U32(0x1U) << 16U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txdlcreditovferr_v(u32 r)
{
	return (r >> 16U) & 0x1U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txdlcreditparityerr_f(u32 v)
{
	return (v & 0x1U) << 17U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txdlcreditparityerr_m(void)
{
	return U32(0x1U) << 17U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txdlcreditparityerr_v(u32 r)
{
	return (r >> 17U) & 0x1U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txramhdrparityerr_f(u32 v)
{
	return (v & 0x1U) << 18U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txramhdrparityerr_m(void)
{
	return U32(0x1U) << 18U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txramhdrparityerr_v(u32 r)
{
	return (r >> 18U) & 0x1U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txramdataparityerr_f(u32 v)
{
	return (v & 0x1U) << 19U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txramdataparityerr_m(void)
{
	return U32(0x1U) << 19U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txramdataparityerr_v(u32 r)
{
	return (r >> 19U) & 0x1U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txunsupvcovferr_f(u32 v)
{
	return (v & 0x1U) << 20U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txunsupvcovferr_m(void)
{
	return U32(0x1U) << 20U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txunsupvcovferr_v(u32 r)
{
	return (r >> 20U) & 0x1U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txstompdet_f(u32 v)
{
	return (v & 0x1U) << 22U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txstompdet_m(void)
{
	return U32(0x1U) << 22U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txstompdet_v(u32 r)
{
	return (r >> 22U) & 0x1U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txpoisondet_f(u32 v)
{
	return (v & 0x1U) << 23U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txpoisondet_m(void)
{
	return U32(0x1U) << 23U;
}
static inline u32 nvltlc_tx_err_contain_en_0_txpoisondet_v(u32 r)
{
	return (r >> 23U) & 0x1U;
}
static inline u32 nvltlc_tx_err_contain_en_0_targeterr_f(u32 v)
{
	return (v & 0x1U) << 24U;
}
static inline u32 nvltlc_tx_err_contain_en_0_targeterr_m(void)
{
	return U32(0x1U) << 24U;
}
static inline u32 nvltlc_tx_err_contain_en_0_targeterr_v(u32 r)
{
	return (r >> 24U) & 0x1U;
}
static inline u32 nvltlc_tx_err_contain_en_0_unsupportedrequesterr_f(u32 v)
{
	return (v & 0x1U) << 25U;
}
static inline u32 nvltlc_tx_err_contain_en_0_unsupportedrequesterr_m(void)
{
	return U32(0x1U) << 25U;
}
static inline u32 nvltlc_tx_err_contain_en_0_unsupportedrequesterr_v(u32 r)
{
	return (r >> 25U) & 0x1U;
}
static inline u32 nvltlc_rx_ctrl_buffer_sz_vc0_r(void)
{
	return 0x00000a00U;
}
static inline u32 nvltlc_rx_ctrl_buffer_sz_vc1_r(void)
{
	return 0x00000a04U;
}
static inline u32 nvltlc_rx_ctrl_buffer_sz_vc2_r(void)
{
	return 0x00000a08U;
}
static inline u32 nvltlc_rx_ctrl_buffer_sz_vc3_r(void)
{
	return 0x00000a0cU;
}
static inline u32 nvltlc_rx_ctrl_buffer_sz_vc4_r(void)
{
	return 0x00000a10U;
}
static inline u32 nvltlc_rx_ctrl_buffer_sz_vc5_r(void)
{
	return 0x00000a14U;
}
static inline u32 nvltlc_rx_ctrl_buffer_sz_vc6_r(void)
{
	return 0x00000a18U;
}
static inline u32 nvltlc_rx_ctrl_buffer_sz_vc7_r(void)
{
	return 0x00000a1cU;
}
static inline u32 nvltlc_rx_ctrl_buffer_credits_vc0_r(void)
{
	return 0x00000b00U;
}
static inline u32 nvltlc_rx_ctrl_buffer_credits_vc1_r(void)
{
	return 0x00000b04U;
}
static inline u32 nvltlc_rx_ctrl_buffer_credits_vc2_r(void)
{
	return 0x00000b08U;
}
static inline u32 nvltlc_rx_ctrl_buffer_credits_vc3_r(void)
{
	return 0x00000b0cU;
}
static inline u32 nvltlc_rx_ctrl_buffer_credits_vc4_r(void)
{
	return 0x00000b10U;
}
static inline u32 nvltlc_rx_ctrl_buffer_credits_vc5_r(void)
{
	return 0x00000b14U;
}
static inline u32 nvltlc_rx_ctrl_buffer_credits_vc6_r(void)
{
	return 0x00000b18U;
}
static inline u32 nvltlc_rx_ctrl_buffer_credits_vc7_r(void)
{
	return 0x00000b1cU;
}
static inline u32 nvltlc_rx_ctrl_buffer_ready_r(void)
{
	return 0x00000c00U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_r(void)
{
	return 0x00000c30U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_softwaredesired_f(u32 v)
{
	return (v & 0x1U) << 2U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_softwaredesired_m(void)
{
	return U32(0x1U) << 2U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_softwaredesired_v(u32 r)
{
	return (r >> 2U) & 0x1U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_softwaredesired_lp_v(void)
{
	return 0x00000001U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_softwaredesired_lp_f(void)
{
	return 0x4U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_softwaredesired_fb_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_softwaredesired_fb_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_hardwaredisable_f(u32 v)
{
	return (v & 0x1U) << 3U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_hardwaredisable_m(void)
{
	return U32(0x1U) << 3U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_hardwaredisable_v(u32 r)
{
	return (r >> 3U) & 0x1U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_hardwaredisable_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_hardwaredisable_init_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_countstart_f(u32 v)
{
	return (v & 0x1U) << 5U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_countstart_m(void)
{
	return U32(0x1U) << 5U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_countstart_v(u32 r)
{
	return (r >> 5U) & 0x1U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_countstart_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_rx_pwrm_ic_sw_ctrl_countstart_init_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_rx_err_status_0_r(void)
{
	return 0x00000f00U;
}
static inline u32 nvltlc_rx_err_log_en_0_r(void)
{
	return 0x00000f04U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxdlhdrparityerr_f(u32 v)
{
	return (v & 0x1U) << 0U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxdlhdrparityerr_m(void)
{
	return U32(0x1U) << 0U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxdlhdrparityerr_v(u32 r)
{
	return (r >> 0U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxdldataparityerr_f(u32 v)
{
	return (v & 0x1U) << 1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxdldataparityerr_m(void)
{
	return U32(0x1U) << 1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxdldataparityerr_v(u32 r)
{
	return (r >> 1U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxdlctrlparityerr_f(u32 v)
{
	return (v & 0x1U) << 2U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxdlctrlparityerr_m(void)
{
	return U32(0x1U) << 2U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxdlctrlparityerr_v(u32 r)
{
	return (r >> 2U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxramdataparityerr_f(u32 v)
{
	return (v & 0x1U) << 3U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxramdataparityerr_m(void)
{
	return U32(0x1U) << 3U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxramdataparityerr_v(u32 r)
{
	return (r >> 3U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxramhdrparityerr_f(u32 v)
{
	return (v & 0x1U) << 4U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxramhdrparityerr_m(void)
{
	return U32(0x1U) << 4U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxramhdrparityerr_v(u32 r)
{
	return (r >> 4U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxinvalidaeerr_f(u32 v)
{
	return (v & 0x1U) << 5U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxinvalidaeerr_m(void)
{
	return U32(0x1U) << 5U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxinvalidaeerr_v(u32 r)
{
	return (r >> 5U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxinvalidbeerr_f(u32 v)
{
	return (v & 0x1U) << 6U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxinvalidbeerr_m(void)
{
	return U32(0x1U) << 6U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxinvalidbeerr_v(u32 r)
{
	return (r >> 6U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxinvalidaddralignerr_f(u32 v)
{
	return (v & 0x1U) << 7U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxinvalidaddralignerr_m(void)
{
	return U32(0x1U) << 7U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxinvalidaddralignerr_v(u32 r)
{
	return (r >> 7U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxpktlenerr_f(u32 v)
{
	return (v & 0x1U) << 8U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxpktlenerr_m(void)
{
	return U32(0x1U) << 8U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxpktlenerr_v(u32 r)
{
	return (r >> 8U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvcmdencerr_f(u32 v)
{
	return (v & 0x1U) << 9U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvcmdencerr_m(void)
{
	return U32(0x1U) << 9U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvcmdencerr_v(u32 r)
{
	return (r >> 9U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvdatlenencerr_f(u32 v)
{
	return (v & 0x1U) << 10U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvdatlenencerr_m(void)
{
	return U32(0x1U) << 10U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvdatlenencerr_v(u32 r)
{
	return (r >> 10U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvaddrtypeerr_f(u32 v)
{
	return (v & 0x1U) << 11U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvaddrtypeerr_m(void)
{
	return U32(0x1U) << 11U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvaddrtypeerr_v(u32 r)
{
	return (r >> 11U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvrspstatuserr_f(u32 v)
{
	return (v & 0x1U) << 12U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvrspstatuserr_m(void)
{
	return U32(0x1U) << 12U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvrspstatuserr_v(u32 r)
{
	return (r >> 12U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvpktstatuserr_f(u32 v)
{
	return (v & 0x1U) << 13U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvpktstatuserr_m(void)
{
	return U32(0x1U) << 13U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvpktstatuserr_v(u32 r)
{
	return (r >> 13U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvcacheattrprobereqerr_f(u32 v)
{
	return (v & 0x1U) << 14U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvcacheattrprobereqerr_m(void)
{
	return U32(0x1U) << 14U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvcacheattrprobereqerr_v(u32 r)
{
	return (r >> 14U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvcacheattrprobersperr_f(u32 v)
{
	return (v & 0x1U) << 15U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvcacheattrprobersperr_m(void)
{
	return U32(0x1U) << 15U;
}
static inline u32 nvltlc_rx_err_log_en_0_rsvcacheattrprobersperr_v(u32 r)
{
	return (r >> 15U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_datlengtatomicreqmaxerr_f(u32 v)
{
	return (v & 0x1U) << 17U;
}
static inline u32 nvltlc_rx_err_log_en_0_datlengtatomicreqmaxerr_m(void)
{
	return U32(0x1U) << 17U;
}
static inline u32 nvltlc_rx_err_log_en_0_datlengtatomicreqmaxerr_v(u32 r)
{
	return (r >> 17U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_datlengtrmwreqmaxerr_f(u32 v)
{
	return (v & 0x1U) << 18U;
}
static inline u32 nvltlc_rx_err_log_en_0_datlengtrmwreqmaxerr_m(void)
{
	return U32(0x1U) << 18U;
}
static inline u32 nvltlc_rx_err_log_en_0_datlengtrmwreqmaxerr_v(u32 r)
{
	return (r >> 18U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_datlenltatrrspminerr_f(u32 v)
{
	return (v & 0x1U) << 19U;
}
static inline u32 nvltlc_rx_err_log_en_0_datlenltatrrspminerr_m(void)
{
	return U32(0x1U) << 19U;
}
static inline u32 nvltlc_rx_err_log_en_0_datlenltatrrspminerr_v(u32 r)
{
	return (r >> 19U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_invalidcacheattrpoerr_f(u32 v)
{
	return (v & 0x1U) << 20U;
}
static inline u32 nvltlc_rx_err_log_en_0_invalidcacheattrpoerr_m(void)
{
	return U32(0x1U) << 20U;
}
static inline u32 nvltlc_rx_err_log_en_0_invalidcacheattrpoerr_v(u32 r)
{
	return (r >> 20U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_invalidcrerr_f(u32 v)
{
	return (v & 0x1U) << 21U;
}
static inline u32 nvltlc_rx_err_log_en_0_invalidcrerr_m(void)
{
	return U32(0x1U) << 21U;
}
static inline u32 nvltlc_rx_err_log_en_0_invalidcrerr_v(u32 r)
{
	return (r >> 21U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxrespstatustargeterr_f(u32 v)
{
	return (v & 0x1U) << 22U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxrespstatustargeterr_m(void)
{
	return U32(0x1U) << 22U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxrespstatustargeterr_v(u32 r)
{
	return (r >> 22U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxrespstatusunsupportedrequesterr_f(u32 v)
{
	return (v & 0x1U) << 23U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxrespstatusunsupportedrequesterr_m(void)
{
	return U32(0x1U) << 23U;
}
static inline u32 nvltlc_rx_err_log_en_0_rxrespstatusunsupportedrequesterr_v(u32 r)
{
	return (r >> 23U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_r(void)
{
	return 0x00000f08U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxdlhdrparityerr_f(u32 v)
{
	return (v & 0x1U) << 0U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxdlhdrparityerr_m(void)
{
	return U32(0x1U) << 0U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxdlhdrparityerr_v(u32 r)
{
	return (r >> 0U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxdldataparityerr_f(u32 v)
{
	return (v & 0x1U) << 1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxdldataparityerr_m(void)
{
	return U32(0x1U) << 1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxdldataparityerr_v(u32 r)
{
	return (r >> 1U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxdlctrlparityerr_f(u32 v)
{
	return (v & 0x1U) << 2U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxdlctrlparityerr_m(void)
{
	return U32(0x1U) << 2U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxdlctrlparityerr_v(u32 r)
{
	return (r >> 2U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxramdataparityerr_f(u32 v)
{
	return (v & 0x1U) << 3U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxramdataparityerr_m(void)
{
	return U32(0x1U) << 3U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxramdataparityerr_v(u32 r)
{
	return (r >> 3U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxramhdrparityerr_f(u32 v)
{
	return (v & 0x1U) << 4U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxramhdrparityerr_m(void)
{
	return U32(0x1U) << 4U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxramhdrparityerr_v(u32 r)
{
	return (r >> 4U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxinvalidaeerr_f(u32 v)
{
	return (v & 0x1U) << 5U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxinvalidaeerr_m(void)
{
	return U32(0x1U) << 5U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxinvalidaeerr_v(u32 r)
{
	return (r >> 5U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxinvalidbeerr_f(u32 v)
{
	return (v & 0x1U) << 6U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxinvalidbeerr_m(void)
{
	return U32(0x1U) << 6U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxinvalidbeerr_v(u32 r)
{
	return (r >> 6U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxinvalidaddralignerr_f(u32 v)
{
	return (v & 0x1U) << 7U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxinvalidaddralignerr_m(void)
{
	return U32(0x1U) << 7U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxinvalidaddralignerr_v(u32 r)
{
	return (r >> 7U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxpktlenerr_f(u32 v)
{
	return (v & 0x1U) << 8U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxpktlenerr_m(void)
{
	return U32(0x1U) << 8U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxpktlenerr_v(u32 r)
{
	return (r >> 8U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvcmdencerr_f(u32 v)
{
	return (v & 0x1U) << 9U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvcmdencerr_m(void)
{
	return U32(0x1U) << 9U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvcmdencerr_v(u32 r)
{
	return (r >> 9U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvdatlenencerr_f(u32 v)
{
	return (v & 0x1U) << 10U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvdatlenencerr_m(void)
{
	return U32(0x1U) << 10U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvdatlenencerr_v(u32 r)
{
	return (r >> 10U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvaddrtypeerr_f(u32 v)
{
	return (v & 0x1U) << 11U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvaddrtypeerr_m(void)
{
	return U32(0x1U) << 11U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvaddrtypeerr_v(u32 r)
{
	return (r >> 11U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvrspstatuserr_f(u32 v)
{
	return (v & 0x1U) << 12U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvrspstatuserr_m(void)
{
	return U32(0x1U) << 12U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvrspstatuserr_v(u32 r)
{
	return (r >> 12U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvpktstatuserr_f(u32 v)
{
	return (v & 0x1U) << 13U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvpktstatuserr_m(void)
{
	return U32(0x1U) << 13U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvpktstatuserr_v(u32 r)
{
	return (r >> 13U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvcacheattrprobereqerr_f(u32 v)
{
	return (v & 0x1U) << 14U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvcacheattrprobereqerr_m(void)
{
	return U32(0x1U) << 14U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvcacheattrprobereqerr_v(u32 r)
{
	return (r >> 14U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvcacheattrprobersperr_f(u32 v)
{
	return (v & 0x1U) << 15U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvcacheattrprobersperr_m(void)
{
	return U32(0x1U) << 15U;
}
static inline u32 nvltlc_rx_err_report_en_0_rsvcacheattrprobersperr_v(u32 r)
{
	return (r >> 15U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_datlengtatomicreqmaxerr_f(u32 v)
{
	return (v & 0x1U) << 17U;
}
static inline u32 nvltlc_rx_err_report_en_0_datlengtatomicreqmaxerr_m(void)
{
	return U32(0x1U) << 17U;
}
static inline u32 nvltlc_rx_err_report_en_0_datlengtatomicreqmaxerr_v(u32 r)
{
	return (r >> 17U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_datlengtrmwreqmaxerr_f(u32 v)
{
	return (v & 0x1U) << 18U;
}
static inline u32 nvltlc_rx_err_report_en_0_datlengtrmwreqmaxerr_m(void)
{
	return U32(0x1U) << 18U;
}
static inline u32 nvltlc_rx_err_report_en_0_datlengtrmwreqmaxerr_v(u32 r)
{
	return (r >> 18U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_datlenltatrrspminerr_f(u32 v)
{
	return (v & 0x1U) << 19U;
}
static inline u32 nvltlc_rx_err_report_en_0_datlenltatrrspminerr_m(void)
{
	return U32(0x1U) << 19U;
}
static inline u32 nvltlc_rx_err_report_en_0_datlenltatrrspminerr_v(u32 r)
{
	return (r >> 19U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_invalidcacheattrpoerr_f(u32 v)
{
	return (v & 0x1U) << 20U;
}
static inline u32 nvltlc_rx_err_report_en_0_invalidcacheattrpoerr_m(void)
{
	return U32(0x1U) << 20U;
}
static inline u32 nvltlc_rx_err_report_en_0_invalidcacheattrpoerr_v(u32 r)
{
	return (r >> 20U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_invalidcrerr_f(u32 v)
{
	return (v & 0x1U) << 21U;
}
static inline u32 nvltlc_rx_err_report_en_0_invalidcrerr_m(void)
{
	return U32(0x1U) << 21U;
}
static inline u32 nvltlc_rx_err_report_en_0_invalidcrerr_v(u32 r)
{
	return (r >> 21U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxrespstatustargeterr_f(u32 v)
{
	return (v & 0x1U) << 22U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxrespstatustargeterr_m(void)
{
	return U32(0x1U) << 22U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxrespstatustargeterr_v(u32 r)
{
	return (r >> 22U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxrespstatusunsupportedrequesterr_f(u32 v)
{
	return (v & 0x1U) << 23U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxrespstatusunsupportedrequesterr_m(void)
{
	return U32(0x1U) << 23U;
}
static inline u32 nvltlc_rx_err_report_en_0_rxrespstatusunsupportedrequesterr_v(u32 r)
{
	return (r >> 23U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_r(void)
{
	return 0x00000f0cU;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxdlhdrparityerr_f(u32 v)
{
	return (v & 0x1U) << 0U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxdlhdrparityerr_m(void)
{
	return U32(0x1U) << 0U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxdlhdrparityerr_v(u32 r)
{
	return (r >> 0U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxdldataparityerr_f(u32 v)
{
	return (v & 0x1U) << 1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxdldataparityerr_m(void)
{
	return U32(0x1U) << 1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxdldataparityerr_v(u32 r)
{
	return (r >> 1U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxdlctrlparityerr_f(u32 v)
{
	return (v & 0x1U) << 2U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxdlctrlparityerr_m(void)
{
	return U32(0x1U) << 2U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxdlctrlparityerr_v(u32 r)
{
	return (r >> 2U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxramdataparityerr_f(u32 v)
{
	return (v & 0x1U) << 3U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxramdataparityerr_m(void)
{
	return U32(0x1U) << 3U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxramdataparityerr_v(u32 r)
{
	return (r >> 3U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxramhdrparityerr_f(u32 v)
{
	return (v & 0x1U) << 4U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxramhdrparityerr_m(void)
{
	return U32(0x1U) << 4U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxramhdrparityerr_v(u32 r)
{
	return (r >> 4U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxinvalidaeerr_f(u32 v)
{
	return (v & 0x1U) << 5U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxinvalidaeerr_m(void)
{
	return U32(0x1U) << 5U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxinvalidaeerr_v(u32 r)
{
	return (r >> 5U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxinvalidbeerr_f(u32 v)
{
	return (v & 0x1U) << 6U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxinvalidbeerr_m(void)
{
	return U32(0x1U) << 6U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxinvalidbeerr_v(u32 r)
{
	return (r >> 6U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxinvalidaddralignerr_f(u32 v)
{
	return (v & 0x1U) << 7U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxinvalidaddralignerr_m(void)
{
	return U32(0x1U) << 7U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxinvalidaddralignerr_v(u32 r)
{
	return (r >> 7U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxpktlenerr_f(u32 v)
{
	return (v & 0x1U) << 8U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxpktlenerr_m(void)
{
	return U32(0x1U) << 8U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxpktlenerr_v(u32 r)
{
	return (r >> 8U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvcmdencerr_f(u32 v)
{
	return (v & 0x1U) << 9U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvcmdencerr_m(void)
{
	return U32(0x1U) << 9U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvcmdencerr_v(u32 r)
{
	return (r >> 9U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvdatlenencerr_f(u32 v)
{
	return (v & 0x1U) << 10U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvdatlenencerr_m(void)
{
	return U32(0x1U) << 10U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvdatlenencerr_v(u32 r)
{
	return (r >> 10U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvaddrtypeerr_f(u32 v)
{
	return (v & 0x1U) << 11U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvaddrtypeerr_m(void)
{
	return U32(0x1U) << 11U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvaddrtypeerr_v(u32 r)
{
	return (r >> 11U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvrspstatuserr_f(u32 v)
{
	return (v & 0x1U) << 12U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvrspstatuserr_m(void)
{
	return U32(0x1U) << 12U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvrspstatuserr_v(u32 r)
{
	return (r >> 12U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvpktstatuserr_f(u32 v)
{
	return (v & 0x1U) << 13U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvpktstatuserr_m(void)
{
	return U32(0x1U) << 13U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvpktstatuserr_v(u32 r)
{
	return (r >> 13U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvcacheattrprobereqerr_f(u32 v)
{
	return (v & 0x1U) << 14U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvcacheattrprobereqerr_m(void)
{
	return U32(0x1U) << 14U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvcacheattrprobereqerr_v(u32 r)
{
	return (r >> 14U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvcacheattrprobersperr_f(u32 v)
{
	return (v & 0x1U) << 15U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvcacheattrprobersperr_m(void)
{
	return U32(0x1U) << 15U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rsvcacheattrprobersperr_v(u32 r)
{
	return (r >> 15U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_datlengtatomicreqmaxerr_f(u32 v)
{
	return (v & 0x1U) << 17U;
}
static inline u32 nvltlc_rx_err_contain_en_0_datlengtatomicreqmaxerr_m(void)
{
	return U32(0x1U) << 17U;
}
static inline u32 nvltlc_rx_err_contain_en_0_datlengtatomicreqmaxerr_v(u32 r)
{
	return (r >> 17U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_datlengtrmwreqmaxerr_f(u32 v)
{
	return (v & 0x1U) << 18U;
}
static inline u32 nvltlc_rx_err_contain_en_0_datlengtrmwreqmaxerr_m(void)
{
	return U32(0x1U) << 18U;
}
static inline u32 nvltlc_rx_err_contain_en_0_datlengtrmwreqmaxerr_v(u32 r)
{
	return (r >> 18U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_datlenltatrrspminerr_f(u32 v)
{
	return (v & 0x1U) << 19U;
}
static inline u32 nvltlc_rx_err_contain_en_0_datlenltatrrspminerr_m(void)
{
	return U32(0x1U) << 19U;
}
static inline u32 nvltlc_rx_err_contain_en_0_datlenltatrrspminerr_v(u32 r)
{
	return (r >> 19U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_invalidcacheattrpoerr_f(u32 v)
{
	return (v & 0x1U) << 20U;
}
static inline u32 nvltlc_rx_err_contain_en_0_invalidcacheattrpoerr_m(void)
{
	return U32(0x1U) << 20U;
}
static inline u32 nvltlc_rx_err_contain_en_0_invalidcacheattrpoerr_v(u32 r)
{
	return (r >> 20U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_invalidcrerr_f(u32 v)
{
	return (v & 0x1U) << 21U;
}
static inline u32 nvltlc_rx_err_contain_en_0_invalidcrerr_m(void)
{
	return U32(0x1U) << 21U;
}
static inline u32 nvltlc_rx_err_contain_en_0_invalidcrerr_v(u32 r)
{
	return (r >> 21U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxrespstatustargeterr_f(u32 v)
{
	return (v & 0x1U) << 22U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxrespstatustargeterr_m(void)
{
	return U32(0x1U) << 22U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxrespstatustargeterr_v(u32 r)
{
	return (r >> 22U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxrespstatusunsupportedrequesterr_f(u32 v)
{
	return (v & 0x1U) << 23U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxrespstatusunsupportedrequesterr_m(void)
{
	return U32(0x1U) << 23U;
}
static inline u32 nvltlc_rx_err_contain_en_0_rxrespstatusunsupportedrequesterr_v(u32 r)
{
	return (r >> 23U) & 0x1U;
}
static inline u32 nvltlc_rx_err_inject_0_r(void)
{
	return 0x00000f10U;
}
static inline u32 nvltlc_rx_err_inject_0_rxramdataparityerr_f(u32 v)
{
	return (v & 0x1U) << 3U;
}
static inline u32 nvltlc_rx_err_inject_0_rxramdataparityerr_m(void)
{
	return U32(0x1U) << 3U;
}
static inline u32 nvltlc_rx_err_inject_0_rxramdataparityerr_v(u32 r)
{
	return (r >> 3U) & 0x1U;
}
static inline u32 nvltlc_rx_err_status_1_r(void)
{
	return 0x00000f18U;
}
static inline u32 nvltlc_rx_err_log_en_1_r(void)
{
	return 0x00000f1cU;
}
static inline u32 nvltlc_rx_err_log_en_1_rxhdrovferr_f(u32 v)
{
	return (v & 0xffU) << 0U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxhdrovferr_m(void)
{
	return U32(0xffU) << 0U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxhdrovferr_v(u32 r)
{
	return (r >> 0U) & 0xffU;
}
static inline u32 nvltlc_rx_err_log_en_1_rxdataovferr_f(u32 v)
{
	return (v & 0xffU) << 8U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxdataovferr_m(void)
{
	return U32(0xffU) << 8U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxdataovferr_v(u32 r)
{
	return (r >> 8U) & 0xffU;
}
static inline u32 nvltlc_rx_err_log_en_1_stompdeterr_f(u32 v)
{
	return (v & 0x1U) << 16U;
}
static inline u32 nvltlc_rx_err_log_en_1_stompdeterr_m(void)
{
	return U32(0x1U) << 16U;
}
static inline u32 nvltlc_rx_err_log_en_1_stompdeterr_v(u32 r)
{
	return (r >> 16U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxpoisonerr_f(u32 v)
{
	return (v & 0x1U) << 17U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxpoisonerr_m(void)
{
	return U32(0x1U) << 17U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxpoisonerr_v(u32 r)
{
	return (r >> 17U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxunsupvcovferr_f(u32 v)
{
	return (v & 0x1U) << 19U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxunsupvcovferr_m(void)
{
	return U32(0x1U) << 19U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxunsupvcovferr_v(u32 r)
{
	return (r >> 19U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxunsupnvlinkcreditrelerr_f(u32 v)
{
	return (v & 0x1U) << 20U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxunsupnvlinkcreditrelerr_m(void)
{
	return U32(0x1U) << 20U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxunsupnvlinkcreditrelerr_v(u32 r)
{
	return (r >> 20U) & 0x1U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxunsupncisoccreditrelerr_f(u32 v)
{
	return (v & 0x1U) << 21U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxunsupncisoccreditrelerr_m(void)
{
	return U32(0x1U) << 21U;
}
static inline u32 nvltlc_rx_err_log_en_1_rxunsupncisoccreditrelerr_v(u32 r)
{
	return (r >> 21U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_1_r(void)
{
	return 0x00000f20U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxhdrovferr_f(u32 v)
{
	return (v & 0xffU) << 0U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxhdrovferr_m(void)
{
	return U32(0xffU) << 0U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxhdrovferr_v(u32 r)
{
	return (r >> 0U) & 0xffU;
}
static inline u32 nvltlc_rx_err_report_en_1_rxdataovferr_f(u32 v)
{
	return (v & 0xffU) << 8U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxdataovferr_m(void)
{
	return U32(0xffU) << 8U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxdataovferr_v(u32 r)
{
	return (r >> 8U) & 0xffU;
}
static inline u32 nvltlc_rx_err_report_en_1_stompdeterr_f(u32 v)
{
	return (v & 0x1U) << 16U;
}
static inline u32 nvltlc_rx_err_report_en_1_stompdeterr_m(void)
{
	return U32(0x1U) << 16U;
}
static inline u32 nvltlc_rx_err_report_en_1_stompdeterr_v(u32 r)
{
	return (r >> 16U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxpoisonerr_f(u32 v)
{
	return (v & 0x1U) << 17U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxpoisonerr_m(void)
{
	return U32(0x1U) << 17U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxpoisonerr_v(u32 r)
{
	return (r >> 17U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxunsupvcovferr_f(u32 v)
{
	return (v & 0x1U) << 19U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxunsupvcovferr_m(void)
{
	return U32(0x1U) << 19U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxunsupvcovferr_v(u32 r)
{
	return (r >> 19U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxunsupnvlinkcreditrelerr_f(u32 v)
{
	return (v & 0x1U) << 20U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxunsupnvlinkcreditrelerr_m(void)
{
	return U32(0x1U) << 20U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxunsupnvlinkcreditrelerr_v(u32 r)
{
	return (r >> 20U) & 0x1U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxunsupncisoccreditrelerr_f(u32 v)
{
	return (v & 0x1U) << 21U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxunsupncisoccreditrelerr_m(void)
{
	return U32(0x1U) << 21U;
}
static inline u32 nvltlc_rx_err_report_en_1_rxunsupncisoccreditrelerr_v(u32 r)
{
	return (r >> 21U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_1_r(void)
{
	return 0x00000f24U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxhdrovferr_f(u32 v)
{
	return (v & 0xffU) << 0U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxhdrovferr_m(void)
{
	return U32(0xffU) << 0U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxhdrovferr_v(u32 r)
{
	return (r >> 0U) & 0xffU;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxdataovferr_f(u32 v)
{
	return (v & 0xffU) << 8U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxdataovferr_m(void)
{
	return U32(0xffU) << 8U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxdataovferr_v(u32 r)
{
	return (r >> 8U) & 0xffU;
}
static inline u32 nvltlc_rx_err_contain_en_1_stompdeterr_f(u32 v)
{
	return (v & 0x1U) << 16U;
}
static inline u32 nvltlc_rx_err_contain_en_1_stompdeterr_m(void)
{
	return U32(0x1U) << 16U;
}
static inline u32 nvltlc_rx_err_contain_en_1_stompdeterr_v(u32 r)
{
	return (r >> 16U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxpoisonerr_f(u32 v)
{
	return (v & 0x1U) << 17U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxpoisonerr_m(void)
{
	return U32(0x1U) << 17U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxpoisonerr_v(u32 r)
{
	return (r >> 17U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxunsupvcovferr_f(u32 v)
{
	return (v & 0x1U) << 19U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxunsupvcovferr_m(void)
{
	return U32(0x1U) << 19U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxunsupvcovferr_v(u32 r)
{
	return (r >> 19U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxunsupnvlinkcreditrelerr_f(u32 v)
{
	return (v & 0x1U) << 20U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxunsupnvlinkcreditrelerr_m(void)
{
	return U32(0x1U) << 20U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxunsupnvlinkcreditrelerr_v(u32 r)
{
	return (r >> 20U) & 0x1U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxunsupncisoccreditrelerr_f(u32 v)
{
	return (v & 0x1U) << 21U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxunsupncisoccreditrelerr_m(void)
{
	return U32(0x1U) << 21U;
}
static inline u32 nvltlc_rx_err_contain_en_1_rxunsupncisoccreditrelerr_v(u32 r)
{
	return (r >> 21U) & 0x1U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_r(void)
{
	return 0x00000490U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_entx0_f(u32 v)
{
	return (v & 0x1U) << 0U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_entx0_m(void)
{
	return U32(0x1U) << 0U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_entx0_v(u32 r)
{
	return (r >> 0U) & 0x1U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_entx0_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_entx0_init_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_entx1_f(u32 v)
{
	return (v & 0x1U) << 1U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_entx1_m(void)
{
	return U32(0x1U) << 1U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_entx1_v(u32 r)
{
	return (r >> 1U) & 0x1U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_entx1_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_entx1_init_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_resettx0_f(u32 v)
{
	return (v & 0x1U) << 16U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_resettx0_m(void)
{
	return U32(0x1U) << 16U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_resettx0_v(u32 r)
{
	return (r >> 16U) & 0x1U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_resettx1_f(u32 v)
{
	return (v & 0x1U) << 17U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_resettx1_m(void)
{
	return U32(0x1U) << 17U;
}
static inline u32 nvltlc_tx_debug_tp_cntr_ctrl_resettx1_v(u32 r)
{
	return (r >> 17U) & 0x1U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_r(void)
{
	return 0x00000c90U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_enrx0_f(u32 v)
{
	return (v & 0x1U) << 0U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_enrx0_m(void)
{
	return U32(0x1U) << 0U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_enrx0_v(u32 r)
{
	return (r >> 0U) & 0x1U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_enrx0_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_enrx0_init_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_enrx1_f(u32 v)
{
	return (v & 0x1U) << 1U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_enrx1_m(void)
{
	return U32(0x1U) << 1U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_enrx1_v(u32 r)
{
	return (r >> 1U) & 0x1U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_enrx1_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_enrx1_init_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_resetrx0_f(u32 v)
{
	return (v & 0x1U) << 16U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_resetrx0_m(void)
{
	return U32(0x1U) << 16U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_resetrx0_v(u32 r)
{
	return (r >> 16U) & 0x1U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_resetrx1_f(u32 v)
{
	return (v & 0x1U) << 17U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_resetrx1_m(void)
{
	return U32(0x1U) << 17U;
}
static inline u32 nvltlc_rx_debug_tp_cntr_ctrl_resetrx1_v(u32 r)
{
	return (r >> 17U) & 0x1U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_ctrl_0_r(void)
{
	return 0x00000494U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_ctrl_0_unit_f(u32 v)
{
	return (v & 0x3U) << 1U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_ctrl_0_unit_m(void)
{
	return U32(0x3U) << 1U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_ctrl_0_unit_v(u32 r)
{
	return (r >> 1U) & 0x3U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_ctrl_0_unit_packets_v(void)
{
	return 0x00000001U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_ctrl_0_unit_packets_f(void)
{
	return 0x2U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_ctrl_0_vcsetfiltermode_f(u32 v)
{
	return (v & 0x3U) << 8U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_ctrl_0_vcsetfiltermode_m(void)
{
	return U32(0x3U) << 8U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_ctrl_0_vcsetfiltermode_v(u32 r)
{
	return (r >> 8U) & 0x3U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_ctrl_0_vcsetfiltermode_init_v(void)
{
	return 0x00000003U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_ctrl_0_vcsetfiltermode_init_f(void)
{
	return 0x300U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_r(void)
{
	return 0x000004a4U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_unit_f(u32 v)
{
	return (v & 0x3U) << 1U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_unit_m(void)
{
	return U32(0x3U) << 1U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_unit_v(u32 r)
{
	return (r >> 1U) & 0x3U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_unit_cycles_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_unit_cycles_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_vcsetfiltermode_f(u32 v)
{
	return (v & 0x3U) << 8U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_vcsetfiltermode_m(void)
{
	return U32(0x3U) << 8U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_vcsetfiltermode_v(u32 r)
{
	return (r >> 8U) & 0x3U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_vcsetfiltermode_init_v(void)
{
	return 0x00000003U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_vcsetfiltermode_init_f(void)
{
	return 0x300U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_flitfilter_f(u32 v)
{
	return (v & 0x1fU) << 3U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_flitfilter_m(void)
{
	return U32(0x1fU) << 3U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_flitfilter_v(u32 r)
{
	return (r >> 3U) & 0x1fU;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_flitfilter_idle_v(void)
{
	return 0x00000010U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_ctrl_0_flitfilter_idle_f(void)
{
	return 0x80U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_r(void)
{
	return 0x00000c94U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_unit_f(u32 v)
{
	return (v & 0x3U) << 1U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_unit_m(void)
{
	return U32(0x3U) << 1U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_unit_v(u32 r)
{
	return (r >> 1U) & 0x3U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_unit_packets_v(void)
{
	return 0x00000001U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_unit_packets_f(void)
{
	return 0x2U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_vcsetfiltermode_f(u32 v)
{
	return (v & 0x3U) << 8U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_vcsetfiltermode_m(void)
{
	return U32(0x3U) << 8U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_vcsetfiltermode_v(u32 r)
{
	return (r >> 8U) & 0x3U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_vcsetfiltermode_init_v(void)
{
	return 0x00000003U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_vcsetfiltermode_init_f(void)
{
	return 0x300U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_flitfilter_f(u32 v)
{
	return (v & 0x1fU) << 3U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_flitfilter_m(void)
{
	return U32(0x1fU) << 3U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_flitfilter_v(u32 r)
{
	return (r >> 3U) & 0x1fU;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_flitfilter_idle_v(void)
{
	return 0x00000010U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_ctrl_0_flitfilter_idle_f(void)
{
	return 0x80U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_r(void)
{
	return 0x00000ca4U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_unit_f(u32 v)
{
	return (v & 0x3U) << 1U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_unit_m(void)
{
	return U32(0x3U) << 1U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_unit_v(u32 r)
{
	return (r >> 1U) & 0x3U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_unit_packets_v(void)
{
	return 0x00000001U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_unit_packets_f(void)
{
	return 0x2U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_unit_cycles_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_unit_cycles_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_vcsetfiltermode_f(u32 v)
{
	return (v & 0x3U) << 8U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_vcsetfiltermode_m(void)
{
	return U32(0x3U) << 8U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_vcsetfiltermode_v(u32 r)
{
	return (r >> 8U) & 0x3U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_vcsetfiltermode_init_v(void)
{
	return 0x00000003U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_vcsetfiltermode_init_f(void)
{
	return 0x300U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_flitfilter_f(u32 v)
{
	return (v & 0x1fU) << 3U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_flitfilter_m(void)
{
	return U32(0x1fU) << 3U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_flitfilter_v(u32 r)
{
	return (r >> 3U) & 0x1fU;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_flitfilter_idle_v(void)
{
	return 0x00000010U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_ctrl_0_flitfilter_idle_f(void)
{
	return 0x80U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_lo_r(void)
{
	return 0x0000049cU;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_hi_r(void)
{
	return 0x000004a0U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_hi_rollover_f(u32 v)
{
	return (v & 0x1U) << 31U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_hi_rollover_m(void)
{
	return U32(0x1U) << 31U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_hi_rollover_v(u32 r)
{
	return (r >> 31U) & 0x1U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_hi_rollover_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_tx_debug_tp_cntr0_hi_rollover_init_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_lo_r(void)
{
	return 0x000004acU;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_hi_r(void)
{
	return 0x000004b0U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_hi_rollover_f(u32 v)
{
	return (v & 0x1U) << 31U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_hi_rollover_m(void)
{
	return U32(0x1U) << 31U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_hi_rollover_v(u32 r)
{
	return (r >> 31U) & 0x1U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_hi_rollover_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_tx_debug_tp_cntr1_hi_rollover_init_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_lo_r(void)
{
	return 0x00000c9cU;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_hi_r(void)
{
	return 0x00000ca0U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_hi_rollover_f(u32 v)
{
	return (v & 0x1U) << 31U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_hi_rollover_m(void)
{
	return U32(0x1U) << 31U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_hi_rollover_v(u32 r)
{
	return (r >> 31U) & 0x1U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_hi_rollover_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_rx_debug_tp_cntr0_hi_rollover_init_f(void)
{
	return 0x0U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_lo_r(void)
{
	return 0x00000cacU;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_hi_r(void)
{
	return 0x00000cb0U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_hi_rollover_f(u32 v)
{
	return (v & 0x1U) << 31U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_hi_rollover_m(void)
{
	return U32(0x1U) << 31U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_hi_rollover_v(u32 r)
{
	return (r >> 31U) & 0x1U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_hi_rollover_init_v(void)
{
	return 0x00000000U;
}
static inline u32 nvltlc_rx_debug_tp_cntr1_hi_rollover_init_f(void)
{
	return 0x0U;
}
#endif
