/*
 * Copyright (c) 2018-2020, NVIDIA CORPORATION.  All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
/*
 * Function/Macro naming determines intended use:
 *
 *     <x>_r(void) : Returns the offset for register <x>.
 *
 *     <x>_o(void) : Returns the offset for element <x>.
 *
 *     <x>_w(void) : Returns the word offset for word (4 byte) element <x>.
 *
 *     <x>_<y>_s(void) : Returns size of field <y> of register <x> in bits.
 *
 *     <x>_<y>_f(u32 v) : Returns a value based on 'v' which has been shifted
 *         and masked to place it at field <y> of register <x>.  This value
 *         can be |'d with others to produce a full register value for
 *         register <x>.
 *
 *     <x>_<y>_m(void) : Returns a mask for field <y> of register <x>.  This
 *         value can be ~'d and then &'d to clear the value of field <y> for
 *         register <x>.
 *
 *     <x>_<y>_<z>_f(void) : Returns the constant value <z> after being shifted
 *         to place it at field <y> of register <x>.  This value can be |'d
 *         with others to produce a full register value for <x>.
 *
 *     <x>_<y>_v(u32 r) : Returns the value of field <y> from a full register
 *         <x> value 'r' after being shifted to place its LSB at bit 0.
 *         This value is suitable for direct comparison with other unshifted
 *         values appropriate for use in field <y> of register <x>.
 *
 *     <x>_<y>_<z>_v(void) : Returns the constant value for <z> defined for
 *         field <y> of register <x>.  This value is suitable for direct
 *         comparison with unshifted values appropriate for use in field <y>
 *         of register <x>.
 */
#ifndef NVLINK_HW_NVSYNC2X_T19X_H
#define NVLINK_HW_NVSYNC2X_T19X_H

#include <nvlink/common/types.h>

static inline u32 nvsync2x_eccparity_ctrl_r(void)
{
	return 0x0000010cU;
}
static inline u32 nvsync2x_eccparity_ctrl_rx_parity_ctrl2_enb_f(u32 v)
{
	return (v & 0x1U) << 3U;
}
static inline u32 nvsync2x_eccparity_ctrl_rx_parity_ctrl2_enb_m(void)
{
	return U32(0x1U) << 3U;
}
static inline u32 nvsync2x_eccparity_ctrl_rx_parity_ctrl2_enb_v(u32 r)
{
	return (r >> 3U) & 0x1U;
}
static inline u32 nvsync2x_eccparity_ctrl_tx_eccenb0_f(u32 v)
{
	return (v & 0x1U) << 16U;
}
static inline u32 nvsync2x_eccparity_ctrl_tx_eccenb0_m(void)
{
	return U32(0x1U) << 16U;
}
static inline u32 nvsync2x_eccparity_ctrl_tx_eccenb0_v(u32 r)
{
	return (r >> 16U) & 0x1U;
}
static inline u32 nvsync2x_eccparity_ctrl_tx_parity_ctrl1_enb_f(u32 v)
{
	return (v & 0x1U) << 18U;
}
static inline u32 nvsync2x_eccparity_ctrl_tx_parity_ctrl1_enb_m(void)
{
	return U32(0x1U) << 18U;
}
static inline u32 nvsync2x_eccparity_ctrl_tx_parity_ctrl1_enb_v(u32 r)
{
	return (r >> 18U) & 0x1U;
}
static inline u32 nvsync2x_eccparity_ctrl_tx_eccparitycounterenb0_f(u32 v)
{
	return (v & 0x1U) << 20U;
}
static inline u32 nvsync2x_eccparity_ctrl_tx_eccparitycounterenb0_m(void)
{
	return U32(0x1U) << 20U;
}
static inline u32 nvsync2x_eccparity_ctrl_tx_eccparitycounterenb0_v(u32 r)
{
	return (r >> 20U) & 0x1U;
}
static inline u32 nvsync2x_eccparity_ctrl_tx_eccparitycountsinglebit0_f(u32 v)
{
	return (v & 0x1U) << 21U;
}
static inline u32 nvsync2x_eccparity_ctrl_tx_eccparitycountsinglebit0_m(void)
{
	return U32(0x1U) << 21U;
}
static inline u32 nvsync2x_eccparity_ctrl_tx_eccparitycountsinglebit0_v(u32 r)
{
	return (r >> 21U) & 0x1U;
}
static inline u32 nvsync2x_tx_eccparity_error_limit_r(void)
{
	return 0x00000120U;
}
static inline u32 nvsync2x_tx_eccparity_error_limit_error_limit_f(u32 v)
{
	return (v & 0xffffffU) << 0U;
}
static inline u32 nvsync2x_tx_eccparity_error_limit_error_limit_m(void)
{
	return U32(0xffffffU) << 0U;
}
static inline u32 nvsync2x_tx_eccparity_error_limit_error_limit_v(u32 r)
{
	return (r >> 0U) & 0xffffffU;
}
static inline u32 nvsync2x_err_log_en_0_r(void)
{
	return 0x00000204U;
}
static inline u32 nvsync2x_err_log_en_0_rxparityctrl2err_f(u32 v)
{
	return (v & 0x1U) << 7U;
}
static inline u32 nvsync2x_err_log_en_0_rxparityctrl2err_m(void)
{
	return U32(0x1U) << 7U;
}
static inline u32 nvsync2x_err_log_en_0_rxparityctrl2err_v(u32 r)
{
	return (r >> 7U) & 0x1U;
}
static inline u32 nvsync2x_err_log_en_0_txeccparitylimiterr_f(u32 v)
{
	return (v & 0x1U) << 8U;
}
static inline u32 nvsync2x_err_log_en_0_txeccparitylimiterr_m(void)
{
	return U32(0x1U) << 8U;
}
static inline u32 nvsync2x_err_log_en_0_txeccparitylimiterr_v(u32 r)
{
	return (r >> 8U) & 0x1U;
}
static inline u32 nvsync2x_err_log_en_0_txecchdrdoublebiterr_f(u32 v)
{
	return (v & 0x1U) << 9U;
}
static inline u32 nvsync2x_err_log_en_0_txecchdrdoublebiterr_m(void)
{
	return U32(0x1U) << 9U;
}
static inline u32 nvsync2x_err_log_en_0_txecchdrdoublebiterr_v(u32 r)
{
	return (r >> 9U) & 0x1U;
}
static inline u32 nvsync2x_err_log_en_0_txeccdatadoublebiterr_f(u32 v)
{
	return (v & 0x1U) << 10U;
}
static inline u32 nvsync2x_err_log_en_0_txeccdatadoublebiterr_m(void)
{
	return U32(0x1U) << 10U;
}
static inline u32 nvsync2x_err_log_en_0_txeccdatadoublebiterr_v(u32 r)
{
	return (r >> 10U) & 0x1U;
}
static inline u32 nvsync2x_err_log_en_0_txparityctrl0err_f(u32 v)
{
	return (v & 0x1U) << 12U;
}
static inline u32 nvsync2x_err_log_en_0_txparityctrl0err_m(void)
{
	return U32(0x1U) << 12U;
}
static inline u32 nvsync2x_err_log_en_0_txparityctrl0err_v(u32 r)
{
	return (r >> 12U) & 0x1U;
}
static inline u32 nvsync2x_err_log_en_0_txparityctrl1err_f(u32 v)
{
	return (v & 0x1U) << 13U;
}
static inline u32 nvsync2x_err_log_en_0_txparityctrl1err_m(void)
{
	return U32(0x1U) << 13U;
}
static inline u32 nvsync2x_err_log_en_0_txparityctrl1err_v(u32 r)
{
	return (r >> 13U) & 0x1U;
}
static inline u32 nvsync2x_err_log_en_0_rxbufferoverflowerr_f(u32 v)
{
	return (v & 0x1U) << 3U;
}
static inline u32 nvsync2x_err_log_en_0_rxbufferoverflowerr_m(void)
{
	return U32(0x1U) << 3U;
}
static inline u32 nvsync2x_err_log_en_0_rxbufferoverflowerr_v(u32 r)
{
	return (r >> 3U) & 0x1U;
}
static inline u32 nvsync2x_err_report_en_0_r(void)
{
	return 0x00000208U;
}
static inline u32 nvsync2x_err_report_en_0_rxparityctrl2err_f(u32 v)
{
	return (v & 0x1U) << 7U;
}
static inline u32 nvsync2x_err_report_en_0_rxparityctrl2err_m(void)
{
	return U32(0x1U) << 7U;
}
static inline u32 nvsync2x_err_report_en_0_rxparityctrl2err_v(u32 r)
{
	return (r >> 7U) & 0x1U;
}
static inline u32 nvsync2x_err_report_en_0_txeccparitylimiterr_f(u32 v)
{
	return (v & 0x1U) << 8U;
}
static inline u32 nvsync2x_err_report_en_0_txeccparitylimiterr_m(void)
{
	return U32(0x1U) << 8U;
}
static inline u32 nvsync2x_err_report_en_0_txeccparitylimiterr_v(u32 r)
{
	return (r >> 8U) & 0x1U;
}
static inline u32 nvsync2x_err_report_en_0_txecchdrdoublebiterr_f(u32 v)
{
	return (v & 0x1U) << 9U;
}
static inline u32 nvsync2x_err_report_en_0_txecchdrdoublebiterr_m(void)
{
	return U32(0x1U) << 9U;
}
static inline u32 nvsync2x_err_report_en_0_txecchdrdoublebiterr_v(u32 r)
{
	return (r >> 9U) & 0x1U;
}
static inline u32 nvsync2x_err_report_en_0_txeccdatadoublebiterr_f(u32 v)
{
	return (v & 0x1U) << 10U;
}
static inline u32 nvsync2x_err_report_en_0_txeccdatadoublebiterr_m(void)
{
	return U32(0x1U) << 10U;
}
static inline u32 nvsync2x_err_report_en_0_txeccdatadoublebiterr_v(u32 r)
{
	return (r >> 10U) & 0x1U;
}
static inline u32 nvsync2x_err_report_en_0_txparityctrl0err_f(u32 v)
{
	return (v & 0x1U) << 12U;
}
static inline u32 nvsync2x_err_report_en_0_txparityctrl0err_m(void)
{
	return U32(0x1U) << 12U;
}
static inline u32 nvsync2x_err_report_en_0_txparityctrl0err_v(u32 r)
{
	return (r >> 12U) & 0x1U;
}
static inline u32 nvsync2x_err_report_en_0_txparityctrl1err_f(u32 v)
{
	return (v & 0x1U) << 13U;
}
static inline u32 nvsync2x_err_report_en_0_txparityctrl1err_m(void)
{
	return U32(0x1U) << 13U;
}
static inline u32 nvsync2x_err_report_en_0_txparityctrl1err_v(u32 r)
{
	return (r >> 13U) & 0x1U;
}
static inline u32 nvsync2x_err_report_en_0_rxbufferoverflowerr_f(u32 v)
{
	return (v & 0x1U) << 3U;
}
static inline u32 nvsync2x_err_report_en_0_rxbufferoverflowerr_m(void)
{
	return U32(0x1U) << 3U;
}
static inline u32 nvsync2x_err_report_en_0_rxbufferoverflowerr_v(u32 r)
{
	return (r >> 3U) & 0x1U;
}
static inline u32 nvsync2x_err_contain_en_0_r(void)
{
	return 0x0000020cU;
}
static inline u32 nvsync2x_err_contain_en_0_rxparityctrl2err_f(u32 v)
{
	return (v & 0x1U) << 7U;
}
static inline u32 nvsync2x_err_contain_en_0_rxparityctrl2err_m(void)
{
	return U32(0x1U) << 7U;
}
static inline u32 nvsync2x_err_contain_en_0_rxparityctrl2err_v(u32 r)
{
	return (r >> 7U) & 0x1U;
}
static inline u32 nvsync2x_err_contain_en_0_txecchdrdoublebiterr_f(u32 v)
{
	return (v & 0x1U) << 9U;
}
static inline u32 nvsync2x_err_contain_en_0_txecchdrdoublebiterr_m(void)
{
	return U32(0x1U) << 9U;
}
static inline u32 nvsync2x_err_contain_en_0_txecchdrdoublebiterr_v(u32 r)
{
	return (r >> 9U) & 0x1U;
}
static inline u32 nvsync2x_err_contain_en_0_txeccdatadoublebiterr_f(u32 v)
{
	return (v & 0x1U) << 10U;
}
static inline u32 nvsync2x_err_contain_en_0_txeccdatadoublebiterr_m(void)
{
	return U32(0x1U) << 10U;
}
static inline u32 nvsync2x_err_contain_en_0_txeccdatadoublebiterr_v(u32 r)
{
	return (r >> 10U) & 0x1U;
}
static inline u32 nvsync2x_err_contain_en_0_txparityctrl0err_f(u32 v)
{
	return (v & 0x1U) << 12U;
}
static inline u32 nvsync2x_err_contain_en_0_txparityctrl0err_m(void)
{
	return U32(0x1U) << 12U;
}
static inline u32 nvsync2x_err_contain_en_0_txparityctrl0err_v(u32 r)
{
	return (r >> 12U) & 0x1U;
}
static inline u32 nvsync2x_err_contain_en_0_txparityctrl1err_f(u32 v)
{
	return (v & 0x1U) << 13U;
}
static inline u32 nvsync2x_err_contain_en_0_txparityctrl1err_m(void)
{
	return U32(0x1U) << 13U;
}
static inline u32 nvsync2x_err_contain_en_0_txparityctrl1err_v(u32 r)
{
	return (r >> 13U) & 0x1U;
}
static inline u32 nvsync2x_err_contain_en_0_rxbufferoverflowerr_f(u32 v)
{
	return (v & 0x1U) << 3U;
}
static inline u32 nvsync2x_err_contain_en_0_rxbufferoverflowerr_m(void)
{
	return U32(0x1U) << 3U;
}
static inline u32 nvsync2x_err_contain_en_0_rxbufferoverflowerr_v(u32 r)
{
	return (r >> 3U) & 0x1U;
}
#endif
