/*
 * Copyright (c) 2017-2020, NVIDIA CORPORATION.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU General Public License,
 * version 2, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 */

#define  OFF_ERRLOGGER_0_ID_COREID_0            0x00000000
#define  OFF_ERRLOGGER_0_ID_REVISIONID_0        0x00000004
#define  OFF_ERRLOGGER_0_FAULTEN_0              0x00000008
#define  OFF_ERRLOGGER_0_ERRVLD_0               0x0000000c
#define  OFF_ERRLOGGER_0_ERRCLR_0               0x00000010
#define  OFF_ERRLOGGER_0_ERRLOG0_0              0x00000014
#define  OFF_ERRLOGGER_0_ERRLOG1_0              0x00000018
#define  OFF_ERRLOGGER_0_RESERVED_00_0          0x0000001c
#define  OFF_ERRLOGGER_0_ERRLOG3_0              0x00000020
#define  OFF_ERRLOGGER_0_ERRLOG4_0              0x00000024
#define  OFF_ERRLOGGER_0_ERRLOG5_0              0x00000028
#define  OFF_ERRLOGGER_0_STALLEN_0              0x00000038

#define  OFF_ERRLOGGER_1_ID_COREID_0            0x00000080
#define  OFF_ERRLOGGER_1_ID_REVISIONID_0        0x00000084
#define  OFF_ERRLOGGER_1_FAULTEN_0              0x00000088
#define  OFF_ERRLOGGER_1_ERRVLD_0               0x0000008c
#define  OFF_ERRLOGGER_1_ERRCLR_0               0x00000090
#define  OFF_ERRLOGGER_1_ERRLOG0_0              0x00000094
#define  OFF_ERRLOGGER_1_ERRLOG1_0              0x00000098
#define  OFF_ERRLOGGER_1_RESERVED_00_0          0x0000009c
#define  OFF_ERRLOGGER_1_ERRLOG3_0              0x000000A0
#define  OFF_ERRLOGGER_1_ERRLOG4_0              0x000000A4
#define  OFF_ERRLOGGER_1_ERRLOG5_0              0x000000A8
#define  OFF_ERRLOGGER_1_STALLEN_0              0x000000b8

#define  OFF_ERRLOGGER_2_ID_COREID_0            0x00000100
#define  OFF_ERRLOGGER_2_ID_REVISIONID_0        0x00000104
#define  OFF_ERRLOGGER_2_FAULTEN_0              0x00000108
#define  OFF_ERRLOGGER_2_ERRVLD_0               0x0000010c
#define  OFF_ERRLOGGER_2_ERRCLR_0               0x00000110
#define  OFF_ERRLOGGER_2_ERRLOG0_0              0x00000114
#define  OFF_ERRLOGGER_2_ERRLOG1_0              0x00000118
#define  OFF_ERRLOGGER_2_RESERVED_00_0          0x0000011c
#define  OFF_ERRLOGGER_2_ERRLOG3_0              0x00000120
#define  OFF_ERRLOGGER_2_ERRLOG4_0              0x00000124
#define  OFF_ERRLOGGER_2_ERRLOG5_0              0x00000128
#define  OFF_ERRLOGGER_2_STALLEN_0              0x00000138

#define get_noc_errlog_subfield(_x_, _msb_, _lsb_) \
	CBB_EXTRACT(_x_, _msb_, _lsb_)

extern int nvcvnas_busy(void);
extern int nvcvnas_idle(void);
extern int is_nvcvnas_probed(void);
extern int nvcvnas_busy_no_rpm(void);
extern int nvcvnas_idle_no_rpm(void);
extern int is_nvcvnas_clk_enabled(void);

struct tegra_noc_packet_header {
	bool lock;   // [0]
	u8   opc;    // [4:1]
	u8   errcode;// [10:8]= RD, RDW, RDL, RDX, WR, WRW, WRC, PRE, URG
	u16  len1;   // [27:16]
	bool format; // [31]  = 1 -> FlexNoC versions 2.7 & above
};

struct tegra_lookup_noc_aperture {
	u8  initflow;
	u8  targflow;
	u8  targ_subrange;
	u8  init_mapping;
	u32 init_localaddress;
	u8  targ_mapping;
	u32 targ_localaddress;
	u16 seqid;
};

struct tegra_noc_userbits {
	u8  axcache;
	u8  non_mod;
	u8  axprot;
	u8  falconsec;
	u8  grpsec;
	u8  vqc;
	u8  mstr_id;
	u8  axi_id;
};

struct tegra_cbb_errlog_record {
	struct list_head node;
	struct serr_hook *callback;
	char *name;
	phys_addr_t start;
	void __iomem *vaddr;
	int num_intr;
	int noc_secure_irq;
	int noc_nonsecure_irq;
	u32 errlog0;
	u32 errlog1;
	u32 errlog2;
	u32 errlog3;
	u32 errlog4;
	u32 errlog5;
	u32 errlog6;	//RESERVED
	u32 errlog7;	//RESERVED
	u32 errlog8;	//RESERVED
	void (*tegra_noc_parse_routeid)(struct tegra_lookup_noc_aperture *, u64);
	void (*tegra_noc_parse_userbits)(struct tegra_noc_userbits *, u64);
	struct tegra_lookup_noc_aperture *noc_aperture;
	int  max_noc_aperture;
	char **tegra_noc_routeid_initflow;
	char **tegra_noc_routeid_targflow;
	char **tegra_cbb_master_id;
	bool is_ax2apb_bridge_connected;
	void __iomem **axi2abp_bases;
	int  apb_bridge_cnt;
	bool erd_mask_inband_err;
	bool is_clk_rst;
	int (*is_cluster_probed)(void);
	int (*is_clk_enabled)(void);
	int (*tegra_noc_en_clk_rpm)(void);
	int (*tegra_noc_dis_clk_rpm)(void);
	int (*tegra_noc_en_clk_no_rpm)(void);
	int (*tegra_noc_dis_clk_no_rpm)(void);
};

static struct tegra_noc_errors tegra194_noc_errors[] = {
	{.errcode = "SLV",
	 .src = "Target",
	 .type = "Target error detected by CBB slave"
	},
	{.errcode = "DEC",
	 .src = "Initiator NIU",
	 .type = "Address decode error"
	},
	{.errcode = "UNS",
	 .src = "Target NIU",
	 .type = "Unsupported request. Not a valid transaction"
	},
	{.errcode = "DISC",                     /* Not Supported by CBB */
	 .src = "Power Disconnect",
	 .type = "Disconnected target or domain"
	},
	{.errcode = "SEC",
	 .src = "Initiator NIU or Firewall",
	 .type = "Security violation. Firewall error"
	},
	{.errcode = "HIDE",                     /* Not Supported by CBB */
	 .src = "Firewall",
	 .type = "Hidden security violation, reported as OK to initiator"
	},
	{.errcode = "TMO",
	 .src = "Target NIU",
	 .type = "Target time-out error"
	},
	{.errcode = "RSV",
	 .src = "None",
	 .type = "Reserved"
	}
};

static char *tegra194_noc_opc_trantype[] = {
	"RD  - Read, Incrementing",
	"RDW - Read, Wrap",                     /* Not Supported by CBB */
	"RDX - Exclusive Read",                 /* Not Supported by CBB */
	"RDL - Linked Read",                    /* Not Supported by CBB */
	"WR  - Write, Incrementing",
	"WRW - Write, Wrap",                    /* Not Supported by CBB */
	"WRC - Exclusive Write",                /* Not Supported by CBB */
	"PRE - Preamble Sequence for Fixed Accesses"
};

static char *t194_master_id[] = {
	"CCPLEX",                               /* 0x1 */
	"CCPLEX_DPMU",                          /* 0x2 */
	"BPMP",                                 /* 0x3 */
	"AON",                                  /* 0x4 */
	"SCE",                                  /* 0x5 */
	"GPCDMA_PERIPHERAL",                    /* 0x6 */
	"TSECA",                                /* 0x7 */
	"TSECB",                                /* 0x8 */
	"JTAGM_DFT",                            /* 0x9 */
	"CORESIGHT_AXIAP",                      /* 0xa */
	"APE",                                  /* 0xb */
	"PEATR",                                /* 0xc */
	"NVDEC",                                /* 0xd */
	"RCE",                                  /* 0xe */
	"NVDEC1"                                /* 0xf */
};

static char *tegra194_axi2apb_errors[] = {
	"SFIFONE - Status FIFO Not Empty interrupt",
	"SFIFOF - Status FIFO Full interrupt",
	"TIM - Timer(Timeout) interrupt",
	"SLV - SLVERR interrupt",
	"NULL",
	"ERBF - Early response buffer Full interrupt",
	"NULL",
	"RDFIFOF - Read Response FIFO Full interrupt",
	"WRFIFOF - Write Response FIFO Full interrupt",
	"CH0DFIFOF - Ch0 Data FIFO Full interrupt",
	"CH1DFIFOF - Ch1 Data FIFO Full interrupt",
	"CH2DFIFOF - Ch2 Data FIFO Full interrupt",
	"UAT - Unsupported alignment type error",
	"UBS - Unsupported burst size error",
	"UBE - Unsupported Byte Enable error",
	"UBT - Unsupported burst type error",
	"BFS - Block Firewall security error",
	"ARFS - Address Range Firewall security error",
	"CH0RFIFOF - Ch0 Request FIFO Full interrupt",
	"CH1RFIFOF - Ch1 Request FIFO Full interrupt",
	"CH2RFIFOF - Ch2 Request FIFO Full interrupt"
};

/*
 * CBB NOC aperture lookup table as per file "cbb_central_noc_Structure.info".
 */

static char *t194_cbbcentralnoc_routeid_initflow[] = {
	"aon_p2ps/I/aon",                       /* 0x0 */
	"ape_p2ps/I/ape_p2ps",                  /* 0x1 */
	"bpmp_p2ps/I/bpmp_p2ps",                /* 0x2 */
	"ccroc_p2ps/I/ccroc_p2ps",              /* 0x3 */
	"csite_p2ps/I/0",                       /* 0x4 */
	"gpcdma_mmio_p2ps/I/0",                 /* 0x5 */
	"jtag_p2ps/I/0",                        /* 0x6 */
	"nvdec1_p2ps/I/0",                      /* 0x7 */
	"nvdec_p2ps/I/0",                       /* 0x8 */
	"rce_p2ps/I/rce_p2ps",                  /* 0x9 */
	"sce_p2ps/I/sce_p2ps",                  /* 0xA */
	"tseca_p2ps/I/0",                       /* 0xB */
	"tsecb_p2ps/I/0",                       /* 0xC */
	"RESERVED",                             /* 0xD */
	"RESERVED",                             /* 0xE */
	"RESERVED"                              /* 0xF */
};

static char *t194_cbbcentralnoc_routeid_targflow[] = {
	"SVC/T/intreg",                                                 /*0x0*/
	"axis_satellite_axi2apb_p2pm/T/axis_satellite_axi2apb_p2pm",    /*0x1*/
	"axis_satellite_grout/T/axis_satellite_grout",                  /*0x2*/
	"cbb_firewall/T/cbb_firewall",                                  /*0x3*/
	"gpu_p2pm/T/gpu_p2pm",                                          /*0x4*/
	"host1x_p2pm/T/host1x_p2pm",                                    /*0x5*/
	"sapb_3_p2pm/T/sapb_3_p2pm",                                    /*0x6*/
	"smmu0_p2pm/T/smmu0_p2pm",                                      /*0x7*/
	"smmu1_p2pm/T/smmu1_p2pm",                                      /*0x8*/
	"smmu2_p2pm/T/smmu2_p2pm",                                      /*0x9*/
	"stm_p2pm/T/stm_p2pm",                                          /*0xA*/
	"RESERVED",                                                     /*0xB*/
	"RESERVED",                                                     /*0xC*/
	"RESERVED",                                                     /*0xD*/
	"RESERVED",                                                     /*0xE*/
	"RESERVED"                                                      /*0xF*/
};

/*
 * Fields of CBB NOC lookup table:
 * Init flow, Targ flow, Targ subrange, Init mapping, Init localAddress,
 *                                              Targ mapping, Targ localAddress
 * ----------------------------------------------------------------------------
 */
static struct tegra_lookup_noc_aperture t194_cbbcentralnoc_aperture_lookup[] = {
	{ 0x0, 0x0, 0x00, 0x0, 0x02300000,  0, 0x0 },
	{ 0x0, 0x1, 0x00, 0x0, 0x02003000,  0, 0x02003000 },
	{ 0x0, 0x1, 0x01, 0x0, 0x02006000,  2, 0x02006000 },
	{ 0x0, 0x1, 0x02, 0x0, 0x02016000,  3, 0x02016000 },
	{ 0x0, 0x1, 0x03, 0x0, 0x0201d000,  4, 0x0201d000 },
	{ 0x0, 0x1, 0x04, 0x0, 0x0202b000,  6, 0x0202b000 },
	{ 0x0, 0x1, 0x05, 0x0, 0x02434000, 20, 0x02434000 },
	{ 0x0, 0x1, 0x06, 0x0, 0x02436000, 21, 0x02436000 },
	{ 0x0, 0x1, 0x07, 0x0, 0x02438000, 22, 0x02438000 },
	{ 0x0, 0x1, 0x08, 0x0, 0x02445000, 24, 0x02445000 },
	{ 0x0, 0x1, 0x09, 0x0, 0x02446000, 25, 0x02446000 },
	{ 0x0, 0x1, 0x0a, 0x0, 0x02004000,  1, 0x02004000 },
	{ 0x0, 0x1, 0x0b, 0x0, 0x0201e000,  5, 0x0201e000 },
	{ 0x0, 0x1, 0x0c, 0x0, 0x0202c000,  7, 0x0202c000 },
	{ 0x0, 0x1, 0x0d, 0x0, 0x02204000,  8, 0x02204000 },
	{ 0x0, 0x1, 0x0e, 0x0, 0x02214000,  9, 0x02214000 },
	{ 0x0, 0x1, 0x0f, 0x0, 0x02224000, 10, 0x02224000 },
	{ 0x0, 0x1, 0x10, 0x0, 0x02234000, 11, 0x02234000 },
	{ 0x0, 0x1, 0x11, 0x0, 0x02244000, 12, 0x02244000 },
	{ 0x0, 0x1, 0x12, 0x0, 0x02254000, 13, 0x02254000 },
	{ 0x0, 0x1, 0x13, 0x0, 0x02264000, 14, 0x02264000 },
	{ 0x0, 0x1, 0x14, 0x0, 0x02274000, 15, 0x02274000 },
	{ 0x0, 0x1, 0x15, 0x0, 0x02284000, 16, 0x02284000 },
	{ 0x0, 0x1, 0x16, 0x0, 0x0243a000, 23, 0x0243a000 },
	{ 0x0, 0x1, 0x17, 0x0, 0x02370000, 17, 0x02370000 },
	{ 0x0, 0x1, 0x18, 0x0, 0x023d0000, 18, 0x023d0000 },
	{ 0x0, 0x1, 0x19, 0x0, 0x023e0000, 19, 0x023e0000 },
	{ 0x0, 0x1, 0x1a, 0x0, 0x02450000, 26, 0x02450000 },
	{ 0x0, 0x1, 0x1b, 0x0, 0x02460000, 27, 0x02460000 },
	{ 0x0, 0x1, 0x1c, 0x0, 0x02490000, 28, 0x02490000 },
	{ 0x0, 0x1, 0x1d, 0x0, 0x03130000, 31, 0x03130000 },
	{ 0x0, 0x1, 0x1e, 0x0, 0x03160000, 32, 0x03160000 },
	{ 0x0, 0x1, 0x1f, 0x0, 0x03270000, 33, 0x03270000 },
	{ 0x0, 0x1, 0x20, 0x0, 0x032e0000, 35, 0x032e0000 },
	{ 0x0, 0x1, 0x21, 0x0, 0x03300000, 36, 0x03300000 },
	{ 0x0, 0x1, 0x22, 0x0, 0x13090000, 40, 0x13090000 },
	{ 0x0, 0x1, 0x23, 0x0, 0x20120000, 43, 0x20120000 },
	{ 0x0, 0x1, 0x24, 0x0, 0x20170000, 44, 0x20170000 },
	{ 0x0, 0x1, 0x25, 0x0, 0x20190000, 45, 0x20190000 },
	{ 0x0, 0x1, 0x26, 0x0, 0x201b0000, 46, 0x201b0000 },
	{ 0x0, 0x1, 0x27, 0x0, 0x20250000, 47, 0x20250000 },
	{ 0x0, 0x1, 0x28, 0x0, 0x20260000, 48, 0x20260000 },
	{ 0x0, 0x1, 0x29, 0x0, 0x20420000, 49, 0x20420000 },
	{ 0x0, 0x1, 0x2a, 0x0, 0x20460000, 50, 0x20460000 },
	{ 0x0, 0x1, 0x2b, 0x0, 0x204f0000, 51, 0x204f0000 },
	{ 0x0, 0x1, 0x2c, 0x0, 0x20520000, 52, 0x20520000 },
	{ 0x0, 0x1, 0x2d, 0x0, 0x20580000, 53, 0x20580000 },
	{ 0x0, 0x1, 0x2e, 0x0, 0x205a0000, 54, 0x205a0000 },
	{ 0x0, 0x1, 0x2f, 0x0, 0x205c0000, 55, 0x205c0000 },
	{ 0x0, 0x1, 0x30, 0x0, 0x20690000, 56, 0x20690000 },
	{ 0x0, 0x1, 0x31, 0x0, 0x20770000, 57, 0x20770000 },
	{ 0x0, 0x1, 0x32, 0x0, 0x20790000, 58, 0x20790000 },
	{ 0x0, 0x1, 0x33, 0x0, 0x20880000, 59, 0x20880000 },
	{ 0x0, 0x1, 0x34, 0x0, 0x20990000, 62, 0x20990000 },
	{ 0x0, 0x1, 0x35, 0x0, 0x20e10000, 65, 0x20e10000 },
	{ 0x0, 0x1, 0x36, 0x0, 0x20e70000, 66, 0x20e70000 },
	{ 0x0, 0x1, 0x37, 0x0, 0x20e80000, 67, 0x20e80000 },
	{ 0x0, 0x1, 0x38, 0x0, 0x20f30000, 68, 0x20f30000 },
	{ 0x0, 0x1, 0x39, 0x0, 0x20f50000, 69, 0x20f50000 },
	{ 0x0, 0x1, 0x3a, 0x0, 0x20fc0000, 70, 0x20fc0000 },
	{ 0x0, 0x1, 0x3b, 0x0, 0x21110000, 72, 0x21110000 },
	{ 0x0, 0x1, 0x3c, 0x0, 0x21270000, 73, 0x21270000 },
	{ 0x0, 0x1, 0x3d, 0x0, 0x21290000, 74, 0x21290000 },
	{ 0x0, 0x1, 0x3e, 0x0, 0x21840000, 75, 0x21840000 },
	{ 0x0, 0x1, 0x3f, 0x0, 0x21880000, 76, 0x21880000 },
	{ 0x0, 0x1, 0x40, 0x0, 0x218d0000, 77, 0x218d0000 },
	{ 0x0, 0x1, 0x41, 0x0, 0x21950000, 78, 0x21950000 },
	{ 0x0, 0x1, 0x42, 0x0, 0x21960000, 79, 0x21960000 },
	{ 0x0, 0x1, 0x43, 0x0, 0x21a10000, 80, 0x21a10000 },
	{ 0x0, 0x1, 0x44, 0x0, 0x024a0000, 29, 0x024a0000 },
	{ 0x0, 0x1, 0x45, 0x0, 0x024c0000, 30, 0x024c0000 },
	{ 0x0, 0x1, 0x46, 0x0, 0x032c0000, 34, 0x032c0000 },
	{ 0x0, 0x1, 0x47, 0x0, 0x03400000, 37, 0x03400000 },
	{ 0x0, 0x1, 0x48, 0x0, 0x130a0000, 41, 0x130a0000 },
	{ 0x0, 0x1, 0x49, 0x0, 0x130c0000, 42, 0x130c0000 },
	{ 0x0, 0x1, 0x4a, 0x0, 0x208a0000, 60, 0x208a0000 },
	{ 0x0, 0x1, 0x4b, 0x0, 0x208c0000, 61, 0x208c0000 },
	{ 0x0, 0x1, 0x4c, 0x0, 0x209a0000, 63, 0x209a0000 },
	{ 0x0, 0x1, 0x4d, 0x0, 0x21a40000, 81, 0x21a40000 },
	{ 0x0, 0x1, 0x4e, 0x0, 0x03440000, 38, 0x03440000 },
	{ 0x0, 0x1, 0x4f, 0x0, 0x20d00000, 64, 0x20d00000 },
	{ 0x0, 0x1, 0x50, 0x0, 0x21000000, 71, 0x21000000 },
	{ 0x0, 0x1, 0x51, 0x0, 0x0b000000, 39, 0x0b000000 },
	{ 0x0, 0x2, 0x00, 0x0, 0x00000000,  0, 0x00000000 },
	{ 0x0, 0x3, 0x00, 0x0, 0x02340000,  0, 0x00000000 },
	{ 0x0, 0x4, 0x00, 0x0, 0x17000000,  0, 0x17000000 },
	{ 0x0, 0x4, 0x01, 0x0, 0x18000000,  1, 0x18000000 },
	{ 0x0, 0x5, 0x00, 0x0, 0x13e80000,  1, 0x13e80000 },
	{ 0x0, 0x5, 0x01, 0x0, 0x15810000, 12, 0x15810000 },
	{ 0x0, 0x5, 0x02, 0x0, 0x15840000, 14, 0x15840000 },
	{ 0x0, 0x5, 0x03, 0x0, 0x15a40000, 17, 0x15a40000 },
	{ 0x0, 0x5, 0x04, 0x0, 0x13f00000,  3, 0x13f00000 },
	{ 0x0, 0x5, 0x05, 0x0, 0x15820000, 13, 0x15820000 },
	{ 0x0, 0x5, 0x06, 0x0, 0x13ec0000,  2, 0x13ec0000 },
	{ 0x0, 0x5, 0x07, 0x0, 0x15200000,  6, 0x15200000 },
	{ 0x0, 0x5, 0x08, 0x0, 0x15340000,  7, 0x15340000 },
	{ 0x0, 0x5, 0x09, 0x0, 0x15380000,  8, 0x15380000 },
	{ 0x0, 0x5, 0x0a, 0x0, 0x15500000, 10, 0x15500000 },
	{ 0x0, 0x5, 0x0b, 0x0, 0x155c0000, 11, 0x155c0000 },
	{ 0x0, 0x5, 0x0c, 0x0, 0x15a00000, 16, 0x15a00000 },
	{ 0x0, 0x5, 0x0d, 0x0, 0x13e00000,  0, 0x13e00000 },
	{ 0x0, 0x5, 0x0e, 0x0, 0x15100000,  5, 0x15100000 },
	{ 0x0, 0x5, 0x0f, 0x0, 0x15480000,  9, 0x15480000 },
	{ 0x0, 0x5, 0x10, 0x0, 0x15880000, 15, 0x15880000 },
	{ 0x0, 0x5, 0x11, 0x0, 0x15a80000, 18, 0x15a80000 },
	{ 0x0, 0x5, 0x12, 0x0, 0x15b00000, 19, 0x15b00000 },
	{ 0x0, 0x5, 0x13, 0x0, 0x14800000,  4, 0x14800000 },
	{ 0x0, 0x5, 0x14, 0x0, 0x15c00000, 20, 0x15c00000 },
	{ 0x0, 0x5, 0x15, 0x0, 0x16000000, 21, 0x16000000 },
	{ 0x0, 0x6, 0x00, 0x0, 0x02000000,  4, 0x02000000 },
	{ 0x0, 0x6, 0x01, 0x0, 0x02007000,  5, 0x02007000 },
	{ 0x0, 0x6, 0x02, 0x0, 0x02008000,  6, 0x02008000 },
	{ 0x0, 0x6, 0x03, 0x0, 0x02013000,  7, 0x02013000 },
	{ 0x0, 0x6, 0x04, 0x0, 0x0201c000,  8, 0x0201c000 },
	{ 0x0, 0x6, 0x05, 0x0, 0x02020000,  9, 0x02020000 },
	{ 0x0, 0x6, 0x06, 0x0, 0x0202a000, 10, 0x0202a000 },
	{ 0x0, 0x6, 0x07, 0x0, 0x0202e000, 11, 0x0202e000 },
	{ 0x0, 0x6, 0x08, 0x0, 0x06400000, 33, 0x06400000 },
	{ 0x0, 0x6, 0x09, 0x0, 0x02038000, 12, 0x02038000 },
	{ 0x0, 0x6, 0x0a, 0x0, 0x00100000,  0, 0x00100000 },
	{ 0x0, 0x6, 0x0b, 0x0, 0x023b0000, 13, 0x023b0000 },
	{ 0x0, 0x6, 0x0c, 0x0, 0x02800000, 16, 0x02800000 },
	{ 0x0, 0x6, 0x0d, 0x0, 0x030e0000, 22, 0x030e0000 },
	{ 0x0, 0x6, 0x0e, 0x0, 0x03800000, 23, 0x03800000 },
	{ 0x0, 0x6, 0x0f, 0x0, 0x03980000, 25, 0x03980000 },
	{ 0x0, 0x6, 0x10, 0x0, 0x03a60000, 26, 0x03a60000 },
	{ 0x0, 0x6, 0x11, 0x0, 0x03d80000, 31, 0x03d80000 },
	{ 0x0, 0x6, 0x12, 0x0, 0x20000000, 36, 0x20000000 },
	{ 0x0, 0x6, 0x13, 0x0, 0x20050000, 38, 0x20050000 },
	{ 0x0, 0x6, 0x14, 0x0, 0x201e0000, 40, 0x201e0000 },
	{ 0x0, 0x6, 0x15, 0x0, 0x20280000, 42, 0x20280000 },
	{ 0x0, 0x6, 0x16, 0x0, 0x202c0000, 43, 0x202c0000 },
	{ 0x0, 0x6, 0x17, 0x0, 0x20390000, 44, 0x20390000 },
	{ 0x0, 0x6, 0x18, 0x0, 0x20430000, 45, 0x20430000 },
	{ 0x0, 0x6, 0x19, 0x0, 0x20440000, 46, 0x20440000 },
	{ 0x0, 0x6, 0x1a, 0x0, 0x204e0000, 47, 0x204e0000 },
	{ 0x0, 0x6, 0x1b, 0x0, 0x20550000, 48, 0x20550000 },
	{ 0x0, 0x6, 0x1c, 0x0, 0x20570000, 49, 0x20570000 },
	{ 0x0, 0x6, 0x1d, 0x0, 0x20590000, 50, 0x20590000 },
	{ 0x0, 0x6, 0x1e, 0x0, 0x20730000, 52, 0x20730000 },
	{ 0x0, 0x6, 0x1f, 0x0, 0x209f0000, 54, 0x209f0000 },
	{ 0x0, 0x6, 0x20, 0x0, 0x20e20000, 55, 0x20e20000 },
	{ 0x0, 0x6, 0x21, 0x0, 0x20ed0000, 56, 0x20ed0000 },
	{ 0x0, 0x6, 0x22, 0x0, 0x20fd0000, 57, 0x20fd0000 },
	{ 0x0, 0x6, 0x23, 0x0, 0x21120000, 59, 0x21120000 },
	{ 0x0, 0x6, 0x24, 0x0, 0x211a0000, 60, 0x211a0000 },
	{ 0x0, 0x6, 0x25, 0x0, 0x21850000, 61, 0x21850000 },
	{ 0x0, 0x6, 0x26, 0x0, 0x21860000, 62, 0x21860000 },
	{ 0x0, 0x6, 0x27, 0x0, 0x21890000, 63, 0x21890000 },
	{ 0x0, 0x6, 0x28, 0x0, 0x21970000, 64, 0x21970000 },
	{ 0x0, 0x6, 0x29, 0x0, 0x21990000, 65, 0x21990000 },
	{ 0x0, 0x6, 0x2a, 0x0, 0x21a00000, 66, 0x21a00000 },
	{ 0x0, 0x6, 0x2b, 0x0, 0x21a90000, 68, 0x21a90000 },
	{ 0x0, 0x6, 0x2c, 0x0, 0x21ac0000, 70, 0x21ac0000 },
	{ 0x0, 0x6, 0x2d, 0x0, 0x01f80000,  3, 0x01f80000 },
	{ 0x0, 0x6, 0x2e, 0x0, 0x024e0000, 14, 0x024e0000 },
	{ 0x0, 0x6, 0x2f, 0x0, 0x030c0000, 21, 0x030c0000 },
	{ 0x0, 0x6, 0x30, 0x0, 0x03820000, 24, 0x03820000 },
	{ 0x0, 0x6, 0x31, 0x0, 0x03aa0000, 27, 0x03aa0000 },
	{ 0x0, 0x6, 0x32, 0x0, 0x03c80000, 29, 0x03c80000 },
	{ 0x0, 0x6, 0x33, 0x0, 0x130e0000, 34, 0x130e0000 },
	{ 0x0, 0x6, 0x34, 0x0, 0x20020000, 37, 0x20020000 },
	{ 0x0, 0x6, 0x35, 0x0, 0x20060000, 39, 0x20060000 },
	{ 0x0, 0x6, 0x36, 0x0, 0x20200000, 41, 0x20200000 },
	{ 0x0, 0x6, 0x37, 0x0, 0x206a0000, 51, 0x206a0000 },
	{ 0x0, 0x6, 0x38, 0x0, 0x20740000, 53, 0x20740000 },
	{ 0x0, 0x6, 0x39, 0x0, 0x20fe0000, 58, 0x20fe0000 },
	{ 0x0, 0x6, 0x3a, 0x0, 0x21a20000, 67, 0x21a20000 },
	{ 0x0, 0x6, 0x3b, 0x0, 0x21aa0000, 69, 0x21aa0000 },
	{ 0x0, 0x6, 0x3c, 0x0, 0x02b80000, 17, 0x02b80000 },
	{ 0x0, 0x6, 0x3d, 0x0, 0x03080000, 20, 0x03080000 },
	{ 0x0, 0x6, 0x3e, 0x0, 0x13100000, 35, 0x13100000 },
	{ 0x0, 0x6, 0x3f, 0x0, 0x01f00000,  2, 0x01f00000 },
	{ 0x0, 0x6, 0x40, 0x0, 0x03000000, 19, 0x03000000 },
	{ 0x0, 0x6, 0x41, 0x0, 0x03c00000, 28, 0x03c00000 },
	{ 0x0, 0x6, 0x42, 0x0, 0x03d00000, 30, 0x03d00000 },
	{ 0x0, 0x6, 0x43, 0x0, 0x01700000,  1, 0x01700000 },
	{ 0x0, 0x6, 0x44, 0x0, 0x02c00000, 18, 0x02c00000 },
	{ 0x0, 0x6, 0x45, 0x0, 0x02600000, 15, 0x02600000 },
	{ 0x0, 0x6, 0x46, 0x0, 0x06000000, 32, 0x06000000 },
	{ 0x0, 0x6, 0x47, 0x0, 0x24000000, 71, 0x24000000 },
	{ 0x0, 0x7, 0x00, 0x0, 0x12000000,  0, 0x12000000 },
	{ 0x0, 0x8, 0x00, 0x0, 0x11000000,  0, 0x11000000 },
	{ 0x0, 0x9, 0x00, 0x0, 0x10000000,  0, 0x10000000 },
	{ 0x0, 0xA, 0x00, 0x0, 0x22000000,  0, 0x22000000 }
};


/*
 * BPMP NOC aperture lookup table as per file "BPMP_NOC_Structure.info".
 */

static char *t194_bpmpnoc_routeid_initflow[] = {
	"cbb_i/I/0",				/* 0x0 */
	"cpu_m_i/I/0",				/* 0x1 */
	"cpu_p_i/I/0",				/* 0x2 */
	"cvc_i/I/0",				/* 0x3 */
	"dma_m_i/I/0",				/* 0x4 */
	"dma_p_i/I/0",				/* 0x5 */
	"RESERVED",				/* 0x6 */
	"RESERVED"				/* 0x6 */
};

static char *t194_bpmpnoc_routeid_targflow[] = {
	"multiport0_t/T/actmon",		/* 0x0 */
	"multiport0_t/T/ast_0",			/* 0x1 */
	"multiport0_t/T/ast_1",			/* 0x2 */
	"multiport0_t/T/atcm_cfg",		/* 0x3 */
	"multiport0_t/T/car",			/* 0x4 */
	"multiport0_t/T/central_pwr_mgr",	/* 0x5 */
	"multiport0_t/T/central_vtg_ctlr",	/* 0x6 */
	"multiport0_t/T/cfg",			/* 0x7 */
	"multiport0_t/T/dma",			/* 0x8 */
	"multiport0_t/T/err_collator",		/* 0x9 */
	"multiport0_t/T/err_collator_car",	/* 0xA */
	"multiport0_t/T/fpga_misc",		/* 0xB */
	"multiport0_t/T/fpga_uart",		/* 0xC */
	"multiport0_t/T/gte",			/* 0xD */
	"multiport0_t/T/hsp",			/* 0xE */
	"multiport0_t/T/misc",			/* 0xF */
	"multiport0_t/T/pm",			/* 0x10 */
	"multiport0_t/T/simon0",		/* 0x11 */
	"multiport0_t/T/simon1",		/* 0x12 */
	"multiport0_t/T/simon2",		/* 0x13 */
	"multiport0_t/T/simon3",		/* 0x14 */
	"multiport0_t/T/simon4",		/* 0x15 */
	"multiport0_t/T/soc_therm",		/* 0x16 */
	"multiport0_t/T/tke",			/* 0x17 */
	"multiport0_t/T/vic_0",			/* 0x18 */
	"multiport0_t/T/vic_1",			/* 0x19 */
	"ast0_t/T/0",				/* 0x1A */
	"ast1_t/T/0",				/* 0x1B */
	"bpmp_noc_firewall/T/0",		/* 0x1C */
	"cbb_t/T/0",				/* 0x1D */
	"cpu_t/T/0",				/* 0x1E */
	"svc_t/T/0"				/* 0x1F */
};

/*
 * Fields of BPMP NOC lookup table:
 * Init flow, Targ flow, Targ subrange, Init mapping, Init localAddress,
 *                                              Targ mapping, Targ localAddress
 * ----------------------------------------------------------------------------
 */
static struct tegra_lookup_noc_aperture t194_bpmpnoc_aperture_lookup[] = {
	{ 0x0, 0x1C, 0x0, 0x0, 0xd640000, 0, 0x0000000 },
	{ 0x0, 0x1E, 0x0, 0x0, 0xd400000, 0, 0xd400000 },
	{ 0x0, 0x00, 0x0, 0x0, 0xd230000, 0, 0x0000000 },
	{ 0x0, 0x01, 0x0, 0x0, 0xd040000, 0, 0x0000000 },
	{ 0x0, 0x02, 0x0, 0x0, 0xd050000, 0, 0x0000000 },
	{ 0x0, 0x03, 0x0, 0x0, 0xd000000, 0, 0x0000000 },
	{ 0x0, 0x04, 0x0, 0x0, 0x20ae0000, 3, 0xe0000 },
	{ 0x0, 0x04, 0x1, 0x0, 0x20ac0000, 2, 0xc0000 },
	{ 0x0, 0x04, 0x2, 0x0, 0x20a80000, 1, 0x80000 },
	{ 0x0, 0x04, 0x3, 0x0, 0x20a00000, 0, 0x0000000 },
	{ 0x0, 0x05, 0x0, 0x0, 0xd2a0000, 0, 0x0000000 },
	{ 0x0, 0x06, 0x0, 0x0, 0xd290000, 0, 0x0000000 },
	{ 0x0, 0x07, 0x0, 0x0, 0xd2c0000, 0, 0x0000000 },
	{ 0x0, 0x08, 0x0, 0x0, 0xd0e0000, 4, 0x80000 },
	{ 0x0, 0x08, 0x1, 0x0, 0xd060000, 0, 0x0000000 },
	{ 0x0, 0x08, 0x2, 0x0, 0xd080000, 1, 0x20000 },
	{ 0x0, 0x08, 0x3, 0x0, 0xd0a0000, 2, 0x40000 },
	{ 0x0, 0x08, 0x4, 0x0, 0xd0c0000, 3, 0x60000 },
	{ 0x0, 0x09, 0x0, 0x0, 0xd650000, 0, 0x0000000 },
	{ 0x0, 0x0A, 0x0, 0x0, 0x20af0000, 0, 0x0000000 },
	{ 0x0, 0x0B, 0x0, 0x0, 0xd3e0000, 0, 0x0000000 },
	{ 0x0, 0x0C, 0x0, 0x0, 0xd3d0000, 0, 0x0000000 },
	{ 0x0, 0x0D, 0x0, 0x0, 0xd1e0000, 0, 0x0000000 },
	{ 0x0, 0x0E, 0x0, 0x0, 0xd150000, 0, 0x0000000 },
	{ 0x0, 0x0E, 0x1, 0x0, 0xd160000, 1, 0x10000 },
	{ 0x0, 0x0E, 0x2, 0x0, 0xd170000, 2, 0x20000 },
	{ 0x0, 0x0E, 0x3, 0x0, 0xd180000, 3, 0x30000 },
	{ 0x0, 0x0E, 0x4, 0x0, 0xd190000, 4, 0x40000 },
	{ 0x0, 0x0E, 0x5, 0x0, 0xd1a0000, 5, 0x50000 },
	{ 0x0, 0x0E, 0x6, 0x0, 0xd1b0000, 6, 0x60000 },
	{ 0x0, 0x0E, 0x7, 0x0, 0xd1c0000, 7, 0x70000 },
	{ 0x0, 0x0E, 0x8, 0x0, 0xd1d0000, 8, 0x80000 },
	{ 0x0, 0x0F, 0x0, 0x0, 0xd660000, 0, 0x0000000 },
	{ 0x0, 0x10, 0x0, 0x0, 0xd1f0000, 0, 0x0000000 },
	{ 0x0, 0x10, 0x1, 0x0, 0xd200000, 1, 0x10000 },
	{ 0x0, 0x10, 0x2, 0x0, 0xd210000, 2, 0x20000 },
	{ 0x0, 0x10, 0x3, 0x0, 0xd220000, 3, 0x30000 },
	{ 0x0, 0x11, 0x0, 0x0, 0xd240000, 0, 0x0000000 },
	{ 0x0, 0x12, 0x0, 0x0, 0xd250000, 0, 0x0000000 },
	{ 0x0, 0x13, 0x0, 0x0, 0xd260000, 0, 0x0000000 },
	{ 0x0, 0x14, 0x0, 0x0, 0xd270000, 0, 0x0000000 },
	{ 0x0, 0x15, 0x0, 0x0, 0xd2b0000, 0, 0x0000000 },
	{ 0x0, 0x16, 0x0, 0x0, 0xd280000, 0, 0x0000000 },
	{ 0x0, 0x17, 0x0, 0x0, 0xd0f0000, 0, 0x0000000 },
	{ 0x0, 0x17, 0x1, 0x0, 0xd100000, 1, 0x10000 },
	{ 0x0, 0x17, 0x2, 0x0, 0xd110000, 2, 0x20000 },
	{ 0x0, 0x17, 0x3, 0x0, 0xd120000, 3, 0x30000 },
	{ 0x0, 0x17, 0x4, 0x0, 0xd130000, 4, 0x40000 },
	{ 0x0, 0x17, 0x5, 0x0, 0xd140000, 5, 0x50000 },
	{ 0x0, 0x18, 0x0, 0x0, 0xd020000, 0, 0x0000000 },
	{ 0x0, 0x19, 0x0, 0x0, 0xd030000, 0, 0x0000000 },
	{ 0x0, 0x1F, 0x0, 0x0, 0xd600000, 0, 0x0000000 },
	{ 0x0, 0x1F, 0x1, 0x0, 0x0, 0, 0x0000000 },
	{ 0x1, 0x1A, 0x0, 0x0, 0x40000000, 0, 0x40000000 },
	{ 0x1, 0x1A, 0x1, 0x1, 0x80000000, 1, 0x80000000 },
	{ 0x1, 0x1A, 0x2, 0x0, 0x0, 0, 0x0000000 },
	{ 0x2, 0x1C, 0x0, 0x0, 0xd640000, 0, 0x0000000 },
	{ 0x2, 0x1D, 0x0, 0x0, 0x20b00000, 8, 0x20b00000 },
	{ 0x2, 0x1D, 0x1, 0x0, 0x20800000, 7, 0x20800000 },
	{ 0x2, 0x1D, 0x2, 0x0, 0x20c00000, 9, 0x20c00000 },
	{ 0x2, 0x1D, 0x3, 0x0, 0xd800000, 3, 0xd800000 },
	{ 0x2, 0x1D, 0x4, 0x0, 0x20000000, 6, 0x20000000 },
	{ 0x2, 0x1D, 0x5, 0x0, 0xc000000, 2, 0xc000000 },
	{ 0x2, 0x1D, 0x6, 0x0, 0x21000000, 10, 0x21000000 },
	{ 0x2, 0x1D, 0x7, 0x0, 0xe000000, 4, 0xe000000 },
	{ 0x2, 0x1D, 0x8, 0x0, 0x22000000, 11, 0x22000000 },
	{ 0x2, 0x1D, 0x9, 0x0, 0x8000000, 1, 0x8000000 },
	{ 0x2, 0x1D, 0xa, 0x0, 0x24000000, 12, 0x24000000 },
	{ 0x2, 0x1D, 0xb, 0x0, 0x0, 0, 0x0000000 },
	{ 0x2, 0x1D, 0xc, 0x0, 0x28000000, 13, 0x28000000 },
	{ 0x2, 0x1D, 0xd, 0x0, 0x10000000, 5, 0x10000000 },
	{ 0x2, 0x1D, 0xe, 0x0, 0x30000000, 14, 0x30000000 },
	{ 0x2, 0x00, 0x0, 0x0, 0xd230000, 0, 0x0000000 },
	{ 0x2, 0x01, 0x0, 0x0, 0xd040000, 0, 0x0000000 },
	{ 0x2, 0x02, 0x0, 0x0, 0xd050000, 0, 0x0000000 },
	{ 0x2, 0x03, 0x0, 0x0, 0xd000000, 0, 0x0000000 },
	{ 0x2, 0x04, 0x0, 0x0, 0x20ae0000, 3, 0xe0000 },
	{ 0x2, 0x04, 0x1, 0x0, 0x20ac0000, 2, 0xc0000 },
	{ 0x2, 0x04, 0x2, 0x0, 0x20a80000, 1, 0x80000 },
	{ 0x2, 0x04, 0x3, 0x0, 0x20a00000, 0, 0x0000000 },
	{ 0x2, 0x05, 0x0, 0x0, 0xd2a0000, 0, 0x0000000 },
	{ 0x2, 0x06, 0x0, 0x0, 0xd290000, 0, 0x0000000 },
	{ 0x2, 0x07, 0x0, 0x0, 0xd2c0000, 0, 0x0000000 },
	{ 0x2, 0x08, 0x0, 0x0, 0xd0e0000, 4, 0x80000 },
	{ 0x2, 0x08, 0x1, 0x0, 0xd060000, 0, 0x0000000 },
	{ 0x2, 0x08, 0x2, 0x0, 0xd080000, 1, 0x20000 },
	{ 0x2, 0x08, 0x3, 0x0, 0xd0a0000, 2, 0x40000 },
	{ 0x2, 0x08, 0x4, 0x0, 0xd0c0000, 3, 0x60000 },
	{ 0x2, 0x09, 0x0, 0x0, 0xd650000, 0, 0x0000000 },
	{ 0x2, 0x0A, 0x0, 0x0, 0x20af0000, 0, 0x0000000 },
	{ 0x2, 0x0B, 0x0, 0x0, 0xd3e0000, 0, 0x0000000 },
	{ 0x2, 0x0C, 0x0, 0x0, 0xd3d0000, 0, 0x0000000 },
	{ 0x2, 0x0D, 0x0, 0x0, 0xd1e0000, 0, 0x0000000 },
	{ 0x2, 0x0E, 0x0, 0x0, 0xd150000, 0, 0x0000000 },
	{ 0x2, 0x0E, 0x1, 0x0, 0xd160000, 1, 0x10000 },
	{ 0x2, 0x0E, 0x2, 0x0, 0xd170000, 2, 0x20000 },
	{ 0x2, 0x0E, 0x3, 0x0, 0xd180000, 3, 0x30000 },
	{ 0x2, 0x0E, 0x4, 0x0, 0xd190000, 4, 0x40000 },
	{ 0x2, 0x0E, 0x5, 0x0, 0xd1a0000, 5, 0x50000 },
	{ 0x2, 0x0E, 0x6, 0x0, 0xd1b0000, 6, 0x60000 },
	{ 0x2, 0x0E, 0x7, 0x0, 0xd1c0000, 7, 0x70000 },
	{ 0x2, 0x0E, 0x8, 0x0, 0xd1d0000, 8, 0x80000 },
	{ 0x2, 0x0F, 0x0, 0x0, 0xd660000, 0, 0x0000000 },
	{ 0x2, 0x10, 0x0, 0x0, 0xd1f0000, 0, 0x0000000 },
	{ 0x2, 0x10, 0x1, 0x0, 0xd200000, 1, 0x10000 },
	{ 0x2, 0x10, 0x2, 0x0, 0xd210000, 2, 0x20000 },
	{ 0x2, 0x10, 0x3, 0x0, 0xd220000, 3, 0x30000 },
	{ 0x2, 0x11, 0x0, 0x0, 0xd240000, 0, 0x0000000 },
	{ 0x2, 0x12, 0x0, 0x0, 0xd250000, 0, 0x0000000 },
	{ 0x2, 0x13, 0x0, 0x0, 0xd260000, 0, 0x0000000 },
	{ 0x2, 0x14, 0x0, 0x0, 0xd270000, 0, 0x0000000 },
	{ 0x2, 0x15, 0x0, 0x0, 0xd2b0000, 0, 0x0000000 },
	{ 0x2, 0x16, 0x0, 0x0, 0xd280000, 0, 0x0000000 },
	{ 0x2, 0x17, 0x0, 0x0, 0xd0f0000, 0, 0x0000000 },
	{ 0x2, 0x17, 0x1, 0x0, 0xd100000, 1, 0x10000 },
	{ 0x2, 0x17, 0x2, 0x0, 0xd110000, 2, 0x20000 },
	{ 0x2, 0x17, 0x3, 0x0, 0xd120000, 3, 0x30000 },
	{ 0x2, 0x17, 0x4, 0x0, 0xd130000, 4, 0x40000 },
	{ 0x2, 0x17, 0x5, 0x0, 0xd140000, 5, 0x50000 },
	{ 0x2, 0x18, 0x0, 0x0, 0xd020000, 0, 0x0000000 },
	{ 0x2, 0x19, 0x0, 0x0, 0xd030000, 0, 0x0000000 },
	{ 0x2, 0x1F, 0x0, 0x0, 0xd600000, 0, 0x0000000 },
	{ 0x2, 0x1F, 0x1, 0x0, 0x0, 0, 0x0000000 },
	{ 0x3, 0x1B, 0x0, 0x0, 0x40000000, 0, 0x40000000 },
	{ 0x3, 0x1B, 0x1, 0x1, 0x80000000, 1, 0x80000000 },
	{ 0x3, 0x1C, 0x0, 0x2, 0xd640000, 0, 0x0000000 },
	{ 0x3, 0x1D, 0x0, 0x2, 0x20b00000, 8, 0x20b00000 },
	{ 0x3, 0x1D, 0x1, 0x2, 0x20800000, 7, 0x20800000 },
	{ 0x3, 0x1D, 0x2, 0x2, 0x20c00000, 9, 0x20c00000 },
	{ 0x3, 0x1D, 0x3, 0x2, 0xd800000, 3, 0xd800000 },
	{ 0x3, 0x1D, 0x4, 0x2, 0x20000000, 6, 0x20000000 },
	{ 0x3, 0x1D, 0x5, 0x2, 0xc000000, 2, 0xc000000 },
	{ 0x3, 0x1D, 0x6, 0x2, 0x21000000, 10, 0x21000000 },
	{ 0x3, 0x1D, 0x7, 0x2, 0xe000000, 4, 0xe000000 },
	{ 0x3, 0x1D, 0x8, 0x2, 0x22000000, 11, 0x22000000 },
	{ 0x3, 0x1D, 0x9, 0x2, 0x8000000, 1, 0x8000000 },
	{ 0x3, 0x1D, 0xa, 0x2, 0x24000000, 12, 0x24000000 },
	{ 0x3, 0x1D, 0xb, 0x2, 0x0, 0, 0x0000000 },
	{ 0x3, 0x1D, 0xc, 0x2, 0x28000000, 13, 0x28000000 },
	{ 0x3, 0x1D, 0xd, 0x2, 0x10000000, 5, 0x10000000 },
	{ 0x3, 0x1D, 0xe, 0x2, 0x30000000, 14, 0x30000000 },
	{ 0x3, 0x1E, 0x0, 0x2, 0xd400000, 0, 0xd400000 },
	{ 0x3, 0x00, 0x0, 0x2, 0xd230000, 0, 0x0000000 },
	{ 0x3, 0x01, 0x0, 0x2, 0xd040000, 0, 0x0000000 },
	{ 0x3, 0x02, 0x0, 0x2, 0xd050000, 0, 0x0000000 },
	{ 0x3, 0x03, 0x0, 0x2, 0xd000000, 0, 0x0000000 },
	{ 0x3, 0x04, 0x0, 0x2, 0x20ae0000, 3, 0xe0000 },
	{ 0x3, 0x04, 0x1, 0x2, 0x20ac0000, 2, 0xc0000 },
	{ 0x3, 0x04, 0x2, 0x2, 0x20a80000, 1, 0x80000 },
	{ 0x3, 0x04, 0x3, 0x2, 0x20a00000, 0, 0x0000000 },
	{ 0x3, 0x05, 0x0, 0x2, 0xd2a0000, 0, 0x0000000 },
	{ 0x3, 0x06, 0x0, 0x2, 0xd290000, 0, 0x0000000 },
	{ 0x3, 0x07, 0x0, 0x2, 0xd2c0000, 0, 0x0000000 },
	{ 0x3, 0x08, 0x0, 0x2, 0xd0e0000, 4, 0x80000 },
	{ 0x3, 0x08, 0x1, 0x2, 0xd060000, 0, 0x0000000 },
	{ 0x3, 0x08, 0x2, 0x2, 0xd080000, 1, 0x20000 },
	{ 0x3, 0x08, 0x3, 0x2, 0xd0a0000, 2, 0x40000 },
	{ 0x3, 0x08, 0x4, 0x2, 0xd0c0000, 3, 0x60000 },
	{ 0x3, 0x09, 0x0, 0x2, 0xd650000, 0, 0x0000000 },
	{ 0x3, 0x0A, 0x0, 0x2, 0x20af0000, 0, 0x0000000 },
	{ 0x3, 0x0B, 0x0, 0x2, 0xd3e0000, 0, 0x0000000 },
	{ 0x3, 0x0C, 0x0, 0x2, 0xd3d0000, 0, 0x0000000 },
	{ 0x3, 0x0D, 0x0, 0x2, 0xd1e0000, 0, 0x0000000 },
	{ 0x3, 0x0E, 0x0, 0x2, 0xd150000, 0, 0x0000000 },
	{ 0x3, 0x0E, 0x1, 0x2, 0xd160000, 1, 0x10000 },
	{ 0x3, 0x0E, 0x2, 0x2, 0xd170000, 2, 0x20000 },
	{ 0x3, 0x0E, 0x3, 0x2, 0xd180000, 3, 0x30000 },
	{ 0x3, 0x0E, 0x4, 0x2, 0xd190000, 4, 0x40000 },
	{ 0x3, 0x0E, 0x5, 0x2, 0xd1a0000, 5, 0x50000 },
	{ 0x3, 0x0E, 0x6, 0x2, 0xd1b0000, 6, 0x60000 },
	{ 0x3, 0x0E, 0x7, 0x2, 0xd1c0000, 7, 0x70000 },
	{ 0x3, 0x0E, 0x8, 0x2, 0xd1d0000, 8, 0x80000 },
	{ 0x3, 0x0F, 0x0, 0x2, 0xd660000, 0, 0x0000000 },
	{ 0x3, 0x10, 0x0, 0x2, 0xd1f0000, 0, 0x0000000 },
	{ 0x3, 0x10, 0x1, 0x2, 0xd200000, 1, 0x10000 },
	{ 0x3, 0x10, 0x2, 0x2, 0xd210000, 2, 0x20000 },
	{ 0x3, 0x10, 0x3, 0x2, 0xd220000, 3, 0x30000 },
	{ 0x3, 0x11, 0x0, 0x2, 0xd240000, 0, 0x0000000 },
	{ 0x3, 0x12, 0x0, 0x2, 0xd250000, 0, 0x0000000 },
	{ 0x3, 0x13, 0x0, 0x2, 0xd260000, 0, 0x0000000 },
	{ 0x3, 0x14, 0x0, 0x2, 0xd270000, 0, 0x0000000 },
	{ 0x3, 0x15, 0x0, 0x2, 0xd2b0000, 0, 0x0000000 },
	{ 0x3, 0x16, 0x0, 0x2, 0xd280000, 0, 0x0000000 },
	{ 0x3, 0x17, 0x0, 0x2, 0xd0f0000, 0, 0x0000000 },
	{ 0x3, 0x17, 0x1, 0x2, 0xd100000, 1, 0x10000 },
	{ 0x3, 0x17, 0x2, 0x2, 0xd110000, 2, 0x20000 },
	{ 0x3, 0x17, 0x3, 0x2, 0xd120000, 3, 0x30000 },
	{ 0x3, 0x17, 0x4, 0x2, 0xd130000, 4, 0x40000 },
	{ 0x3, 0x17, 0x5, 0x2, 0xd140000, 5, 0x50000 },
	{ 0x3, 0x18, 0x0, 0x2, 0xd020000, 0, 0x0000000 },
	{ 0x3, 0x19, 0x0, 0x2, 0xd030000, 0, 0x0000000 },
	{ 0x3, 0x1F, 0x0, 0x2, 0xd600000, 0, 0x0000000 },
	{ 0x3, 0x1F, 0x1, 0x0, 0x0, 0, 0x0000000 },
	{ 0x4, 0x1B, 0x0, 0x0, 0x40000000, 0, 0x40000000 },
	{ 0x4, 0x1B, 0x1, 0x1, 0x80000000, 1, 0x80000000 },
	{ 0x4, 0x1E, 0x0, 0x2, 0xd400000, 0, 0xd400000 },
	{ 0x4, 0x1E, 0x1, 0x0, 0x0, 0, 0x0000000 },
	{ 0x5, 0x1C, 0x0, 0x0, 0xd640000, 0, 0x0000000 },
	{ 0x5, 0x1D, 0x0, 0x0, 0x20b00000, 8, 0x20b00000 },
	{ 0x5, 0x1D, 0x1, 0x0, 0x20800000, 7, 0x20800000 },
	{ 0x5, 0x1D, 0x2, 0x0, 0x20c00000, 9, 0x20c00000 },
	{ 0x5, 0x1D, 0x3, 0x0, 0xd800000, 3, 0xd800000 },
	{ 0x5, 0x1D, 0x4, 0x0, 0x20000000, 6, 0x20000000 },
	{ 0x5, 0x1D, 0x5, 0x0, 0xc000000, 2, 0xc000000 },
	{ 0x5, 0x1D, 0x6, 0x0, 0x21000000, 10, 0x21000000 },
	{ 0x5, 0x1D, 0x7, 0x0, 0xe000000, 4, 0xe000000 },
	{ 0x5, 0x1D, 0x8, 0x0, 0x22000000, 11, 0x22000000 },
	{ 0x5, 0x1D, 0x9, 0x0, 0x8000000, 1, 0x8000000 },
	{ 0x5, 0x1D, 0xa, 0x0, 0x24000000, 12, 0x24000000 },
	{ 0x5, 0x1D, 0xb, 0x0, 0x0, 0, 0x0000000 },
	{ 0x5, 0x1D, 0xc, 0x0, 0x28000000, 13, 0x28000000 },
	{ 0x5, 0x1D, 0xd, 0x0, 0x10000000, 5, 0x10000000 },
	{ 0x5, 0x1D, 0xe, 0x0, 0x30000000, 14, 0x30000000 },
	{ 0x5, 0x00, 0x0, 0x0, 0xd230000, 0, 0x0000000 },
	{ 0x5, 0x01, 0x0, 0x0, 0xd040000, 0, 0x0000000 },
	{ 0x5, 0x02, 0x0, 0x0, 0xd050000, 0, 0x0000000 },
	{ 0x5, 0x03, 0x0, 0x0, 0xd000000, 0, 0x0000000 },
	{ 0x5, 0x04, 0x0, 0x0, 0x20ae0000, 3, 0xe0000 },
	{ 0x5, 0x04, 0x1, 0x0, 0x20ac0000, 2, 0xc0000 },
	{ 0x5, 0x04, 0x2, 0x0, 0x20a80000, 1, 0x80000 },
	{ 0x5, 0x04, 0x3, 0x0, 0x20a00000, 0, 0x0000000 },
	{ 0x5, 0x05, 0x0, 0x0, 0xd2a0000, 0, 0x0000000 },
	{ 0x5, 0x06, 0x0, 0x0, 0xd290000, 0, 0x0000000 },
	{ 0x5, 0x07, 0x0, 0x0, 0xd2c0000, 0, 0x0000000 },
	{ 0x5, 0x08, 0x0, 0x0, 0xd0e0000, 4, 0x80000 },
	{ 0x5, 0x08, 0x1, 0x0, 0xd060000, 0, 0x0000000 },
	{ 0x5, 0x08, 0x2, 0x0, 0xd080000, 1, 0x20000 },
	{ 0x5, 0x08, 0x3, 0x0, 0xd0a0000, 2, 0x40000 },
	{ 0x5, 0x08, 0x4, 0x0, 0xd0c0000, 3, 0x60000 },
	{ 0x5, 0x09, 0x0, 0x0, 0xd650000, 0, 0x0000000 },
	{ 0x5, 0x0A, 0x0, 0x0, 0x20af0000, 0, 0x0000000 },
	{ 0x5, 0x0B, 0x0, 0x0, 0xd3e0000, 0, 0x0000000 },
	{ 0x5, 0x0C, 0x0, 0x0, 0xd3d0000, 0, 0x0000000 },
	{ 0x5, 0x0D, 0x0, 0x0, 0xd1e0000, 0, 0x0000000 },
	{ 0x5, 0x0E, 0x0, 0x0, 0xd150000, 0, 0x0000000 },
	{ 0x5, 0x0E, 0x1, 0x0, 0xd160000, 1, 0x10000 },
	{ 0x5, 0x0E, 0x2, 0x0, 0xd170000, 2, 0x20000 },
	{ 0x5, 0x0E, 0x3, 0x0, 0xd180000, 3, 0x30000 },
	{ 0x5, 0x0E, 0x4, 0x0, 0xd190000, 4, 0x40000 },
	{ 0x5, 0x0E, 0x5, 0x0, 0xd1a0000, 5, 0x50000 },
	{ 0x5, 0x0E, 0x6, 0x0, 0xd1b0000, 6, 0x60000 },
	{ 0x5, 0x0E, 0x7, 0x0, 0xd1c0000, 7, 0x70000 },
	{ 0x5, 0x0E, 0x8, 0x0, 0xd1d0000, 8, 0x80000 },
	{ 0x5, 0x0F, 0x0, 0x0, 0xd660000, 0, 0x0000000 },
	{ 0x5, 0x10, 0x0, 0x0, 0xd1f0000, 0, 0x0000000 },
	{ 0x5, 0x10, 0x1, 0x0, 0xd200000, 1, 0x10000 },
	{ 0x5, 0x10, 0x2, 0x0, 0xd210000, 2, 0x20000 },
	{ 0x5, 0x10, 0x3, 0x0, 0xd220000, 3, 0x30000 },
	{ 0x5, 0x11, 0x0, 0x0, 0xd240000, 0, 0x0000000 },
	{ 0x5, 0x12, 0x0, 0x0, 0xd250000, 0, 0x0000000 },
	{ 0x5, 0x13, 0x0, 0x0, 0xd260000, 0, 0x0000000 },
	{ 0x5, 0x14, 0x0, 0x0, 0xd270000, 0, 0x0000000 },
	{ 0x5, 0x15, 0x0, 0x0, 0xd2b0000, 0, 0x0000000 },
	{ 0x5, 0x16, 0x0, 0x0, 0xd280000, 0, 0x0000000 },
	{ 0x5, 0x17, 0x0, 0x0, 0xd0f0000, 0, 0x0000000 },
	{ 0x5, 0x17, 0x1, 0x0, 0xd100000, 1, 0x10000 },
	{ 0x5, 0x17, 0x2, 0x0, 0xd110000, 2, 0x20000 },
	{ 0x5, 0x17, 0x3, 0x0, 0xd120000, 3, 0x30000 },
	{ 0x5, 0x17, 0x4, 0x0, 0xd130000, 4, 0x40000 },
	{ 0x5, 0x17, 0x5, 0x0, 0xd140000, 5, 0x50000 },
	{ 0x5, 0x18, 0x0, 0x0, 0xd020000, 0, 0x0000000 },
	{ 0x5, 0x19, 0x0, 0x0, 0xd030000, 0, 0x0000000 },
	{ 0x5, 0x1F, 0x0, 0x0, 0xd600000, 0, 0x0000000 },
	{ 0x5, 0x1F, 0x1, 0x0, 0x0, 0, 0x0000000 }
};


/*
 * AON NOC aperture lookup table as per file "AON_NOC_Structure.info".
 */
static char *t194_aonnoc_routeid_initflow[] = {
	"cbb_i/I/0",				/* 0x0 */
	"cpu_p_i/I/0",                          /* 0x1 */
	"dma_m_i/I/0",                          /* 0x2 */
	"dma_p_i/I/0"                           /* 0x3 */
};

static char *t194_aonnoc_routeid_targflow[] = {
	"multiport1_t/T/aon_misc",			 /* 0  */
	"multiport1_t/T/avic0",                          /* 1  */
	"multiport1_t/T/avic1",                          /* 2  */
	"multiport1_t/T/can1",                           /* 3  */
	"multiport1_t/T/can2",                           /* 4  */
	"multiport1_t/T/dma",                            /* 5  */
	"multiport1_t/T/dmic",                           /* 6  */
	"multiport1_t/T/err_collator",                   /* 7  */
	"multiport1_t/T/fpga_misc",                      /* 8  */
	"multiport1_t/T/gte",                            /* 9  */
	"multiport1_t/T/hsp",                            /* A  */
	"multiport1_t/T/i2c2",                           /* B  */
	"multiport1_t/T/i2c8",                           /* C  */
	"multiport1_t/T/pwm",                            /* D  */
	"multiport1_t/T/spi2",                           /* E  */
	"multiport1_t/T/tke",                            /* F  */
	"multiport1_t/T/uartg",                          /* 10 */
	"RESERVED",	                                 /* 11 */
	"RESERVED",                                      /* 12 */
	"RESERVED",                                      /* 13 */
	"RESERVED",                                      /* 14 */
	"RESERVED",                                      /* 15 */
	"RESERVED",                                      /* 16 */
	"RESERVED",                                      /* 17 */
	"RESERVED",                                      /* 18 */
	"RESERVED",                                      /* 19 */
	"RESERVED",                                      /* 1A */
	"RESERVED",                                      /* 1B */
	"RESERVED",                                      /* 1C */
	"RESERVED",                                      /* 1D */
	"RESERVED",                                      /* 1E */
	"RESERVED",                                      /* 1F */
	"multiport0_t/T/aovc",                           /* 20 */
	"multiport0_t/T/atcm",                           /* 21 */
	"multiport0_t/T/cast",                           /* 22 */
	"multiport0_t/T/dast",                           /* 23 */
	"multiport0_t/T/err_collator_car",               /* 24 */
	"multiport0_t/T/gpio",                           /* 25 */
	"multiport0_t/T/i2c10",                          /* 26 */
	"multiport0_t/T/mss",                            /* 27 */
	"multiport0_t/T/padctl_a12",                     /* 28 */
	"multiport0_t/T/padctl_a14",                     /* 29 */
	"multiport0_t/T/padctl_a15",                     /* 2A */
	"multiport0_t/T/rtc",                            /* 2B */
	"multiport0_t/T/tsc",                            /* 2C */
	"RESERVED",                                      /* 2D */
	"RESERVED",                                      /* 2E */
	"RESERVED",                                      /* 2F */
	"multiport2_t/T/aon_vref_ro",                    /* 30 */
	"multiport2_t/T/aopm",                           /* 31 */
	"multiport2_t/T/car",                            /* 32 */
	"multiport2_t/T/pmc",                            /* 33 */
	"ast1_t/T/0",                                    /* 34 */
	"cbb_t/T/0",                                     /* 35 */
	"cpu_t/T/0",                                     /* 36 */
	"firewall_t/T/0",                                /* 37 */
	"svc_t/T/0",                                     /* 38 */
	"uartc/T/uartc",                                 /* 39 */
	"RESERVED",                                      /* 3A */
	"RESERVED",                                      /* 3B */
	"RESERVED",                                      /* 3C */
	"RESERVED",                                      /* 3D */
	"RESERVED",                                      /* 3E */
	"RESERVED"                                       /* 3F */
};


/*
 * Fields of AON NOC lookup table:
 * Init flow, Targ flow, Targ subrange, Init mapping, Init localAddress,
 *                                              Targ mapping, Targ localAddress
 * ----------------------------------------------------------------------------
 */
static struct tegra_lookup_noc_aperture t194_aonnoc_aperture_lookup[] = {
	{ 0x0, 0x37, 0x0,  0,	0xc640000,    0, 0x0 },
	{ 0x0, 0x20, 0x0,  0,	0xc3b0000,    0, 0x0 },
	{ 0x0, 0x21, 0x0,  0,	0xc000000,    0, 0x0 },
	{ 0x0, 0x22, 0x0,  0,	0xc040000,    0, 0x0 },
	{ 0x0, 0x23, 0x0,  0,	0xc050000,    0, 0x0 },
	{ 0x0, 0x24, 0x0,  0,	0x20cf0000,   0, 0x0 },
	{ 0x0, 0x25, 0x0,  0,	0xc2f0000,    0, 0x0 },
	{ 0x0, 0x26, 0x0,  0,	0xc230000,    0, 0x0 },
	{ 0x0, 0x27, 0x0,  0,	0xc350000,    0, 0x0 },
	{ 0x0, 0x28, 0x0,  0,	0xc301000,    0, 0x0 },
	{ 0x0, 0x29, 0x0,  0,	0xc302000,    0, 0x0 },
	{ 0x0, 0x2A, 0x0,  0,	0xc303000,    0, 0x0 },
	{ 0x0, 0x2B, 0x0,  0,	0xc2a0000,    0, 0x0 },
	{ 0x0, 0x2C, 0x0,  0,	0xc2b0000,    0, 0x0 },
	{ 0x0, 0x2C, 0x1,  0,	0xc2c0000,    1, 0x10000 },
	{ 0x0, 0x2C, 0x2,  0,	0xc2d0000,    2, 0x20000 },
	{ 0x0, 0x2C, 0x3,  0,	0xc2e0000,    3, 0x30000 },
	{ 0x0, 0x0,  0x0,  0,	0xc660000,    0, 0x0 },
	{ 0x0, 0x1,  0x0,  0,	0xc020000,    0, 0x0 },
	{ 0x0, 0x2,  0x0,  0,	0xc030000,    0, 0x0 },
	{ 0x0, 0x3,  0x0,  0,	0xc310000,    0, 0x0 },
	{ 0x0, 0x4,  0x0,  0,	0xc320000,    0, 0x0 },
	{ 0x0, 0x5,  0x0,  0,	0xc0a0000,    2, 0x40000 },
	{ 0x0, 0x5,  0x1,  0,	0xc0b0000,    3, 0x50000 },
	{ 0x0, 0x5,  0x2,  0,	0xc0e0000,    5, 0x80000 },
	{ 0x0, 0x5,  0x3,  0,	0xc060000,    0, 0x0 },
	{ 0x0, 0x5,  0x4,  0,	0xc080000,    1, 0x20000 },
	{ 0x0, 0x5,  0x5,  0,	0xc0c0000,    4, 0x60000 },
	{ 0x0, 0x6,  0x0,  0,	0xc330000,    0, 0x0 },
	{ 0x0, 0x7,  0x0,  0,	0xc650000,    0, 0x0 },
	{ 0x0, 0x8,  0x0,  0,	0xc3e0000,    0, 0x0 },
	{ 0x0, 0x9,  0x0,  0,	0xc1e0000,    0, 0x0 },
	{ 0x0, 0xA,  0x0,  0,	0xc150000,    0, 0x0 },
	{ 0x0, 0xA,  0x1,  0,	0xc160000,    1, 0x10000 },
	{ 0x0, 0xA,  0x2,  0,	0xc170000,    2, 0x20000 },
	{ 0x0, 0xA,  0x3,  0,	0xc180000,    3, 0x30000 },
	{ 0x0, 0xA,  0x4,  0,	0xc190000,    4, 0x40000 },
	{ 0x0, 0xA,  0x5,  0,	0xc1a0000,    5, 0x50000 },
	{ 0x0, 0xA,  0x6,  0,	0xc1b0000,    6, 0x60000 },
	{ 0x0, 0xA,  0x7,  0,	0xc1c0000,    7, 0x70000 },
	{ 0x0, 0xA,  0x8,  0,	0xc1d0000,    8, 0x80000 },
	{ 0x0, 0xB,  0x0,  0,	0xc240000,    0, 0x0 },
	{ 0x0, 0xC,  0x0,  0,	0xc250000,    0, 0x0 },
	{ 0x0, 0xD,  0x0,  0,	0xc340000,    0, 0x0 },
	{ 0x0, 0xE,  0x0,  0,	0xc260000,    0, 0x0 },
	{ 0x0, 0xF,  0x0,  0,	0xc0f0000,    0, 0x0 },
	{ 0x0, 0xF,  0x1,  0,	0xc100000,    1, 0x10000 },
	{ 0x0, 0xF,  0x2,  0,	0xc110000,    2, 0x20000 },
	{ 0x0, 0xF,  0x3,  0,	0xc120000,    3, 0x30000 },
	{ 0x0, 0xF,  0x4,  0,	0xc130000,    4, 0x40000 },
	{ 0x0, 0xF,  0x5,  0,	0xc140000,    5, 0x50000 },
	{ 0x0, 0x10, 0x0,  0,	0xc290000,    0, 0x0 },
	{ 0x0, 0x30, 0x0,  0,	0x20ce0000,   0, 0x0 },
	{ 0x0, 0x31, 0x0,  0,	0xc1f0000,    0, 0x0 },
	{ 0x0, 0x31, 0x1,  0,	0xc200000,    1, 0x10000 },
	{ 0x0, 0x31, 0x2,  0,	0xc210000,    2, 0x20000 },
	{ 0x0, 0x31, 0x3,  0,	0xc220000,    3, 0x30000 },
	{ 0x0, 0x32, 0x0,  0,	0x20cc0000,   3, 0x1c0000 },
	{ 0x0, 0x32, 0x1,  0,	0x20c80000,   2, 0x180000 },
	{ 0x0, 0x32, 0x2,  0,	0x20c00000,   1, 0x100000 },
	{ 0x0, 0x32, 0x3,  0,	0x20b00000,   0, 0x0 },
	{ 0x0, 0x33, 0x0,  0,	0xc360000,    0, 0x0 },
	{ 0x0, 0x33, 0x1,  0,	0xc370000,    1, 0x10000 },
	{ 0x0, 0x33, 0x2,  0,	0xc3a0000,    3, 0x40000 },
	{ 0x0, 0x33, 0x3,  0,	0xc380000,    2, 0x20000 },
	{ 0x0, 0x38, 0x0,  0,	0xc600000,    0, 0x0 },
	{ 0x0, 0x38, 0x1,  0,	0x0000000,    0, 0x0,  },
	{ 0x0, 0x39, 0x0,  0,	0xc280000,    0, 0x0 },
	{ 0x1, 0x35, 0x0,  0,	0x0000000,    0, 0x0,  },
	{ 0x1, 0x35, 0x1,  0,	0x100000,     1, 0x100000 },
	{ 0x1, 0x35, 0x2,  0,	0x5a00000,    11, 0x5a00000 },
	{ 0x1, 0x35, 0x3,  0,	0x5b00000,    32, 0x5b00000 },
	{ 0x1, 0x35, 0x4,  0,	0x5c00000,    33, 0x5c00000 },
	{ 0x1, 0x35, 0x5,  0,	0x5d00000,    12, 0x5d00000 },
	{ 0x1, 0x35, 0x6,  0,	0x20000000,   19, 0x20000000 },
	{ 0x1, 0x35, 0x7,  0,	0x20100000,   20, 0x20100000 },
	{ 0x1, 0x35, 0x8,  0,	0x20a00000,   24, 0x20a00000 },
	{ 0x1, 0x35, 0x9,  0,	0x20d00000,   25, 0x20d00000 },
	{ 0x1, 0x35, 0xa,  0,	0x200000,     2, 0x200000 },
	{ 0x1, 0x35, 0xb,  0,	0x5800000,    10, 0x5800000 },
	{ 0x1, 0x35, 0xc,  0,	0x5e00000,    13, 0x5e00000 },
	{ 0x1, 0x35, 0xd,  0,	0x20200000,   21, 0x20200000 },
	{ 0x1, 0x35, 0xe,  0,	0x20800000,   23, 0x20800000 },
	{ 0x1, 0x35, 0xf,  0,	0x20e00000,   26, 0x20e00000 },
	{ 0x1, 0x35, 0x10, 0,	0x400000,     3, 0x400000 },
	{ 0x1, 0x35, 0x11, 0,	0x20400000,   22, 0x20400000 },
	{ 0x1, 0x35, 0x12, 0,	0x800000,  4,  0x800000 },
	{ 0x1, 0x35, 0x13, 0,	0x5000000,  9,  0x5000000 },
	{ 0x1, 0x35, 0x14, 0,	0xc800000,  34, 0xc800000 },
	{ 0x1, 0x35, 0x15, 0,	0x1000000,  5,  0x1000000 },
	{ 0x1, 0x35, 0x16, 0,	0x3000000,  7,  0x3000000 },
	{ 0x1, 0x35, 0x17, 0,	0x4000000,  8,  0x4000000 },
	{ 0x1, 0x35, 0x18, 0,	0xd000000,  16, 0xd000000 },
	{ 0x1, 0x35, 0x19, 0,	0x21000000,  27, 0x21000000 },
	{ 0x1, 0x35, 0x1a, 0,	0x2000000,  6,  0x2000000 },
	{ 0x1, 0x35, 0x1b, 0,	0x6000000,  14, 0x6000000 },
	{ 0x1, 0x35, 0x1c, 0,	0xe000000,  17, 0xe000000 },
	{ 0x1, 0x35, 0x1d, 0,	0x22000000,  28, 0x22000000 },
	{ 0x1, 0x35, 0x1e, 0,	0x8000000,  15, 0x8000000 },
	{ 0x1, 0x35, 0x1f, 0,	0x24000000,  29, 0x24000000 },
	{ 0x1, 0x35, 0x20, 0,	0x28000000,  30, 0x28000000 },
	{ 0x1, 0x35, 0x21, 0,	0x10000000,  18, 0x10000000 },
	{ 0x1, 0x35, 0x22, 0,	0x30000000,  31, 0x30000000 },
	{ 0x1, 0x37, 0x0,  0,	0xc640000,  0,  0x0 },
	{ 0x1, 0x20, 0x0,  0,	0xc3b0000,  0,  0x0 },
	{ 0x1, 0x21, 0x0,  0,	0xc000000,  0,  0x0 },
	{ 0x1, 0x22, 0x0,  0,	0xc040000,  0,  0x0 },
	{ 0x1, 0x23, 0x0,  0,	0xc050000,  0,  0x0 },
	{ 0x1, 0x24, 0x0,  0,	0x20cf0000,  0,  0x0 },
	{ 0x1, 0x25, 0x0,  0,	0xc2f0000,  0,  0x0 },
	{ 0x1, 0x26, 0x0,  0,	0xc230000,  0,  0x0 },
	{ 0x1, 0x27, 0x0,  0,	0xc350000,  0,  0x0 },
	{ 0x1, 0x28, 0x0,  0,	0xc301000,  0,  0x0 },
	{ 0x1, 0x29, 0x0,  0,	0xc302000,  0,  0x0 },
	{ 0x1, 0x2A, 0x0,  0,	0xc303000,  0,  0x0 },
	{ 0x1, 0x2B, 0x0,  0,	0xc2a0000,  0,  0x0 },
	{ 0x1, 0x2C, 0x0,  0,	0xc2b0000,  0,  0x0 },
	{ 0x1, 0x2C, 0x1,  0,	0xc2c0000,  1,  0x10000 },
	{ 0x1, 0x2C, 0x2,  0,	0xc2d0000,  2,  0x20000 },
	{ 0x1, 0x2C, 0x3,  0,	0xc2e0000,  3,  0x30000 },
	{ 0x1, 0x0,  0x0,  0,	0xc660000,  0,  0x0 },
	{ 0x1, 0x1,  0x0,  0,	0xc020000,  0,  0x0 },
	{ 0x1, 0x2,  0x0,  0,	0xc030000,  0,  0x0 },
	{ 0x1, 0x3,  0x0,  0,	0xc310000,  0,  0x0 },
	{ 0x1, 0x4,  0x0,  0,	0xc320000,  0,  0x0 },
	{ 0x1, 0x5,  0x0,  0,	0xc0a0000,  2,  0x40000 },
	{ 0x1, 0x5,  0x1,  0,	0xc0b0000,  3,  0x50000 },
	{ 0x1, 0x5,  0x2,  0,	0xc0e0000,  5,  0x80000 },
	{ 0x1, 0x5,  0x3,  0,	0xc060000,  0,  0x0 },
	{ 0x1, 0x5,  0x4,  0,	0xc080000,  1,  0x20000 },
	{ 0x1, 0x5,  0x5,  0,	0xc0c0000,  4,  0x60000 },
	{ 0x1, 0x6,  0x0,  0,	0xc330000,  0,  0x0 },
	{ 0x1, 0x7,  0x0,  0,	0xc650000,  0,  0x0 },
	{ 0x1, 0x8,  0x0,  0,	0xc3e0000,  0,  0x0 },
	{ 0x1, 0x9,  0x0,  0,	0xc1e0000,  0,  0x0 },
	{ 0x1, 0xA,  0x0,  0,	0xc150000,  0,  0x0 },
	{ 0x1, 0xA,  0x1,  0,	0xc160000,  1,  0x10000 },
	{ 0x1, 0xA,  0x2,  0,	0xc170000,  2,  0x20000 },
	{ 0x1, 0xA,  0x3,  0,	0xc180000,  3,  0x30000 },
	{ 0x1, 0xA,  0x4,  0,	0xc190000,  4,  0x40000 },
	{ 0x1, 0xA,  0x5,  0,	0xc1a0000,  5,  0x50000 },
	{ 0x1, 0xA,  0x6,  0,	0xc1b0000,  6,  0x60000 },
	{ 0x1, 0xA,  0x7,  0,	0xc1c0000,  7,  0x70000 },
	{ 0x1, 0xA,  0x8,  0,	0xc1d0000,  8,  0x80000 },
	{ 0x1, 0xB,  0x0,  0,	0xc240000,  0,  0x0 },
	{ 0x1, 0xC,  0x0,  0,	0xc250000,  0,  0x0 },
	{ 0x1, 0xD,  0x0,  0,	0xc340000,  0,  0x0 },
	{ 0x1, 0xE,  0x0,  0,	0xc260000,  0,  0x0 },
	{ 0x1, 0xF,  0x0,  0,	0xc0f0000,  0,  0x0 },
	{ 0x1, 0xF,  0x1,  0,	0xc100000,  1,  0x10000 },
	{ 0x1, 0xF,  0x2,  0,	0xc110000,  2,  0x20000 },
	{ 0x1, 0xF,  0x3,  0,	0xc120000,  3,  0x30000 },
	{ 0x1, 0xF,  0x4,  0,	0xc130000,  4,  0x40000 },
	{ 0x1, 0xF,  0x5,  0,	0xc140000,  5,  0x50000 },
	{ 0x1, 0x10, 0x0,  0,	0xc290000,  0,  0x0 },
	{ 0x1, 0x30, 0x0,  0,	0x20ce0000,  0,  0x0 },
	{ 0x1, 0x31, 0x0,  0,	0xc1f0000,  0,  0x0 },
	{ 0x1, 0x31, 0x1,  0,	0xc200000,  1,  0x10000 },
	{ 0x1, 0x31, 0x2,  0,	0xc210000,  2,  0x20000 },
	{ 0x1, 0x31, 0x3,  0,	0xc220000,  3,  0x30000 },
	{ 0x1, 0x32, 0x0,  0,	0x20cc0000,  3,  0x1c0000 },
	{ 0x1, 0x32, 0x1,  0,	0x20c80000,  2,  0x180000 },
	{ 0x1, 0x32, 0x2,  0,	0x20c00000,  1,  0x100000 },
	{ 0x1, 0x32, 0x3,  0,	0x20b00000,  0,  0x0 },
	{ 0x1, 0x33, 0x0,  0,	0xc360000,  0,  0x0 },
	{ 0x1, 0x33, 0x1,  0,	0xc370000,  1,  0x10000 },
	{ 0x1, 0x33, 0x2,  0,	0xc3a0000,  3,  0x40000 },
	{ 0x1, 0x33, 0x3,  0,	0xc380000,  2,  0x20000 },
	{ 0x1, 0x38, 0x0,  0,	0xc600000,  0,  0x0 },
	{ 0x1, 0x38, 0x1,  0,	0x0000000,  0,  0x0,  },
	{ 0x1, 0x39, 0x0,  0,	0xc280000,  0,  0x0 },
	{ 0x2, 0x34, 0x0,  0,	0x40000000,  0,  0x40000000 },
	{ 0x2, 0x34, 0x1,  0,	0x80000000,  1,  0x80000000 },
	{ 0x2, 0x36, 0x0,  0,	0xc400000,  0,  0xc400000 },
	{ 0x2, 0x36, 0x1,  0,	0x0000000,  0,  0x0,  },
	{ 0x3, 0x35, 0x0,  0,	0x0000000,  0,  0x0,  },
	{ 0x3, 0x35, 0x1,  0,	0x100000,  1,  0x100000 },
	{ 0x3, 0x35, 0x2,  0,	0x5a00000,  11, 0x5a00000 },
	{ 0x3, 0x35, 0x3,  0,	0x5b00000,  32, 0x5b00000 },
	{ 0x3, 0x35, 0x4,  0,	0x5c00000,  33, 0x5c00000 },
	{ 0x3, 0x35, 0x5,  0,	0x5d00000,  12, 0x5d00000 },
	{ 0x3, 0x35, 0x6,  0,	0x20000000,  19, 0x20000000 },
	{ 0x3, 0x35, 0x7,  0,	0x20100000,  20, 0x20100000 },
	{ 0x3, 0x35, 0x8,  0,	0x20a00000,  24, 0x20a00000 },
	{ 0x3, 0x35, 0x9,  0,	0x20d00000,  25, 0x20d00000 },
	{ 0x3, 0x35, 0xa,  0,	0x200000,  2,  0x200000 },
	{ 0x3, 0x35, 0xb,  0,	0x5800000,  10, 0x5800000 },
	{ 0x3, 0x35, 0xc,  0,	0x5e00000,  13, 0x5e00000 },
	{ 0x3, 0x35, 0xd,  0,	0x20200000,  21, 0x20200000 },
	{ 0x3, 0x35, 0xe,  0,	0x20800000,  23, 0x20800000 },
	{ 0x3, 0x35, 0xf,  0,	0x20e00000,  26, 0x20e00000 },
	{ 0x3, 0x35, 0x10, 0,	0x400000,  3,  0x400000 },
	{ 0x3, 0x35, 0x11, 0,	0x20400000,  22, 0x20400000 },
	{ 0x3, 0x35, 0x12, 0,	0x800000,  4,  0x800000 },
	{ 0x3, 0x35, 0x13, 0,	0x5000000,  9,  0x5000000 },
	{ 0x3, 0x35, 0x14, 0,	0xc800000,  34, 0xc800000 },
	{ 0x3, 0x35, 0x15, 0,	0x1000000,  5,  0x1000000 },
	{ 0x3, 0x35, 0x16, 0,	0x3000000,  7,  0x3000000 },
	{ 0x3, 0x35, 0x17, 0,	0x4000000,  8,  0x4000000 },
	{ 0x3, 0x35, 0x18, 0,	0xd000000,  16, 0xd000000 },
	{ 0x3, 0x35, 0x19, 0,	0x21000000,  27, 0x21000000 },
	{ 0x3, 0x35, 0x1a, 0,	0x2000000,  6,  0x2000000 },
	{ 0x3, 0x35, 0x1b, 0,	0x6000000,  14, 0x6000000 },
	{ 0x3, 0x35, 0x1c, 0,	0xe000000,  17, 0xe000000 },
	{ 0x3, 0x35, 0x1d, 0,	0x22000000,  28, 0x22000000 },
	{ 0x3, 0x35, 0x1e, 0,	0x8000000,  15, 0x8000000 },
	{ 0x3, 0x35, 0x1f, 0,	0x24000000,  29, 0x24000000 },
	{ 0x3, 0x35, 0x20, 0,	0x28000000,  30, 0x28000000 },
	{ 0x3, 0x35, 0x21, 0,	0x10000000,  18, 0x10000000 },
	{ 0x3, 0x35, 0x22, 0,	0x30000000,  31, 0x30000000 },
	{ 0x3, 0x37, 0x0,  0,	0xc640000,  0,  0x0 },
	{ 0x3, 0x20, 0x0,  0,	0xc3b0000,  0,  0x0 },
	{ 0x3, 0x21, 0x0,  0,	0xc000000,  0,  0x0 },
	{ 0x3, 0x22, 0x0,  0,	0xc040000,  0,  0x0 },
	{ 0x3, 0x23, 0x0,  0,	0xc050000,  0,  0x0 },
	{ 0x3, 0x24, 0x0,  0,	0x20cf0000,  0,  0x0 },
	{ 0x3, 0x25, 0x0,  0,	0xc2f0000,  0,  0x0 },
	{ 0x3, 0x26, 0x0,  0,	0xc230000,  0,  0x0 },
	{ 0x3, 0x27, 0x0,  0,	0xc350000,  0,  0x0 },
	{ 0x3, 0x28, 0x0,  0,	0xc301000,  0,  0x0 },
	{ 0x3, 0x29, 0x0,  0,	0xc302000,  0,  0x0 },
	{ 0x3, 0x2A, 0x0,  0,	0xc303000,  0,  0x0 },
	{ 0x3, 0x2B, 0x0,  0,	0xc2a0000,  0,  0x0 },
	{ 0x3, 0x2C, 0x0,  0,	0xc2b0000,  0,  0x0 },
	{ 0x3, 0x2C, 0x1,  0,	0xc2c0000,  1,  0x10000 },
	{ 0x3, 0x2C, 0x2,  0,	0xc2d0000,  2,  0x20000 },
	{ 0x3, 0x2C, 0x3,  0,	0xc2e0000,  3,  0x30000 },
	{ 0x3, 0x0,  0x0,  0,	0xc660000,  0,  0x0 },
	{ 0x3, 0x1,  0x0,  0,	0xc020000,  0,  0x0 },
	{ 0x3, 0x2,  0x0,  0,	0xc030000,  0,  0x0 },
	{ 0x3, 0x3,  0x0,  0,	0xc310000,  0,  0x0 },
	{ 0x3, 0x4,  0x0,  0,	0xc320000,  0,  0x0 },
	{ 0x3, 0x5,  0x0,  0,	0xc0a0000,  2,  0x40000 },
	{ 0x3, 0x5,  0x1,  0,	0xc0b0000,  3,  0x50000 },
	{ 0x3, 0x5,  0x2,  0,	0xc0e0000,  5,  0x80000 },
	{ 0x3, 0x5,  0x3,  0,	0xc060000,  0,  0x0 },
	{ 0x3, 0x5,  0x4,  0,	0xc080000,  1,  0x20000 },
	{ 0x3, 0x5,  0x5,  0,	0xc0c0000,  4,  0x60000 },
	{ 0x3, 0x6,  0x0,  0,	0xc330000,  0,  0x0 },
	{ 0x3, 0x7,  0x0,  0,	0xc650000,  0,  0x0 },
	{ 0x3, 0x8,  0x0,  0,	0xc3e0000,  0,  0x0 },
	{ 0x3, 0x9,  0x0,  0,	0xc1e0000,  0,  0x0 },
	{ 0x3, 0xA,  0x0,  0,	0xc150000,  0,  0x0 },
	{ 0x3, 0xA,  0x1,  0,	0xc160000,  1,  0x10000 },
	{ 0x3, 0xA,  0x2,  0,	0xc170000,  2,  0x20000 },
	{ 0x3, 0xA,  0x3,  0,	0xc180000,  3,  0x30000 },
	{ 0x3, 0xA,  0x4,  0,	0xc190000,  4,  0x40000 },
	{ 0x3, 0xA,  0x5,  0,	0xc1a0000,  5,  0x50000 },
	{ 0x3, 0xA,  0x6,  0,	0xc1b0000,  6,  0x60000 },
	{ 0x3, 0xA,  0x7,  0,	0xc1c0000,  7,  0x70000 },
	{ 0x3, 0xA,  0x8,  0,	0xc1d0000,  8,  0x80000 },
	{ 0x3, 0xB,  0x0,  0,	0xc240000,  0,  0x0 },
	{ 0x3, 0xC,  0x0,  0,	0xc250000,  0,  0x0 },
	{ 0x3, 0xD,  0x0,  0,	0xc340000,  0,  0x0 },
	{ 0x3, 0xE,  0x0,  0,	0xc260000,  0,  0x0 },
	{ 0x3, 0xF,  0x0,  0,	0xc0f0000,  0,  0x0 },
	{ 0x3, 0xF,  0x1,  0,	0xc100000,  1,  0x10000 },
	{ 0x3, 0xF,  0x2,  0,	0xc110000,  2,  0x20000 },
	{ 0x3, 0xF,  0x3,  0,	0xc120000,  3,  0x30000 },
	{ 0x3, 0xF,  0x4,  0,	0xc130000,  4,  0x40000 },
	{ 0x3, 0xF,  0x5,  0,	0xc140000,  5,  0x50000 },
	{ 0x3, 0x10, 0x0,  0,	0xc290000,  0,  0x0 },
	{ 0x3, 0x30, 0x0,  0,	0x20ce0000,  0,  0x0 },
	{ 0x3, 0x31, 0x0,  0,	0xc1f0000,  0,  0x0 },
	{ 0x3, 0x31, 0x1,  0,	0xc200000,  1,  0x10000 },
	{ 0x3, 0x31, 0x2,  0,	0xc210000,  2,  0x20000 },
	{ 0x3, 0x31, 0x3,  0,	0xc220000,  3,  0x30000 },
	{ 0x3, 0x32, 0x0,  0,	0x20cc0000,  3,  0x1c0000 },
	{ 0x3, 0x32, 0x1,  0,	0x20c80000,  2,  0x180000 },
	{ 0x3, 0x32, 0x2,  0,	0x20c00000,  1,  0x100000 },
	{ 0x3, 0x32, 0x3,  0,	0x20b00000,  0,  0x0 },
	{ 0x3, 0x33, 0x0,  0,	0xc360000,  0,  0x0 },
	{ 0x3, 0x33, 0x1,  0,	0xc370000,  1,  0x10000 },
	{ 0x3, 0x33, 0x2,  0,	0xc3a0000,  3,  0x40000 },
	{ 0x3, 0x33, 0x3,  0,	0xc380000,  2,  0x20000 },
	{ 0x3, 0x38, 0x0,  0,	0xc600000,  0,  0x0 },
	{ 0x3, 0x38, 0x1,  0,	0x0,  0,  0x0 },
	{ 0x3, 0x39, 0x0,  0,	0xc280000,  0,  0x0 }
};


/*
 * SCE/RCE NOC aperture lookup table as per file "AON_NOC_Structure.info".
 */
static char *t194_scenoc_routeid_initflow[] = {
	"cbb_i/I/0",		/* 0 */
	"cpu_m_i/I/0",		/* 1 */
	"cpu_p_i/I/0",		/* 2 */
	"dma_m_i/I/0",		/* 3 */
	"dma_p_i/I/0",		/* 4 */
	"RESERVED",		/* 5 */
	"RESERVED",		/* 6 */
	"RESERVED"		/* 7 */
};

static char *t194_scenoc_routeid_targflow[] = {
	"multiport0_t/T/atcm_cfg",		/* 0x0  */
	"multiport0_t/T/car",                   /* 0x1  */
	"multiport0_t/T/cast",                  /* 0x2  */
	"multiport0_t/T/cfg",                   /* 0x3  */
	"multiport0_t/T/dast",                  /* 0x4  */
	"multiport0_t/T/dma",                   /* 0x5  */
	"multiport0_t/T/err_collator",          /* 0x6  */
	"multiport0_t/T/err_collator_car",      /* 0x7  */
	"multiport0_t/T/fpga_misc",             /* 0x8  */
	"multiport0_t/T/fpga_uart",             /* 0x9  */
	"multiport0_t/T/gte",                   /* 0xA  */
	"multiport0_t/T/hsp",                   /* 0xB  */
	"multiport0_t/T/misc",                  /* 0xC  */
	"multiport0_t/T/pm",                    /* 0xD  */
	"multiport0_t/T/tke",                   /* 0xE  */
	"RESERVED",                             /* 0xF  */
	"multiport1_t/T/hsm",                   /* 0x10 */
	"multiport1_t/T/vic0",                  /* 0x11 */
	"multiport1_t/T/vic1",                  /* 0x12 */
	"ast0_t/T/0",                           /* 0x13 */
	"ast1_t/T/0",                           /* 0x14 */
	"cbb_t/T/0",                            /* 0x15 */
	"cpu_t/T/0",                            /* 0x16 */
	"sce_noc_firewall/T/0",                 /* 0x17 */
	"svc_t/T/0",                            /* 0x18 */
	"RESERVED",                             /* 0x19 */
	"RESERVED",                             /* 0x1A */
	"RESERVED",                             /* 0x1B */
	"RESERVED",                             /* 0x1C */
	"RESERVED",                             /* 0x1D */
	"RESERVED",                             /* 0x1E */
	"RESERVED"                              /* 0x1F */
};


/*
 * Fields of SCE/RCE NOC lookup table:
 * Init flow, Targ flow, Targ subrange, Init mapping, Init localAddress,
 *                                              Targ mapping, Targ localAddress
 * ----------------------------------------------------------------------------
 */
static struct tegra_lookup_noc_aperture t194_scenoc_aperture_lookup[] = {
	{ 0x0, 0x16, 0x0, 0, 0xb400000, 0, 0xb400000 },
	{ 0x0, 0x16, 0x1, 0, 0xbc00000, 1, 0xbc00000 },
	{ 0x0, 0x0, 0x0, 0, 0xb000000, 0, 0x0 },
	{ 0x0, 0x0, 0x1, 0, 0xb800000, 1, 0x0 },
	{ 0x0, 0x1, 0x0, 0, 0x20de0000, 3, 0xe0000 },
	{ 0x0, 0x1, 0x1, 0, 0x210e0000, 7, 0xe0000 },
	{ 0x0, 0x1, 0x2, 0, 0x20dc0000, 2, 0xc0000 },
	{ 0x0, 0x1, 0x3, 0, 0x210c0000, 6, 0xc0000 },
	{ 0x0, 0x1, 0x4, 0, 0x20d80000, 1, 0x80000 },
	{ 0x0, 0x1, 0x5, 0, 0x21080000, 5, 0x80000 },
	{ 0x0, 0x1, 0x6, 0, 0x20d00000, 0, 0x0 },
	{ 0x0, 0x1, 0x7, 0, 0x21000000, 4, 0x0 },
	{ 0x0, 0x2, 0x0, 0, 0xb040000, 0, 0x0 },
	{ 0x0, 0x2, 0x1, 0, 0xb840000, 1, 0x0 },
	{ 0x0, 0x3, 0x0, 0, 0xb230000, 0, 0x0 },
	{ 0x0, 0x3, 0x1, 0, 0xba30000, 1, 0x0 },
	{ 0x0, 0x4, 0x0, 0, 0xb050000, 0, 0x0 },
	{ 0x0, 0x4, 0x1, 0, 0xb850000, 1, 0x0 },
	{ 0x0, 0x5, 0x0, 0, 0xb060000, 0, 0x0 },
	{ 0x0, 0x5, 0x1, 0, 0xb070000, 1, 0x10000 },
	{ 0x0, 0x5, 0x2, 0, 0xb080000, 2, 0x20000 },
	{ 0x0, 0x5, 0x3, 0, 0xb090000, 3, 0x30000 },
	{ 0x0, 0x5, 0x4, 0, 0xb0a0000, 4, 0x40000 },
	{ 0x0, 0x5, 0x5, 0, 0xb0b0000, 5, 0x50000 },
	{ 0x0, 0x5, 0x6, 0, 0xb0c0000, 6, 0x60000 },
	{ 0x0, 0x5, 0x7, 0, 0xb0d0000, 7, 0x70000 },
	{ 0x0, 0x5, 0x8, 0, 0xb0e0000, 8, 0x80000 },
	{ 0x0, 0x5, 0x9, 0, 0xb860000, 9, 0x0 },
	{ 0x0, 0x5, 0xa, 0, 0xb870000, 10, 0x10000 },
	{ 0x0, 0x5, 0xb, 0, 0xb880000, 11, 0x20000 },
	{ 0x0, 0x5, 0xc, 0, 0xb890000, 12, 0x30000 },
	{ 0x0, 0x5, 0xd, 0, 0xb8a0000, 13, 0x40000 },
	{ 0x0, 0x5, 0xe, 0, 0xb8b0000, 14, 0x50000 },
	{ 0x0, 0x5, 0xf, 0, 0xb8c0000, 15, 0x60000 },
	{ 0x0, 0x5, 0x10, 0, 0xb8d0000, 16, 0x70000 },
	{ 0x0, 0x5, 0x11, 0, 0xb8e0000, 17, 0x80000 },
	{ 0x0, 0x6, 0x0, 0, 0xb650000, 0, 0x0 },
	{ 0x0, 0x6, 0x1, 0, 0xbe50000, 1, 0x0 },
	{ 0x0, 0x7, 0x0, 0, 0x20df0000, 0, 0x0 },
	{ 0x0, 0x7, 0x1, 0, 0x210f0000, 1, 0x0 },
	{ 0x0, 0x8, 0x0, 0, 0xb3e0000, 0, 0x0 },
	{ 0x0, 0x8, 0x1, 0, 0xbbe0000, 1, 0x0 },
	{ 0x0, 0x9, 0x0, 0, 0xb3d0000, 0, 0x0 },
	{ 0x0, 0x9, 0x1, 0, 0xbbd0000, 1, 0x0 },
	{ 0x0, 0xA, 0x0, 0, 0xb1e0000, 0, 0x0 },
	{ 0x0, 0xA, 0x1, 0, 0xb9e0000, 1, 0x0 },
	{ 0x0, 0xB, 0x0, 0, 0xb150000, 0, 0x0 },
	{ 0x0, 0xB, 0x1, 0, 0xb160000, 1, 0x10000 },
	{ 0x0, 0xB, 0x2, 0, 0xb170000, 2, 0x20000 },
	{ 0x0, 0xB, 0x3, 0, 0xb180000, 3, 0x30000 },
	{ 0x0, 0xB, 0x4, 0, 0xb190000, 4, 0x40000 },
	{ 0x0, 0xB, 0x5, 0, 0xb1a0000, 5, 0x50000 },
	{ 0x0, 0xB, 0x6, 0, 0xb1b0000, 6, 0x60000 },
	{ 0x0, 0xB, 0x7, 0, 0xb1c0000, 7, 0x70000 },
	{ 0x0, 0xB, 0x8, 0, 0xb1d0000, 8, 0x80000 },
	{ 0x0, 0xB, 0x9, 0, 0xb950000, 9, 0x0 },
	{ 0x0, 0xB, 0xa, 0, 0xb960000, 10, 0x10000 },
	{ 0x0, 0xB, 0xb, 0, 0xb970000, 11, 0x20000 },
	{ 0x0, 0xB, 0xc, 0, 0xb980000, 12, 0x30000 },
	{ 0x0, 0xB, 0xd, 0, 0xb990000, 13, 0x40000 },
	{ 0x0, 0xB, 0xe, 0, 0xb9a0000, 14, 0x50000 },
	{ 0x0, 0xB, 0xf, 0, 0xb9b0000, 15, 0x60000 },
	{ 0x0, 0xB, 0x10, 0, 0xb9c0000, 16, 0x70000 },
	{ 0x0, 0xB, 0x11, 0, 0xb9d0000, 17, 0x80000 },
	{ 0x0, 0xC, 0x0, 0, 0xb660000, 0, 0x0 },
	{ 0x0, 0xC, 0x1, 0, 0xbe60000, 1, 0x0 },
	{ 0x0, 0xD, 0x0, 0, 0xb1f0000, 0, 0x0 },
	{ 0x0, 0xD, 0x1, 0, 0xb200000, 1, 0x10000 },
	{ 0x0, 0xD, 0x2, 0, 0xb210000, 2, 0x20000 },
	{ 0x0, 0xD, 0x3, 0, 0xb220000, 3, 0x30000 },
	{ 0x0, 0xD, 0x4, 0, 0xb9f0000, 4, 0x0 },
	{ 0x0, 0xD, 0x5, 0, 0xba00000, 5, 0x10000 },
	{ 0x0, 0xD, 0x6, 0, 0xba10000, 6, 0x20000 },
	{ 0x0, 0xD, 0x7, 0, 0xba20000, 7, 0x30000 },
	{ 0x0, 0xE, 0x0, 0, 0xb0f0000, 0, 0x0 },
	{ 0x0, 0xE, 0x1, 0, 0xb100000, 1, 0x10000 },
	{ 0x0, 0xE, 0x2, 0, 0xb110000, 2, 0x20000 },
	{ 0x0, 0xE, 0x3, 0, 0xb120000, 3, 0x30000 },
	{ 0x0, 0xE, 0x4, 0, 0xb130000, 4, 0x40000 },
	{ 0x0, 0xE, 0x5, 0, 0xb140000, 5, 0x50000 },
	{ 0x0, 0xE, 0x6, 0, 0xb8f0000, 6, 0x0 },
	{ 0x0, 0xE, 0x7, 0, 0xb900000, 7, 0x10000 },
	{ 0x0, 0xE, 0x8, 0, 0xb910000, 8, 0x20000 },
	{ 0x0, 0xE, 0x9, 0, 0xb920000, 9, 0x30000 },
	{ 0x0, 0xE, 0xa, 0, 0xb930000, 10, 0x40000 },
	{ 0x0, 0xE, 0xb, 0, 0xb940000, 11, 0x50000 },
	{ 0x0, 0x10, 0x0, 0, 0xb240000, 0, 0x0 },
	{ 0x0, 0x10, 0x1, 0, 0xba40000, 1, 0x0 },
	{ 0x0, 0x11, 0x0, 0, 0xb020000, 0, 0x0 },
	{ 0x0, 0x11, 0x1, 0, 0xb820000, 1, 0x0 },
	{ 0x0, 0x12, 0x0, 0, 0xb030000, 0, 0x0 },
	{ 0x0, 0x12, 0x1, 0, 0xb830000, 1, 0x0 },
	{ 0x0, 0x17, 0x0, 0, 0xb640000, 0, 0x0 },
	{ 0x0, 0x17, 0x1, 0, 0xbe40000, 1, 0x0 },
	{ 0x0, 0x18, 0x0, 0, 0xb600000, 0, 0x0 },
	{ 0x0, 0x18, 0x1, 0, 0xbe00000, 1, 0x0 },
	{ 0x0, 0x18, 0x2, 0, 0x0, 0, 0x0 },
	{ 0x0, 0x18, 0x3, 0, 0x0, 0, 0x0 },
	{ 0x1, 0x13, 0x0, 0, 0x40000000, 0, 0x40000000 },
	{ 0x1, 0x13, 0x1, 1, 0x80000000, 1, 0x80000000 },
	{ 0x1, 0x13, 0x2, 0, 0x0, 0, 0x0 },
	{ 0x2, 0x15, 0x0, 0, 0x20c00000, 8, 0x20c00000 },
	{ 0x2, 0x15, 0x1, 0, 0x21100000, 22, 0x21100000 },
	{ 0x2, 0x15, 0x2, 0, 0x20e00000, 9, 0x20e00000 },
	{ 0x2, 0x15, 0x3, 0, 0x21200000, 23, 0x21200000 },
	{ 0x2, 0x15, 0x4, 0, 0x20800000, 7, 0x20800000 },
	{ 0x2, 0x15, 0x5, 0, 0x21400000, 24, 0x21400000 },
	{ 0x2, 0x15, 0x6, 0, 0xb000000, 18, 0xb000000 },
	{ 0x2, 0x15, 0x7, 0, 0xb800000, 3, 0xb800000 },
	{ 0x2, 0x15, 0x8, 0, 0x20000000, 6, 0x20000000 },
	{ 0x2, 0x15, 0x9, 0, 0x21800000, 25, 0x21800000 },
	{ 0x2, 0x15, 0xa, 0, 0xa000000, 2, 0xa000000 },
	{ 0x2, 0x15, 0xb, 0, 0xa000000, 17, 0xa000000 },
	{ 0x2, 0x15, 0xc, 0, 0x20000000, 21, 0x20000000 },
	{ 0x2, 0x15, 0xd, 0, 0x21000000, 10, 0x21000000 },
	{ 0x2, 0x15, 0xe, 0, 0x8000000, 1, 0x8000000 },
	{ 0x2, 0x15, 0xf, 0, 0x8000000, 16, 0x8000000 },
	{ 0x2, 0x15, 0x10, 0, 0x22000000, 11, 0x22000000 },
	{ 0x2, 0x15, 0x11, 0, 0x22000000, 26, 0x22000000 },
	{ 0x2, 0x15, 0x12, 0, 0xc000000, 4, 0xc000000 },
	{ 0x2, 0x15, 0x13, 0, 0xc000000, 19, 0xc000000 },
	{ 0x2, 0x15, 0x14, 0, 0x24000000, 12, 0x24000000 },
	{ 0x2, 0x15, 0x15, 0, 0x24000000, 27, 0x24000000 },
	{ 0x2, 0x15, 0x16, 0, 0x0, 0, 0x0 },
	{ 0x2, 0x15, 0x17, 0, 0x0, 15, 0x0 },
	{ 0x2, 0x15, 0x18, 0, 0x28000000, 13, 0x28000000 },
	{ 0x2, 0x15, 0x19, 0, 0x28000000, 28, 0x28000000 },
	{ 0x2, 0x15, 0x1a, 0, 0x10000000, 5, 0x10000000 },
	{ 0x2, 0x15, 0x1b, 0, 0x10000000, 20, 0x10000000 },
	{ 0x2, 0x15, 0x1c, 0, 0x30000000, 14, 0x30000000 },
	{ 0x2, 0x15, 0x1d, 0, 0x30000000, 29, 0x30000000 },
	{ 0x2, 0x0, 0x0, 0, 0xb000000, 0, 0x0 },
	{ 0x2, 0x0, 0x1, 0, 0xb800000, 1, 0x0 },
	{ 0x2, 0x1, 0x0, 0, 0x20de0000, 3, 0xe0000 },
	{ 0x2, 0x1, 0x1, 0, 0x210e0000, 7, 0xe0000 },
	{ 0x2, 0x1, 0x2, 0, 0x20dc0000, 2, 0xc0000 },
	{ 0x2, 0x1, 0x3, 0, 0x210c0000, 6, 0xc0000 },
	{ 0x2, 0x1, 0x4, 0, 0x20d80000, 1, 0x80000 },
	{ 0x2, 0x1, 0x5, 0, 0x21080000, 5, 0x80000 },
	{ 0x2, 0x1, 0x6, 0, 0x20d00000, 0, 0x0 },
	{ 0x2, 0x1, 0x7, 0, 0x21000000, 4, 0x0 },
	{ 0x2, 0x2, 0x0, 0, 0xb040000, 0, 0x0 },
	{ 0x2, 0x2, 0x1, 0, 0xb840000, 1, 0x0 },
	{ 0x2, 0x3, 0x0, 0, 0xb230000, 0, 0x0 },
	{ 0x2, 0x3, 0x1, 0, 0xba30000, 1, 0x0 },
	{ 0x2, 0x4, 0x0, 0, 0xb050000, 0, 0x0 },
	{ 0x2, 0x4, 0x1, 0, 0xb850000, 1, 0x0 },
	{ 0x2, 0x5, 0x0, 0, 0xb060000, 0, 0x0 },
	{ 0x2, 0x5, 0x1, 0, 0xb070000, 1, 0x10000 },
	{ 0x2, 0x5, 0x2, 0, 0xb080000, 2, 0x20000 },
	{ 0x2, 0x5, 0x3, 0, 0xb090000, 3, 0x30000 },
	{ 0x2, 0x5, 0x4, 0, 0xb0a0000, 4, 0x40000 },
	{ 0x2, 0x5, 0x5, 0, 0xb0b0000, 5, 0x50000 },
	{ 0x2, 0x5, 0x6, 0, 0xb0c0000, 6, 0x60000 },
	{ 0x2, 0x5, 0x7, 0, 0xb0d0000, 7, 0x70000 },
	{ 0x2, 0x5, 0x8, 0, 0xb0e0000, 8, 0x80000 },
	{ 0x2, 0x5, 0x9, 0, 0xb860000, 9, 0x0 },
	{ 0x2, 0x5, 0xa, 0, 0xb870000, 10, 0x10000 },
	{ 0x2, 0x5, 0xb, 0, 0xb880000, 11, 0x20000 },
	{ 0x2, 0x5, 0xc, 0, 0xb890000, 12, 0x30000 },
	{ 0x2, 0x5, 0xd, 0, 0xb8a0000, 13, 0x40000 },
	{ 0x2, 0x5, 0xe, 0, 0xb8b0000, 14, 0x50000 },
	{ 0x2, 0x5, 0xf, 0, 0xb8c0000, 15, 0x60000 },
	{ 0x2, 0x5, 0x10, 0, 0xb8d0000, 16, 0x70000 },
	{ 0x2, 0x5, 0x11, 0, 0xb8e0000, 17, 0x80000 },
	{ 0x2, 0x6, 0x0, 0, 0xb650000, 0, 0x0 },
	{ 0x2, 0x6, 0x1, 0, 0xbe50000, 1, 0x0 },
	{ 0x2, 0x7, 0x0, 0, 0x20df0000, 0, 0x0 },
	{ 0x2, 0x7, 0x1, 0, 0x210f0000, 1, 0x0 },
	{ 0x2, 0x8, 0x0, 0, 0xb3e0000, 0, 0x0 },
	{ 0x2, 0x8, 0x1, 0, 0xbbe0000, 1, 0x0 },
	{ 0x2, 0x9, 0x0, 0, 0xb3d0000, 0, 0x0 },
	{ 0x2, 0x9, 0x1, 0, 0xbbd0000, 1, 0x0 },
	{ 0x2, 0xA, 0x0, 0, 0xb1e0000, 0, 0x0 },
	{ 0x2, 0xA, 0x1, 0, 0xb9e0000, 1, 0x0 },
	{ 0x2, 0xB, 0x0, 0, 0xb150000, 0, 0x0 },
	{ 0x2, 0xB, 0x1, 0, 0xb160000, 1, 0x10000 },
	{ 0x2, 0xB, 0x2, 0, 0xb170000, 2, 0x20000 },
	{ 0x2, 0xB, 0x3, 0, 0xb180000, 3, 0x30000 },
	{ 0x2, 0xB, 0x4, 0, 0xb190000, 4, 0x40000 },
	{ 0x2, 0xB, 0x5, 0, 0xb1a0000, 5, 0x50000 },
	{ 0x2, 0xB, 0x6, 0, 0xb1b0000, 6, 0x60000 },
	{ 0x2, 0xB, 0x7, 0, 0xb1c0000, 7, 0x70000 },
	{ 0x2, 0xB, 0x8, 0, 0xb1d0000, 8, 0x80000 },
	{ 0x2, 0xB, 0x9, 0, 0xb950000, 9, 0x0 },
	{ 0x2, 0xB, 0xa, 0, 0xb960000, 10, 0x10000 },
	{ 0x2, 0xB, 0xb, 0, 0xb970000, 11, 0x20000 },
	{ 0x2, 0xB, 0xc, 0, 0xb980000, 12, 0x30000 },
	{ 0x2, 0xB, 0xd, 0, 0xb990000, 13, 0x40000 },
	{ 0x2, 0xB, 0xe, 0, 0xb9a0000, 14, 0x50000 },
	{ 0x2, 0xB, 0xf, 0, 0xb9b0000, 15, 0x60000 },
	{ 0x2, 0xB, 0x10, 0, 0xb9c0000, 16, 0x70000 },
	{ 0x2, 0xB, 0x11, 0, 0xb9d0000, 17, 0x80000 },
	{ 0x2, 0xC, 0x0, 0, 0xb660000, 0, 0x0 },
	{ 0x2, 0xC, 0x1, 0, 0xbe60000, 1, 0x0 },
	{ 0x2, 0xD, 0x0, 0, 0xb1f0000, 0, 0x0 },
	{ 0x2, 0xD, 0x1, 0, 0xb200000, 1, 0x10000 },
	{ 0x2, 0xD, 0x2, 0, 0xb210000, 2, 0x20000 },
	{ 0x2, 0xD, 0x3, 0, 0xb220000, 3, 0x30000 },
	{ 0x2, 0xD, 0x4, 0, 0xb9f0000, 4, 0x0 },
	{ 0x2, 0xD, 0x5, 0, 0xba00000, 5, 0x10000 },
	{ 0x2, 0xD, 0x6, 0, 0xba10000, 6, 0x20000 },
	{ 0x2, 0xD, 0x7, 0, 0xba20000, 7, 0x30000 },
	{ 0x2, 0xE, 0x0, 0, 0xb0f0000, 0, 0x0 },
	{ 0x2, 0xE, 0x1, 0, 0xb100000, 1, 0x10000 },
	{ 0x2, 0xE, 0x2, 0, 0xb110000, 2, 0x20000 },
	{ 0x2, 0xE, 0x3, 0, 0xb120000, 3, 0x30000 },
	{ 0x2, 0xE, 0x4, 0, 0xb130000, 4, 0x40000 },
	{ 0x2, 0xE, 0x5, 0, 0xb140000, 5, 0x50000 },
	{ 0x2, 0xE, 0x6, 0, 0xb8f0000, 6, 0x0 },
	{ 0x2, 0xE, 0x7, 0, 0xb900000, 7, 0x10000 },
	{ 0x2, 0xE, 0x8, 0, 0xb910000, 8, 0x20000 },
	{ 0x2, 0xE, 0x9, 0, 0xb920000, 9, 0x30000 },
	{ 0x2, 0xE, 0xa, 0, 0xb930000, 10, 0x40000 },
	{ 0x2, 0xE, 0xb, 0, 0xb940000, 11, 0x50000 },
	{ 0x2, 0x10, 0x0, 0, 0xb240000, 0, 0x0 },
	{ 0x2, 0x10, 0x1, 0, 0xba40000, 1, 0x0 },
	{ 0x2, 0x11, 0x0, 0, 0xb020000, 0, 0x0 },
	{ 0x2, 0x11, 0x1, 0, 0xb820000, 1, 0x0 },
	{ 0x2, 0x12, 0x0, 0, 0xb030000, 0, 0x0 },
	{ 0x2, 0x12, 0x1, 0, 0xb830000, 1, 0x0 },
	{ 0x2, 0x17, 0x0, 0, 0xb640000, 0, 0x0 },
	{ 0x2, 0x17, 0x1, 0, 0xbe40000, 1, 0x0 },
	{ 0x2, 0x18, 0x0, 0, 0xb600000, 0, 0x0 },
	{ 0x2, 0x18, 0x1, 0, 0xbe00000, 1, 0x0 },
	{ 0x2, 0x18, 0x2, 0, 0x0, 0, 0x0 },
	{ 0x2, 0x18, 0x3, 0, 0x0, 0, 0x0 },
	{ 0x3, 0x14, 0x0, 0, 0x40000000, 0, 0x40000000 },
	{ 0x3, 0x14, 0x1, 1, 0x80000000, 1, 0x80000000 },
	{ 0x3, 0x16, 0x0, 2, 0xb400000, 0, 0xb400000 },
	{ 0x3, 0x16, 0x1, 2, 0xbc00000, 1, 0xbc00000 },
	{ 0x3, 0x16, 0x2, 0, 0x0, 0, 0x0 },
	{ 0x3, 0x16, 0x3, 0, 0x0, 0, 0x0 },
	{ 0x4, 0x15, 0x0, 0, 0x20c00000, 8, 0x20c00000 },
	{ 0x4, 0x15, 0x1, 0, 0x21100000, 22, 0x21100000 },
	{ 0x4, 0x15, 0x2, 0, 0x20e00000, 9, 0x20e00000 },
	{ 0x4, 0x15, 0x3, 0, 0x21200000, 23, 0x21200000 },
	{ 0x4, 0x15, 0x4, 0, 0x20800000, 7, 0x20800000 },
	{ 0x4, 0x15, 0x5, 0, 0x21400000, 24, 0x21400000 },
	{ 0x4, 0x15, 0x6, 0, 0xb000000, 18, 0xb000000 },
	{ 0x4, 0x15, 0x7, 0, 0xb800000, 3, 0xb800000 },
	{ 0x4, 0x15, 0x8, 0, 0x20000000, 6, 0x20000000 },
	{ 0x4, 0x15, 0x9, 0, 0x21800000, 25, 0x21800000 },
	{ 0x4, 0x15, 0xa, 0, 0xa000000, 2, 0xa000000 },
	{ 0x4, 0x15, 0xb, 0, 0xa000000, 17, 0xa000000 },
	{ 0x4, 0x15, 0xc, 0, 0x20000000, 21, 0x20000000 },
	{ 0x4, 0x15, 0xd, 0, 0x21000000, 10, 0x21000000 },
	{ 0x4, 0x15, 0xe, 0, 0x8000000, 1, 0x8000000 },
	{ 0x4, 0x15, 0xf, 0, 0x8000000, 16, 0x8000000 },
	{ 0x4, 0x15, 0x10, 0, 0x22000000, 11, 0x22000000 },
	{ 0x4, 0x15, 0x11, 0, 0x22000000, 26, 0x22000000 },
	{ 0x4, 0x15, 0x12, 0, 0xc000000, 4, 0xc000000 },
	{ 0x4, 0x15, 0x13, 0, 0xc000000, 19, 0xc000000 },
	{ 0x4, 0x15, 0x14, 0, 0x24000000, 12, 0x24000000 },
	{ 0x4, 0x15, 0x15, 0, 0x24000000, 27, 0x24000000 },
	{ 0x4, 0x15, 0x16, 0, 0x0, 0, 0x0 },
	{ 0x4, 0x15, 0x17, 0, 0x0, 15, 0x0 },
	{ 0x4, 0x15, 0x18, 0, 0x28000000, 13, 0x28000000 },
	{ 0x4, 0x15, 0x19, 0, 0x28000000, 28, 0x28000000 },
	{ 0x4, 0x15, 0x1a, 0, 0x10000000, 5, 0x10000000 },
	{ 0x4, 0x15, 0x1b, 0, 0x10000000, 20, 0x10000000 },
	{ 0x4, 0x15, 0x1c, 0, 0x30000000, 14, 0x30000000 },
	{ 0x4, 0x15, 0x1d, 0, 0x30000000, 29, 0x30000000 },
	{ 0x4, 0x0, 0x0, 0, 0xb000000, 0, 0x0 },
	{ 0x4, 0x0, 0x1, 0, 0xb800000, 1, 0x0 },
	{ 0x4, 0x1, 0x0, 0, 0x20de0000, 3, 0xe0000 },
	{ 0x4, 0x1, 0x1, 0, 0x210e0000, 7, 0xe0000 },
	{ 0x4, 0x1, 0x2, 0, 0x20dc0000, 2, 0xc0000 },
	{ 0x4, 0x1, 0x3, 0, 0x210c0000, 6, 0xc0000 },
	{ 0x4, 0x1, 0x4, 0, 0x20d80000, 1, 0x80000 },
	{ 0x4, 0x1, 0x5, 0, 0x21080000, 5, 0x80000 },
	{ 0x4, 0x1, 0x6, 0, 0x20d00000, 0, 0x0 },
	{ 0x4, 0x1, 0x7, 0, 0x21000000, 4, 0x0 },
	{ 0x4, 0x2, 0x0, 0, 0xb040000, 0, 0x0 },
	{ 0x4, 0x2, 0x1, 0, 0xb840000, 1, 0x0 },
	{ 0x4, 0x3, 0x0, 0, 0xb230000, 0, 0x0 },
	{ 0x4, 0x3, 0x1, 0, 0xba30000, 1, 0x0 },
	{ 0x4, 0x4, 0x0, 0, 0xb050000, 0, 0x0 },
	{ 0x4, 0x4, 0x1, 0, 0xb850000, 1, 0x0 },
	{ 0x4, 0x5, 0x0, 0, 0xb060000, 0, 0x0 },
	{ 0x4, 0x5, 0x1, 0, 0xb070000, 1, 0x10000 },
	{ 0x4, 0x5, 0x2, 0, 0xb080000, 2, 0x20000 },
	{ 0x4, 0x5, 0x3, 0, 0xb090000, 3, 0x30000 },
	{ 0x4, 0x5, 0x4, 0, 0xb0a0000, 4, 0x40000 },
	{ 0x4, 0x5, 0x5, 0, 0xb0b0000, 5, 0x50000 },
	{ 0x4, 0x5, 0x6, 0, 0xb0c0000, 6, 0x60000 },
	{ 0x4, 0x5, 0x7, 0, 0xb0d0000, 7, 0x70000 },
	{ 0x4, 0x5, 0x8, 0, 0xb0e0000, 8, 0x80000 },
	{ 0x4, 0x5, 0x9, 0, 0xb860000, 9, 0x0 },
	{ 0x4, 0x5, 0xa, 0, 0xb870000, 10, 0x10000 },
	{ 0x4, 0x5, 0xb, 0, 0xb880000, 11, 0x20000 },
	{ 0x4, 0x5, 0xc, 0, 0xb890000, 12, 0x30000 },
	{ 0x4, 0x5, 0xd, 0, 0xb8a0000, 13, 0x40000 },
	{ 0x4, 0x5, 0xe, 0, 0xb8b0000, 14, 0x50000 },
	{ 0x4, 0x5, 0xf, 0, 0xb8c0000, 15, 0x60000 },
	{ 0x4, 0x5, 0x10, 0, 0xb8d0000, 16, 0x70000 },
	{ 0x4, 0x5, 0x11, 0, 0xb8e0000, 17, 0x80000 },
	{ 0x4, 0x6, 0x0, 0, 0xb650000, 0, 0x0 },
	{ 0x4, 0x6, 0x1, 0, 0xbe50000, 1, 0x0 },
	{ 0x4, 0x7, 0x0, 0, 0x20df0000, 0, 0x0 },
	{ 0x4, 0x7, 0x1, 0, 0x210f0000, 1, 0x0 },
	{ 0x4, 0x8, 0x0, 0, 0xb3e0000, 0, 0x0 },
	{ 0x4, 0x8, 0x1, 0, 0xbbe0000, 1, 0x0 },
	{ 0x4, 0x9, 0x0, 0, 0xb3d0000, 0, 0x0 },
	{ 0x4, 0x9, 0x1, 0, 0xbbd0000, 1, 0x0 },
	{ 0x4, 0xA, 0x0, 0, 0xb1e0000, 0, 0x0 },
	{ 0x4, 0xA, 0x1, 0, 0xb9e0000, 1, 0x0 },
	{ 0x4, 0xB, 0x0, 0, 0xb150000, 0, 0x0 },
	{ 0x4, 0xB, 0x1, 0, 0xb160000, 1, 0x10000 },
	{ 0x4, 0xB, 0x2, 0, 0xb170000, 2, 0x20000 },
	{ 0x4, 0xB, 0x3, 0, 0xb180000, 3, 0x30000 },
	{ 0x4, 0xB, 0x4, 0, 0xb190000, 4, 0x40000 },
	{ 0x4, 0xB, 0x5, 0, 0xb1a0000, 5, 0x50000 },
	{ 0x4, 0xB, 0x6, 0, 0xb1b0000, 6, 0x60000 },
	{ 0x4, 0xB, 0x7, 0, 0xb1c0000, 7, 0x70000 },
	{ 0x4, 0xB, 0x8, 0, 0xb1d0000, 8, 0x80000 },
	{ 0x4, 0xB, 0x9, 0, 0xb950000, 9, 0x0 },
	{ 0x4, 0xB, 0xa, 0, 0xb960000, 10, 0x10000 },
	{ 0x4, 0xB, 0xb, 0, 0xb970000, 11, 0x20000 },
	{ 0x4, 0xB, 0xc, 0, 0xb980000, 12, 0x30000 },
	{ 0x4, 0xB, 0xd, 0, 0xb990000, 13, 0x40000 },
	{ 0x4, 0xB, 0xe, 0, 0xb9a0000, 14, 0x50000 },
	{ 0x4, 0xB, 0xf, 0, 0xb9b0000, 15, 0x60000 },
	{ 0x4, 0xB, 0x10, 0, 0xb9c0000, 16, 0x70000 },
	{ 0x4, 0xB, 0x11, 0, 0xb9d0000, 17, 0x80000 },
	{ 0x4, 0xC, 0x0, 0, 0xb660000, 0, 0x0 },
	{ 0x4, 0xC, 0x1, 0, 0xbe60000, 1, 0x0 },
	{ 0x4, 0xD, 0x0, 0, 0xb1f0000, 0, 0x0 },
	{ 0x4, 0xD, 0x1, 0, 0xb200000, 1, 0x10000 },
	{ 0x4, 0xD, 0x2, 0, 0xb210000, 2, 0x20000 },
	{ 0x4, 0xD, 0x3, 0, 0xb220000, 3, 0x30000 },
	{ 0x4, 0xD, 0x4, 0, 0xb9f0000, 4, 0x0 },
	{ 0x4, 0xD, 0x5, 0, 0xba00000, 5, 0x10000 },
	{ 0x4, 0xD, 0x6, 0, 0xba10000, 6, 0x20000 },
	{ 0x4, 0xD, 0x7, 0, 0xba20000, 7, 0x30000 },
	{ 0x4, 0xE, 0x0, 0, 0xb0f0000, 0, 0x0 },
	{ 0x4, 0xE, 0x1, 0, 0xb100000, 1, 0x10000 },
	{ 0x4, 0xE, 0x2, 0, 0xb110000, 2, 0x20000 },
	{ 0x4, 0xE, 0x3, 0, 0xb120000, 3, 0x30000 },
	{ 0x4, 0xE, 0x4, 0, 0xb130000, 4, 0x40000 },
	{ 0x4, 0xE, 0x5, 0, 0xb140000, 5, 0x50000 },
	{ 0x4, 0xE, 0x6, 0, 0xb8f0000, 6, 0x0 },
	{ 0x4, 0xE, 0x7, 0, 0xb900000, 7, 0x10000 },
	{ 0x4, 0xE, 0x8, 0, 0xb910000, 8, 0x20000 },
	{ 0x4, 0xE, 0x9, 0, 0xb920000, 9, 0x30000 },
	{ 0x4, 0xE, 0xa, 0, 0xb930000, 10, 0x40000 },
	{ 0x4, 0xE, 0xb, 0, 0xb940000, 11, 0x50000 },
	{ 0x4, 0x10, 0x0, 0, 0xb240000, 0, 0x0 },
	{ 0x4, 0x10, 0x1, 0, 0xba40000, 1, 0x0 },
	{ 0x4, 0x11, 0x0, 0, 0xb020000, 0, 0x0 },
	{ 0x4, 0x11, 0x1, 0, 0xb820000, 1, 0x0 },
	{ 0x4, 0x12, 0x0, 0, 0xb030000, 0, 0x0 },
	{ 0x4, 0x12, 0x1, 0, 0xb830000, 1, 0x0 },
	{ 0x4, 0x17, 0x0, 0, 0xb640000, 0, 0x0 },
	{ 0x4, 0x17, 0x1, 0, 0xbe40000, 1, 0x0 },
	{ 0x4, 0x18, 0x0, 0, 0xb600000, 0, 0x0 },
	{ 0x4, 0x18, 0x1, 0, 0xbe00000, 1, 0x0 },
	{ 0x4, 0x18, 0x2, 0, 0x0, 0, 0x0 },
	{ 0x4, 0x18, 0x3, 0, 0x0, 0, 0x0 }
};


/*
 * CV NOC aperture lookup table as per file "CVNOC_Structure.info".
 */
static char *t194_cvnoc_routeid_initflow[] = {
	"cbb_i/I/0",			/* 0 */
	"nvdla0_i/I/0",			/* 1 */
	"nvdla1_i/I/0",			/* 2 */
	"pva0_i/I/0",			/* 3 */
	"pva1_i/I/0",			/* 4 */
	"RESERVED",			/* 5 */
	"RESERVED",			/* 6 */
	"RESERVED"			/* 7 */
};

static char *t194_cvnoc_routeid_targflow[] = {
	"MultiTarget/T/firewall0_t",		/* 0x0 */
	"MultiTarget/T/firewall1_t",		/* 0x1 */
	"MultiTarget/T/firewall2_t",		/* 0x2 */
	"MultiTarget/T/firewall3_t",		/* 0x3 */
	"cvsram0_t/T/0",			/* 0x4 */
	"cvsram1_t/T/0",			/* 0x5 */
	"cvsram2_t/T/0",			/* 0x6 */
	"cvsram3_t/T/0",			/* 0x7 */
	"cvsram_cfg_t/T/0",			/* 0x8 */
	"svc_t/T/0",				/* 0x9 */
	"RESERVED",				/* 0xA */
	"RESERVED",				/* 0xB */
	"RESERVED",				/* 0xC */
	"RESERVED",				/* 0xD */
	"RESERVED",				/* 0xE */
	"RESERVED",				/* 0xF */
};

/*
 * Fields of CV NOC lookup table:
 * Init flow, Targ flow, Targ subrange, Init mapping, Init localAddress,
 *                                              Targ mapping, Targ localAddress
 * ----------------------------------------------------------------------------
 */
static struct tegra_lookup_noc_aperture t194_cvnoc_aperture_lookup[] = {
	{ 0, 0, 0x00, 0, 0x14010000, 0, 0x10000 },
	{ 0, 1, 0x00, 0, 0x14010400, 0, 0x10400 },
	{ 0, 2, 0x00, 0, 0x14010800, 0, 0x10800 },
	{ 0, 3, 0x00, 0, 0x14010c00, 0, 0x10c00 },
	{ 0, 4, 0x00, 0, 0x0, 0, 0x0 },
	{ 0, 4, 0x01, 0, 0x400, 4, 0x400 },
	{ 0, 4, 0x02, 0, 0x800, 8, 0x800 },
	{ 0, 4, 0x03, 0, 0xc00, 12, 0xc00 },
	{ 0, 4, 0x04, 0, 0x100000, 1, 0x100000 },
	{ 0, 4, 0x05, 0, 0x100400, 5, 0x100400 },
	{ 0, 4, 0x06, 0, 0x100800, 9, 0x100800 },
	{ 0, 4, 0x07, 0, 0x100c00, 13, 0x100c00 },
	{ 0, 4, 0x08, 0, 0x200000, 2, 0x200000 },
	{ 0, 4, 0x09, 0, 0x200400, 6, 0x200400 },
	{ 0, 4, 0x0a, 0, 0x200800, 10, 0x200800 },
	{ 0, 4, 0x0b, 0, 0x200c00, 14, 0x200c00 },
	{ 0, 4, 0x0c, 0, 0x300000, 3, 0x300000 },
	{ 0, 4, 0x0d, 0, 0x300400, 7, 0x300400 },
	{ 0, 4, 0x0e, 0, 0x300800, 11, 0x300800 },
	{ 0, 4, 0x0f, 0, 0x300c00, 15, 0x300c00 },
	{ 0, 4, 0x10, 0, 0x400000, 16, 0x400000 },
	{ 0, 4, 0x11, 0, 0x400500, 20, 0x400500 },
	{ 0, 4, 0x12, 0, 0x400b00, 24, 0x400b00 },
	{ 0, 4, 0x13, 0, 0x400e00, 28, 0x400e00 },
	{ 0, 4, 0x14, 0, 0x500000, 17, 0x500000 },
	{ 0, 4, 0x15, 0, 0x500500, 21, 0x500500 },
	{ 0, 4, 0x16, 0, 0x500b00, 25, 0x500b00 },
	{ 0, 4, 0x17, 0, 0x500e00, 29, 0x500e00 },
	{ 0, 4, 0x18, 0, 0x600000, 18, 0x600000 },
	{ 0, 4, 0x19, 0, 0x600500, 22, 0x600500 },
	{ 0, 4, 0x1a, 0, 0x600b00, 26, 0x600b00 },
	{ 0, 4, 0x1b, 0, 0x600e00, 30, 0x600e00 },
	{ 0, 4, 0x1c, 0, 0x700000, 19, 0x700000 },
	{ 0, 4, 0x1d, 0, 0x700500, 23, 0x700500 },
	{ 0, 4, 0x1e, 0, 0x700b00, 27, 0x700b00 },
	{ 0, 4, 0x1f, 0, 0x700e00, 31, 0x700e00 },
	{ 0, 5, 0x00, 0, 0x100, 0, 0x100 },
	{ 0, 5, 0x01, 0, 0x500, 4, 0x500 },
	{ 0, 5, 0x02, 0, 0x900, 8, 0x900 },
	{ 0, 5, 0x03, 0, 0xd00, 12, 0xd00 },
	{ 0, 5, 0x04, 0, 0x100100, 1, 0x100100 },
	{ 0, 5, 0x05, 0, 0x100500, 5, 0x100500 },
	{ 0, 5, 0x06, 0, 0x100900, 9, 0x100900 },
	{ 0, 5, 0x07, 0, 0x100d00, 13, 0x100d00 },
	{ 0, 5, 0x08, 0, 0x200100, 2, 0x200100 },
	{ 0, 5, 0x09, 0, 0x200500, 6, 0x200500 },
	{ 0, 5, 0x0a, 0, 0x200900, 10, 0x200900 },
	{ 0, 5, 0x0b, 0, 0x200d00, 14, 0x200d00 },
	{ 0, 5, 0x0c, 0, 0x300100, 3, 0x300100 },
	{ 0, 5, 0x0d, 0, 0x300500, 7, 0x300500 },
	{ 0, 5, 0x0e, 0, 0x300900, 11, 0x300900 },
	{ 0, 5, 0x0f, 0, 0x300d00, 15, 0x300d00 },
	{ 0, 5, 0x10, 0, 0x400100, 16, 0x400100 },
	{ 0, 5, 0x11, 0, 0x400400, 20, 0x400400 },
	{ 0, 5, 0x12, 0, 0x400a00, 24, 0x400a00 },
	{ 0, 5, 0x13, 0, 0x400f00, 28, 0x400f00 },
	{ 0, 5, 0x14, 0, 0x500100, 17, 0x500100 },
	{ 0, 5, 0x15, 0, 0x500400, 21, 0x500400 },
	{ 0, 5, 0x16, 0, 0x500a00, 25, 0x500a00 },
	{ 0, 5, 0x17, 0, 0x500f00, 29, 0x500f00 },
	{ 0, 5, 0x18, 0, 0x600100, 18, 0x600100 },
	{ 0, 5, 0x19, 0, 0x600400, 22, 0x600400 },
	{ 0, 5, 0x1a, 0, 0x600a00, 26, 0x600a00 },
	{ 0, 5, 0x1b, 0, 0x600f00, 30, 0x600f00 },
	{ 0, 5, 0x1c, 0, 0x700100, 19, 0x700100 },
	{ 0, 5, 0x1d, 0, 0x700400, 23, 0x700400 },
	{ 0, 5, 0x1e, 0, 0x700a00, 27, 0x700a00 },
	{ 0, 5, 0x1f, 0, 0x700f00, 31, 0x700f00 },
	{ 0, 6, 0x00, 0, 0x200, 0, 0x200 },
	{ 0, 6, 0x01, 0, 0x600, 4, 0x600 },
	{ 0, 6, 0x02, 0, 0xa00, 8, 0xa00 },
	{ 0, 6, 0x03, 0, 0xe00, 12, 0xe00 },
	{ 0, 6, 0x04, 0, 0x100200, 1, 0x100200 },
	{ 0, 6, 0x05, 0, 0x100600, 5, 0x100600 },
	{ 0, 6, 0x06, 0, 0x100a00, 9, 0x100a00 },
	{ 0, 6, 0x07, 0, 0x100e00, 13, 0x100e00 },
	{ 0, 6, 0x08, 0, 0x200200, 2, 0x200200 },
	{ 0, 6, 0x09, 0, 0x200600, 6, 0x200600 },
	{ 0, 6, 0x0a, 0, 0x200a00, 10, 0x200a00 },
	{ 0, 6, 0x0b, 0, 0x200e00, 14, 0x200e00 },
	{ 0, 6, 0x0c, 0, 0x300200, 3, 0x300200 },
	{ 0, 6, 0x0d, 0, 0x300600, 7, 0x300600 },
	{ 0, 6, 0x0e, 0, 0x300a00, 11, 0x300a00 },
	{ 0, 6, 0x0f, 0, 0x300e00, 15, 0x300e00 },
	{ 0, 6, 0x10, 0, 0x400200, 16, 0x400200 },
	{ 0, 6, 0x11, 0, 0x400700, 20, 0x400700 },
	{ 0, 6, 0x12, 0, 0x400900, 24, 0x400900 },
	{ 0, 6, 0x13, 0, 0x400c00, 28, 0x400c00 },
	{ 0, 6, 0x14, 0, 0x500200, 17, 0x500200 },
	{ 0, 6, 0x15, 0, 0x500700, 21, 0x500700 },
	{ 0, 6, 0x16, 0, 0x500900, 25, 0x500900 },
	{ 0, 6, 0x17, 0, 0x500c00, 29, 0x500c00 },
	{ 0, 6, 0x18, 0, 0x600200, 18, 0x600200 },
	{ 0, 6, 0x19, 0, 0x600700, 22, 0x600700 },
	{ 0, 6, 0x1a, 0, 0x600900, 26, 0x600900 },
	{ 0, 6, 0x1b, 0, 0x600c00, 30, 0x600c00 },
	{ 0, 6, 0x1c, 0, 0x700200, 19, 0x700200 },
	{ 0, 6, 0x1d, 0, 0x700700, 23, 0x700700 },
	{ 0, 6, 0x1e, 0, 0x700900, 27, 0x700900 },
	{ 0, 6, 0x1f, 0, 0x700c00, 31, 0x700c00 },
	{ 0, 7, 0x00, 0, 0x300, 0, 0x300 },
	{ 0, 7, 0x01, 0, 0x700, 4, 0x700 },
	{ 0, 7, 0x02, 0, 0xb00, 8, 0xb00 },
	{ 0, 7, 0x03, 0, 0xf00, 12, 0xf00 },
	{ 0, 7, 0x04, 0, 0x100300, 1, 0x100300 },
	{ 0, 7, 0x05, 0, 0x100700, 5, 0x100700 },
	{ 0, 7, 0x06, 0, 0x100b00, 9, 0x100b00 },
	{ 0, 7, 0x07, 0, 0x100f00, 13, 0x100f00 },
	{ 0, 7, 0x08, 0, 0x200300, 2, 0x200300 },
	{ 0, 7, 0x09, 0, 0x200700, 6, 0x200700 },
	{ 0, 7, 0x0a, 0, 0x200b00, 10, 0x200b00 },
	{ 0, 7, 0x0b, 0, 0x200f00, 14, 0x200f00 },
	{ 0, 7, 0x0c, 0, 0x300300, 3, 0x300300 },
	{ 0, 7, 0x0d, 0, 0x300700, 7, 0x300700 },
	{ 0, 7, 0x0e, 0, 0x300b00, 11, 0x300b00 },
	{ 0, 7, 0x0f, 0, 0x300f00, 15, 0x300f00 },
	{ 0, 7, 0x10, 0, 0x400300, 16, 0x400300 },
	{ 0, 7, 0x11, 0, 0x400600, 20, 0x400600 },
	{ 0, 7, 0x12, 0, 0x400800, 24, 0x400800 },
	{ 0, 7, 0x13, 0, 0x400d00, 28, 0x400d00 },
	{ 0, 7, 0x14, 0, 0x500300, 17, 0x500300 },
	{ 0, 7, 0x15, 0, 0x500600, 21, 0x500600 },
	{ 0, 7, 0x16, 0, 0x500800, 25, 0x500800 },
	{ 0, 7, 0x17, 0, 0x500d00, 29, 0x500d00 },
	{ 0, 7, 0x18, 0, 0x600300, 18, 0x600300 },
	{ 0, 7, 0x19, 0, 0x600600, 22, 0x600600 },
	{ 0, 7, 0x1a, 0, 0x600800, 26, 0x600800 },
	{ 0, 7, 0x1b, 0, 0x600d00, 30, 0x600d00 },
	{ 0, 7, 0x1c, 0, 0x700300, 19, 0x700300 },
	{ 0, 7, 0x1d, 0, 0x700600, 23, 0x700600 },
	{ 0, 7, 0x1e, 0, 0x700800, 27, 0x700800 },
	{ 0, 7, 0x1f, 0, 0x700d00, 31, 0x700d00 },
	{ 0, 8, 0x00, 0, 0x14020000, 0, 0x20000 },
	{ 0, 9, 0x00, 0, 0x14040000, 0, 0x0 },
	{ 0, 9, 0x01, 0, 0x14040080, 0, 0x80 },
	{ 0, 9, 0x02, 0, 0x14040100, 0, 0x100 },
	{ 0, 9, 0x03, 0, 0x14050000, 0, 0x10000 },
	{ 0, 9, 0x04, 0, 0x0, 0, 0x0 },
	{ 1, 4, 0x00, 0, 0x0, 0, 0x0 },
	{ 1, 4, 0x01, 0, 0x400, 4, 0x400 },
	{ 1, 4, 0x02, 0, 0x800, 8, 0x800 },
	{ 1, 4, 0x03, 0, 0xc00, 12, 0xc00 },
	{ 1, 4, 0x04, 0, 0x100000, 1, 0x100000 },
	{ 1, 4, 0x05, 0, 0x100400, 5, 0x100400 },
	{ 1, 4, 0x06, 0, 0x100800, 9, 0x100800 },
	{ 1, 4, 0x07, 0, 0x100c00, 13, 0x100c00 },
	{ 1, 4, 0x08, 0, 0x200000, 2, 0x200000 },
	{ 1, 4, 0x09, 0, 0x200400, 6, 0x200400 },
	{ 1, 4, 0x0a, 0, 0x200800, 10, 0x200800 },
	{ 1, 4, 0x0b, 0, 0x200c00, 14, 0x200c00 },
	{ 1, 4, 0x0c, 0, 0x300000, 3, 0x300000 },
	{ 1, 4, 0x0d, 0, 0x300400, 7, 0x300400 },
	{ 1, 4, 0x0e, 0, 0x300800, 11, 0x300800 },
	{ 1, 4, 0x0f, 0, 0x300c00, 15, 0x300c00 },
	{ 1, 4, 0x10, 0, 0x400000, 16, 0x400000 },
	{ 1, 4, 0x11, 0, 0x400500, 20, 0x400500 },
	{ 1, 4, 0x12, 0, 0x400b00, 24, 0x400b00 },
	{ 1, 4, 0x13, 0, 0x400e00, 28, 0x400e00 },
	{ 1, 4, 0x14, 0, 0x500000, 17, 0x500000 },
	{ 1, 4, 0x15, 0, 0x500500, 21, 0x500500 },
	{ 1, 4, 0x16, 0, 0x500b00, 25, 0x500b00 },
	{ 1, 4, 0x17, 0, 0x500e00, 29, 0x500e00 },
	{ 1, 4, 0x18, 0, 0x600000, 18, 0x600000 },
	{ 1, 4, 0x19, 0, 0x600500, 22, 0x600500 },
	{ 1, 4, 0x1a, 0, 0x600b00, 26, 0x600b00 },
	{ 1, 4, 0x1b, 0, 0x600e00, 30, 0x600e00 },
	{ 1, 4, 0x1c, 0, 0x700000, 19, 0x700000 },
	{ 1, 4, 0x1d, 0, 0x700500, 23, 0x700500 },
	{ 1, 4, 0x1e, 0, 0x700b00, 27, 0x700b00 },
	{ 1, 4, 0x1f, 0, 0x700e00, 31, 0x700e00 },
	{ 1, 5, 0x00, 0, 0x100, 0, 0x100 },
	{ 1, 5, 0x01, 0, 0x500, 4, 0x500 },
	{ 1, 5, 0x02, 0, 0x900, 8, 0x900 },
	{ 1, 5, 0x03, 0, 0xd00, 12, 0xd00 },
	{ 1, 5, 0x04, 0, 0x100100, 1, 0x100100 },
	{ 1, 5, 0x05, 0, 0x100500, 5, 0x100500 },
	{ 1, 5, 0x06, 0, 0x100900, 9, 0x100900 },
	{ 1, 5, 0x07, 0, 0x100d00, 13, 0x100d00 },
	{ 1, 5, 0x08, 0, 0x200100, 2, 0x200100 },
	{ 1, 5, 0x09, 0, 0x200500, 6, 0x200500 },
	{ 1, 5, 0x0a, 0, 0x200900, 10, 0x200900 },
	{ 1, 5, 0x0b, 0, 0x200d00, 14, 0x200d00 },
	{ 1, 5, 0x0c, 0, 0x300100, 3, 0x300100 },
	{ 1, 5, 0x0d, 0, 0x300500, 7, 0x300500 },
	{ 1, 5, 0x0e, 0, 0x300900, 11, 0x300900 },
	{ 1, 5, 0x0f, 0, 0x300d00, 15, 0x300d00 },
	{ 1, 5, 0x10, 0, 0x400100, 16, 0x400100 },
	{ 1, 5, 0x11, 0, 0x400400, 20, 0x400400 },
	{ 1, 5, 0x12, 0, 0x400a00, 24, 0x400a00 },
	{ 1, 5, 0x13, 0, 0x400f00, 28, 0x400f00 },
	{ 1, 5, 0x14, 0, 0x500100, 17, 0x500100 },
	{ 1, 5, 0x15, 0, 0x500400, 21, 0x500400 },
	{ 1, 5, 0x16, 0, 0x500a00, 25, 0x500a00 },
	{ 1, 5, 0x17, 0, 0x500f00, 29, 0x500f00 },
	{ 1, 5, 0x18, 0, 0x600100, 18, 0x600100 },
	{ 1, 5, 0x19, 0, 0x600400, 22, 0x600400 },
	{ 1, 5, 0x1a, 0, 0x600a00, 26, 0x600a00 },
	{ 1, 5, 0x1b, 0, 0x600f00, 30, 0x600f00 },
	{ 1, 5, 0x1c, 0, 0x700100, 19, 0x700100 },
	{ 1, 5, 0x1d, 0, 0x700400, 23, 0x700400 },
	{ 1, 5, 0x1e, 0, 0x700a00, 27, 0x700a00 },
	{ 1, 5, 0x1f, 0, 0x700f00, 31, 0x700f00 },
	{ 1, 6, 0x00, 0, 0x200, 0, 0x200 },
	{ 1, 6, 0x01, 0, 0x600, 4, 0x600 },
	{ 1, 6, 0x02, 0, 0xa00, 8, 0xa00 },
	{ 1, 6, 0x03, 0, 0xe00, 12, 0xe00 },
	{ 1, 6, 0x04, 0, 0x100200, 1, 0x100200 },
	{ 1, 6, 0x05, 0, 0x100600, 5, 0x100600 },
	{ 1, 6, 0x06, 0, 0x100a00, 9, 0x100a00 },
	{ 1, 6, 0x07, 0, 0x100e00, 13, 0x100e00 },
	{ 1, 6, 0x08, 0, 0x200200, 2, 0x200200 },
	{ 1, 6, 0x09, 0, 0x200600, 6, 0x200600 },
	{ 1, 6, 0x0a, 0, 0x200a00, 10, 0x200a00 },
	{ 1, 6, 0x0b, 0, 0x200e00, 14, 0x200e00 },
	{ 1, 6, 0x0c, 0, 0x300200, 3, 0x300200 },
	{ 1, 6, 0x0d, 0, 0x300600, 7, 0x300600 },
	{ 1, 6, 0x0e, 0, 0x300a00, 11, 0x300a00 },
	{ 1, 6, 0x0f, 0, 0x300e00, 15, 0x300e00 },
	{ 1, 6, 0x10, 0, 0x400200, 16, 0x400200 },
	{ 1, 6, 0x11, 0, 0x400700, 20, 0x400700 },
	{ 1, 6, 0x12, 0, 0x400900, 24, 0x400900 },
	{ 1, 6, 0x13, 0, 0x400c00, 28, 0x400c00 },
	{ 1, 6, 0x14, 0, 0x500200, 17, 0x500200 },
	{ 1, 6, 0x15, 0, 0x500700, 21, 0x500700 },
	{ 1, 6, 0x16, 0, 0x500900, 25, 0x500900 },
	{ 1, 6, 0x17, 0, 0x500c00, 29, 0x500c00 },
	{ 1, 6, 0x18, 0, 0x600200, 18, 0x600200 },
	{ 1, 6, 0x19, 0, 0x600700, 22, 0x600700 },
	{ 1, 6, 0x1a, 0, 0x600900, 26, 0x600900 },
	{ 1, 6, 0x1b, 0, 0x600c00, 30, 0x600c00 },
	{ 1, 6, 0x1c, 0, 0x700200, 19, 0x700200 },
	{ 1, 6, 0x1d, 0, 0x700700, 23, 0x700700 },
	{ 1, 6, 0x1e, 0, 0x700900, 27, 0x700900 },
	{ 1, 6, 0x1f, 0, 0x700c00, 31, 0x700c00 },
	{ 1, 7, 0x00, 0, 0x300, 0, 0x300 },
	{ 1, 7, 0x01, 0, 0x700, 4, 0x700 },
	{ 1, 7, 0x02, 0, 0xb00, 8, 0xb00 },
	{ 1, 7, 0x03, 0, 0xf00, 12, 0xf00 },
	{ 1, 7, 0x04, 0, 0x100300, 1, 0x100300 },
	{ 1, 7, 0x05, 0, 0x100700, 5, 0x100700 },
	{ 1, 7, 0x06, 0, 0x100b00, 9, 0x100b00 },
	{ 1, 7, 0x07, 0, 0x100f00, 13, 0x100f00 },
	{ 1, 7, 0x08, 0, 0x200300, 2, 0x200300 },
	{ 1, 7, 0x09, 0, 0x200700, 6, 0x200700 },
	{ 1, 7, 0x0a, 0, 0x200b00, 10, 0x200b00 },
	{ 1, 7, 0x0b, 0, 0x200f00, 14, 0x200f00 },
	{ 1, 7, 0x0c, 0, 0x300300, 3, 0x300300 },
	{ 1, 7, 0x0d, 0, 0x300700, 7, 0x300700 },
	{ 1, 7, 0x0e, 0, 0x300b00, 11, 0x300b00 },
	{ 1, 7, 0x0f, 0, 0x300f00, 15, 0x300f00 },
	{ 1, 7, 0x10, 0, 0x400300, 16, 0x400300 },
	{ 1, 7, 0x11, 0, 0x400600, 20, 0x400600 },
	{ 1, 7, 0x12, 0, 0x400800, 24, 0x400800 },
	{ 1, 7, 0x13, 0, 0x400d00, 28, 0x400d00 },
	{ 1, 7, 0x14, 0, 0x500300, 17, 0x500300 },
	{ 1, 7, 0x15, 0, 0x500600, 21, 0x500600 },
	{ 1, 7, 0x16, 0, 0x500800, 25, 0x500800 },
	{ 1, 7, 0x17, 0, 0x500d00, 29, 0x500d00 },
	{ 1, 7, 0x18, 0, 0x600300, 18, 0x600300 },
	{ 1, 7, 0x19, 0, 0x600600, 22, 0x600600 },
	{ 1, 7, 0x1a, 0, 0x600800, 26, 0x600800 },
	{ 1, 7, 0x1b, 0, 0x600d00, 30, 0x600d00 },
	{ 1, 7, 0x1c, 0, 0x700300, 19, 0x700300 },
	{ 1, 7, 0x1d, 0, 0x700600, 23, 0x700600 },
	{ 1, 7, 0x1e, 0, 0x700800, 27, 0x700800 },
	{ 1, 7, 0x1f, 0, 0x700d00, 31, 0x700d00 },
	{ 2, 4, 0x00, 0, 0x0, 0, 0x0 },
	{ 2, 4, 0x01, 0, 0x400, 4, 0x400 },
	{ 2, 4, 0x02, 0, 0x800, 8, 0x800 },
	{ 2, 4, 0x03, 0, 0xc00, 12, 0xc00 },
	{ 2, 4, 0x04, 0, 0x100000, 1, 0x100000 },
	{ 2, 4, 0x05, 0, 0x100400, 5, 0x100400 },
	{ 2, 4, 0x06, 0, 0x100800, 9, 0x100800 },
	{ 2, 4, 0x07, 0, 0x100c00, 13, 0x100c00 },
	{ 2, 4, 0x08, 0, 0x200000, 2, 0x200000 },
	{ 2, 4, 0x09, 0, 0x200400, 6, 0x200400 },
	{ 2, 4, 0x0a, 0, 0x200800, 10, 0x200800 },
	{ 2, 4, 0x0b, 0, 0x200c00, 14, 0x200c00 },
	{ 2, 4, 0x0c, 0, 0x300000, 3, 0x300000 },
	{ 2, 4, 0x0d, 0, 0x300400, 7, 0x300400 },
	{ 2, 4, 0x0e, 0, 0x300800, 11, 0x300800 },
	{ 2, 4, 0x0f, 0, 0x300c00, 15, 0x300c00 },
	{ 2, 4, 0x10, 0, 0x400000, 16, 0x400000 },
	{ 2, 4, 0x11, 0, 0x400500, 20, 0x400500 },
	{ 2, 4, 0x12, 0, 0x400b00, 24, 0x400b00 },
	{ 2, 4, 0x13, 0, 0x400e00, 28, 0x400e00 },
	{ 2, 4, 0x14, 0, 0x500000, 17, 0x500000 },
	{ 2, 4, 0x15, 0, 0x500500, 21, 0x500500 },
	{ 2, 4, 0x16, 0, 0x500b00, 25, 0x500b00 },
	{ 2, 4, 0x17, 0, 0x500e00, 29, 0x500e00 },
	{ 2, 4, 0x18, 0, 0x600000, 18, 0x600000 },
	{ 2, 4, 0x19, 0, 0x600500, 22, 0x600500 },
	{ 2, 4, 0x1a, 0, 0x600b00, 26, 0x600b00 },
	{ 2, 4, 0x1b, 0, 0x600e00, 30, 0x600e00 },
	{ 2, 4, 0x1c, 0, 0x700000, 19, 0x700000 },
	{ 2, 4, 0x1d, 0, 0x700500, 23, 0x700500 },
	{ 2, 4, 0x1e, 0, 0x700b00, 27, 0x700b00 },
	{ 2, 4, 0x1f, 0, 0x700e00, 31, 0x700e00 },
	{ 2, 5, 0x00, 0, 0x100, 0, 0x100 },
	{ 2, 5, 0x01, 0, 0x500, 4, 0x500 },
	{ 2, 5, 0x02, 0, 0x900, 8, 0x900 },
	{ 2, 5, 0x03, 0, 0xd00, 12, 0xd00 },
	{ 2, 5, 0x04, 0, 0x100100, 1, 0x100100 },
	{ 2, 5, 0x05, 0, 0x100500, 5, 0x100500 },
	{ 2, 5, 0x06, 0, 0x100900, 9, 0x100900 },
	{ 2, 5, 0x07, 0, 0x100d00, 13, 0x100d00 },
	{ 2, 5, 0x08, 0, 0x200100, 2, 0x200100 },
	{ 2, 5, 0x09, 0, 0x200500, 6, 0x200500 },
	{ 2, 5, 0x0a, 0, 0x200900, 10, 0x200900 },
	{ 2, 5, 0x0b, 0, 0x200d00, 14, 0x200d00 },
	{ 2, 5, 0x0c, 0, 0x300100, 3, 0x300100 },
	{ 2, 5, 0x0d, 0, 0x300500, 7, 0x300500 },
	{ 2, 5, 0x0e, 0, 0x300900, 11, 0x300900 },
	{ 2, 5, 0x0f, 0, 0x300d00, 15, 0x300d00 },
	{ 2, 5, 0x10, 0, 0x400100, 16, 0x400100 },
	{ 2, 5, 0x11, 0, 0x400400, 20, 0x400400 },
	{ 2, 5, 0x12, 0, 0x400a00, 24, 0x400a00 },
	{ 2, 5, 0x13, 0, 0x400f00, 28, 0x400f00 },
	{ 2, 5, 0x14, 0, 0x500100, 17, 0x500100 },
	{ 2, 5, 0x15, 0, 0x500400, 21, 0x500400 },
	{ 2, 5, 0x16, 0, 0x500a00, 25, 0x500a00 },
	{ 2, 5, 0x17, 0, 0x500f00, 29, 0x500f00 },
	{ 2, 5, 0x18, 0, 0x600100, 18, 0x600100 },
	{ 2, 5, 0x19, 0, 0x600400, 22, 0x600400 },
	{ 2, 5, 0x1a, 0, 0x600a00, 26, 0x600a00 },
	{ 2, 5, 0x1b, 0, 0x600f00, 30, 0x600f00 },
	{ 2, 5, 0x1c, 0, 0x700100, 19, 0x700100 },
	{ 2, 5, 0x1d, 0, 0x700400, 23, 0x700400 },
	{ 2, 5, 0x1e, 0, 0x700a00, 27, 0x700a00 },
	{ 2, 5, 0x1f, 0, 0x700f00, 31, 0x700f00 },
	{ 2, 6, 0x00, 0, 0x200, 0, 0x200 },
	{ 2, 6, 0x01, 0, 0x600, 4, 0x600 },
	{ 2, 6, 0x02, 0, 0xa00, 8, 0xa00 },
	{ 2, 6, 0x03, 0, 0xe00, 12, 0xe00 },
	{ 2, 6, 0x04, 0, 0x100200, 1, 0x100200 },
	{ 2, 6, 0x05, 0, 0x100600, 5, 0x100600 },
	{ 2, 6, 0x06, 0, 0x100a00, 9, 0x100a00 },
	{ 2, 6, 0x07, 0, 0x100e00, 13, 0x100e00 },
	{ 2, 6, 0x08, 0, 0x200200, 2, 0x200200 },
	{ 2, 6, 0x09, 0, 0x200600, 6, 0x200600 },
	{ 2, 6, 0x0a, 0, 0x200a00, 10, 0x200a00 },
	{ 2, 6, 0x0b, 0, 0x200e00, 14, 0x200e00 },
	{ 2, 6, 0x0c, 0, 0x300200, 3, 0x300200 },
	{ 2, 6, 0x0d, 0, 0x300600, 7, 0x300600 },
	{ 2, 6, 0x0e, 0, 0x300a00, 11, 0x300a00 },
	{ 2, 6, 0x0f, 0, 0x300e00, 15, 0x300e00 },
	{ 2, 6, 0x10, 0, 0x400200, 16, 0x400200 },
	{ 2, 6, 0x11, 0, 0x400700, 20, 0x400700 },
	{ 2, 6, 0x12, 0, 0x400900, 24, 0x400900 },
	{ 2, 6, 0x13, 0, 0x400c00, 28, 0x400c00 },
	{ 2, 6, 0x14, 0, 0x500200, 17, 0x500200 },
	{ 2, 6, 0x15, 0, 0x500700, 21, 0x500700 },
	{ 2, 6, 0x16, 0, 0x500900, 25, 0x500900 },
	{ 2, 6, 0x17, 0, 0x500c00, 29, 0x500c00 },
	{ 2, 6, 0x18, 0, 0x600200, 18, 0x600200 },
	{ 2, 6, 0x19, 0, 0x600700, 22, 0x600700 },
	{ 2, 6, 0x1a, 0, 0x600900, 26, 0x600900 },
	{ 2, 6, 0x1b, 0, 0x600c00, 30, 0x600c00 },
	{ 2, 6, 0x1c, 0, 0x700200, 19, 0x700200 },
	{ 2, 6, 0x1d, 0, 0x700700, 23, 0x700700 },
	{ 2, 6, 0x1e, 0, 0x700900, 27, 0x700900 },
	{ 2, 6, 0x1f, 0, 0x700c00, 31, 0x700c00 },
	{ 2, 7, 0x00, 0, 0x300, 0, 0x300 },
	{ 2, 7, 0x01, 0, 0x700, 4, 0x700 },
	{ 2, 7, 0x02, 0, 0xb00, 8, 0xb00 },
	{ 2, 7, 0x03, 0, 0xf00, 12, 0xf00 },
	{ 2, 7, 0x04, 0, 0x100300, 1, 0x100300 },
	{ 2, 7, 0x05, 0, 0x100700, 5, 0x100700 },
	{ 2, 7, 0x06, 0, 0x100b00, 9, 0x100b00 },
	{ 2, 7, 0x07, 0, 0x100f00, 13, 0x100f00 },
	{ 2, 7, 0x08, 0, 0x200300, 2, 0x200300 },
	{ 2, 7, 0x09, 0, 0x200700, 6, 0x200700 },
	{ 2, 7, 0x0a, 0, 0x200b00, 10, 0x200b00 },
	{ 2, 7, 0x0b, 0, 0x200f00, 14, 0x200f00 },
	{ 2, 7, 0x0c, 0, 0x300300, 3, 0x300300 },
	{ 2, 7, 0x0d, 0, 0x300700, 7, 0x300700 },
	{ 2, 7, 0x0e, 0, 0x300b00, 11, 0x300b00 },
	{ 2, 7, 0x0f, 0, 0x300f00, 15, 0x300f00 },
	{ 2, 7, 0x10, 0, 0x400300, 16, 0x400300 },
	{ 2, 7, 0x11, 0, 0x400600, 20, 0x400600 },
	{ 2, 7, 0x12, 0, 0x400800, 24, 0x400800 },
	{ 2, 7, 0x13, 0, 0x400d00, 28, 0x400d00 },
	{ 2, 7, 0x14, 0, 0x500300, 17, 0x500300 },
	{ 2, 7, 0x15, 0, 0x500600, 21, 0x500600 },
	{ 2, 7, 0x16, 0, 0x500800, 25, 0x500800 },
	{ 2, 7, 0x17, 0, 0x500d00, 29, 0x500d00 },
	{ 2, 7, 0x18, 0, 0x600300, 18, 0x600300 },
	{ 2, 7, 0x19, 0, 0x600600, 22, 0x600600 },
	{ 2, 7, 0x1a, 0, 0x600800, 26, 0x600800 },
	{ 2, 7, 0x1b, 0, 0x600d00, 30, 0x600d00 },
	{ 2, 7, 0x1c, 0, 0x700300, 19, 0x700300 },
	{ 2, 7, 0x1d, 0, 0x700600, 23, 0x700600 },
	{ 2, 7, 0x1e, 0, 0x700800, 27, 0x700800 },
	{ 2, 7, 0x1f, 0, 0x700d00, 31, 0x700d00 },
	{ 3, 4, 0x00, 0, 0x0, 0, 0x0 },
	{ 3, 4, 0x01, 0, 0x400, 4, 0x400 },
	{ 3, 4, 0x02, 0, 0x800, 8, 0x800 },
	{ 3, 4, 0x03, 0, 0xc00, 12, 0xc00 },
	{ 3, 4, 0x04, 0, 0x100000, 1, 0x100000 },
	{ 3, 4, 0x05, 0, 0x100400, 5, 0x100400 },
	{ 3, 4, 0x06, 0, 0x100800, 9, 0x100800 },
	{ 3, 4, 0x07, 0, 0x100c00, 13, 0x100c00 },
	{ 3, 4, 0x08, 0, 0x200000, 2, 0x200000 },
	{ 3, 4, 0x09, 0, 0x200400, 6, 0x200400 },
	{ 3, 4, 0x0a, 0, 0x200800, 10, 0x200800 },
	{ 3, 4, 0x0b, 0, 0x200c00, 14, 0x200c00 },
	{ 3, 4, 0x0c, 0, 0x300000, 3, 0x300000 },
	{ 3, 4, 0x0d, 0, 0x300400, 7, 0x300400 },
	{ 3, 4, 0x0e, 0, 0x300800, 11, 0x300800 },
	{ 3, 4, 0x0f, 0, 0x300c00, 15, 0x300c00 },
	{ 3, 4, 0x10, 0, 0x400000, 16, 0x400000 },
	{ 3, 4, 0x11, 0, 0x400500, 20, 0x400500 },
	{ 3, 4, 0x12, 0, 0x400b00, 24, 0x400b00 },
	{ 3, 4, 0x13, 0, 0x400e00, 28, 0x400e00 },
	{ 3, 4, 0x14, 0, 0x500000, 17, 0x500000 },
	{ 3, 4, 0x15, 0, 0x500500, 21, 0x500500 },
	{ 3, 4, 0x16, 0, 0x500b00, 25, 0x500b00 },
	{ 3, 4, 0x17, 0, 0x500e00, 29, 0x500e00 },
	{ 3, 4, 0x18, 0, 0x600000, 18, 0x600000 },
	{ 3, 4, 0x19, 0, 0x600500, 22, 0x600500 },
	{ 3, 4, 0x1a, 0, 0x600b00, 26, 0x600b00 },
	{ 3, 4, 0x1b, 0, 0x600e00, 30, 0x600e00 },
	{ 3, 4, 0x1c, 0, 0x700000, 19, 0x700000 },
	{ 3, 4, 0x1d, 0, 0x700500, 23, 0x700500 },
	{ 3, 4, 0x1e, 0, 0x700b00, 27, 0x700b00 },
	{ 3, 4, 0x1f, 0, 0x700e00, 31, 0x700e00 },
	{ 3, 5, 0x00, 0, 0x100, 0, 0x100 },
	{ 3, 5, 0x01, 0, 0x500, 4, 0x500 },
	{ 3, 5, 0x02, 0, 0x900, 8, 0x900 },
	{ 3, 5, 0x03, 0, 0xd00, 12, 0xd00 },
	{ 3, 5, 0x04, 0, 0x100100, 1, 0x100100 },
	{ 3, 5, 0x05, 0, 0x100500, 5, 0x100500 },
	{ 3, 5, 0x06, 0, 0x100900, 9, 0x100900 },
	{ 3, 5, 0x07, 0, 0x100d00, 13, 0x100d00 },
	{ 3, 5, 0x08, 0, 0x200100, 2, 0x200100 },
	{ 3, 5, 0x09, 0, 0x200500, 6, 0x200500 },
	{ 3, 5, 0x0a, 0, 0x200900, 10, 0x200900 },
	{ 3, 5, 0x0b, 0, 0x200d00, 14, 0x200d00 },
	{ 3, 5, 0x0c, 0, 0x300100, 3, 0x300100 },
	{ 3, 5, 0x0d, 0, 0x300500, 7, 0x300500 },
	{ 3, 5, 0x0e, 0, 0x300900, 11, 0x300900 },
	{ 3, 5, 0x0f, 0, 0x300d00, 15, 0x300d00 },
	{ 3, 5, 0x10, 0, 0x400100, 16, 0x400100 },
	{ 3, 5, 0x11, 0, 0x400400, 20, 0x400400 },
	{ 3, 5, 0x12, 0, 0x400a00, 24, 0x400a00 },
	{ 3, 5, 0x13, 0, 0x400f00, 28, 0x400f00 },
	{ 3, 5, 0x14, 0, 0x500100, 17, 0x500100 },
	{ 3, 5, 0x15, 0, 0x500400, 21, 0x500400 },
	{ 3, 5, 0x16, 0, 0x500a00, 25, 0x500a00 },
	{ 3, 5, 0x17, 0, 0x500f00, 29, 0x500f00 },
	{ 3, 5, 0x18, 0, 0x600100, 18, 0x600100 },
	{ 3, 5, 0x19, 0, 0x600400, 22, 0x600400 },
	{ 3, 5, 0x1a, 0, 0x600a00, 26, 0x600a00 },
	{ 3, 5, 0x1b, 0, 0x600f00, 30, 0x600f00 },
	{ 3, 5, 0x1c, 0, 0x700100, 19, 0x700100 },
	{ 3, 5, 0x1d, 0, 0x700400, 23, 0x700400 },
	{ 3, 5, 0x1e, 0, 0x700a00, 27, 0x700a00 },
	{ 3, 5, 0x1f, 0, 0x700f00, 31, 0x700f00 },
	{ 3, 6, 0x00, 0, 0x200, 0, 0x200 },
	{ 3, 6, 0x01, 0, 0x600, 4, 0x600 },
	{ 3, 6, 0x02, 0, 0xa00, 8, 0xa00 },
	{ 3, 6, 0x03, 0, 0xe00, 12, 0xe00 },
	{ 3, 6, 0x04, 0, 0x100200, 1, 0x100200 },
	{ 3, 6, 0x05, 0, 0x100600, 5, 0x100600 },
	{ 3, 6, 0x06, 0, 0x100a00, 9, 0x100a00 },
	{ 3, 6, 0x07, 0, 0x100e00, 13, 0x100e00 },
	{ 3, 6, 0x08, 0, 0x200200, 2, 0x200200 },
	{ 3, 6, 0x09, 0, 0x200600, 6, 0x200600 },
	{ 3, 6, 0x0a, 0, 0x200a00, 10, 0x200a00 },
	{ 3, 6, 0x0b, 0, 0x200e00, 14, 0x200e00 },
	{ 3, 6, 0x0c, 0, 0x300200, 3, 0x300200 },
	{ 3, 6, 0x0d, 0, 0x300600, 7, 0x300600 },
	{ 3, 6, 0x0e, 0, 0x300a00, 11, 0x300a00 },
	{ 3, 6, 0x0f, 0, 0x300e00, 15, 0x300e00 },
	{ 3, 6, 0x10, 0, 0x400200, 16, 0x400200 },
	{ 3, 6, 0x11, 0, 0x400700, 20, 0x400700 },
	{ 3, 6, 0x12, 0, 0x400900, 24, 0x400900 },
	{ 3, 6, 0x13, 0, 0x400c00, 28, 0x400c00 },
	{ 3, 6, 0x14, 0, 0x500200, 17, 0x500200 },
	{ 3, 6, 0x15, 0, 0x500700, 21, 0x500700 },
	{ 3, 6, 0x16, 0, 0x500900, 25, 0x500900 },
	{ 3, 6, 0x17, 0, 0x500c00, 29, 0x500c00 },
	{ 3, 6, 0x18, 0, 0x600200, 18, 0x600200 },
	{ 3, 6, 0x19, 0, 0x600700, 22, 0x600700 },
	{ 3, 6, 0x1a, 0, 0x600900, 26, 0x600900 },
	{ 3, 6, 0x1b, 0, 0x600c00, 30, 0x600c00 },
	{ 3, 6, 0x1c, 0, 0x700200, 19, 0x700200 },
	{ 3, 6, 0x1d, 0, 0x700700, 23, 0x700700 },
	{ 3, 6, 0x1e, 0, 0x700900, 27, 0x700900 },
	{ 3, 6, 0x1f, 0, 0x700c00, 31, 0x700c00 },
	{ 3, 7, 0x00, 0, 0x300, 0, 0x300 },
	{ 3, 7, 0x01, 0, 0x700, 4, 0x700 },
	{ 3, 7, 0x02, 0, 0xb00, 8, 0xb00 },
	{ 3, 7, 0x03, 0, 0xf00, 12, 0xf00 },
	{ 3, 7, 0x04, 0, 0x100300, 1, 0x100300 },
	{ 3, 7, 0x05, 0, 0x100700, 5, 0x100700 },
	{ 3, 7, 0x06, 0, 0x100b00, 9, 0x100b00 },
	{ 3, 7, 0x07, 0, 0x100f00, 13, 0x100f00 },
	{ 3, 7, 0x08, 0, 0x200300, 2, 0x200300 },
	{ 3, 7, 0x09, 0, 0x200700, 6, 0x200700 },
	{ 3, 7, 0x0a, 0, 0x200b00, 10, 0x200b00 },
	{ 3, 7, 0x0b, 0, 0x200f00, 14, 0x200f00 },
	{ 3, 7, 0x0c, 0, 0x300300, 3, 0x300300 },
	{ 3, 7, 0x0d, 0, 0x300700, 7, 0x300700 },
	{ 3, 7, 0x0e, 0, 0x300b00, 11, 0x300b00 },
	{ 3, 7, 0x0f, 0, 0x300f00, 15, 0x300f00 },
	{ 3, 7, 0x10, 0, 0x400300, 16, 0x400300 },
	{ 3, 7, 0x11, 0, 0x400600, 20, 0x400600 },
	{ 3, 7, 0x12, 0, 0x400800, 24, 0x400800 },
	{ 3, 7, 0x13, 0, 0x400d00, 28, 0x400d00 },
	{ 3, 7, 0x14, 0, 0x500300, 17, 0x500300 },
	{ 3, 7, 0x15, 0, 0x500600, 21, 0x500600 },
	{ 3, 7, 0x16, 0, 0x500800, 25, 0x500800 },
	{ 3, 7, 0x17, 0, 0x500d00, 29, 0x500d00 },
	{ 3, 7, 0x18, 0, 0x600300, 18, 0x600300 },
	{ 3, 7, 0x19, 0, 0x600600, 22, 0x600600 },
	{ 3, 7, 0x1a, 0, 0x600800, 26, 0x600800 },
	{ 3, 7, 0x1b, 0, 0x600d00, 30, 0x600d00 },
	{ 3, 7, 0x1c, 0, 0x700300, 19, 0x700300 },
	{ 3, 7, 0x1d, 0, 0x700600, 23, 0x700600 },
	{ 3, 7, 0x1e, 0, 0x700800, 27, 0x700800 },
	{ 3, 7, 0x1f, 0, 0x700d00, 31, 0x700d00 },
	{ 4, 4, 0x00, 0, 0x0, 0, 0x0 },
	{ 4, 4, 0x01, 0, 0x400, 4, 0x400 },
	{ 4, 4, 0x02, 0, 0x800, 8, 0x800 },
	{ 4, 4, 0x03, 0, 0xc00, 12, 0xc00 },
	{ 4, 4, 0x04, 0, 0x100000, 1, 0x100000 },
	{ 4, 4, 0x05, 0, 0x100400, 5, 0x100400 },
	{ 4, 4, 0x06, 0, 0x100800, 9, 0x100800 },
	{ 4, 4, 0x07, 0, 0x100c00, 13, 0x100c00 },
	{ 4, 4, 0x08, 0, 0x200000, 2, 0x200000 },
	{ 4, 4, 0x09, 0, 0x200400, 6, 0x200400 },
	{ 4, 4, 0x0a, 0, 0x200800, 10, 0x200800 },
	{ 4, 4, 0x0b, 0, 0x200c00, 14, 0x200c00 },
	{ 4, 4, 0x0c, 0, 0x300000, 3, 0x300000 },
	{ 4, 4, 0x0d, 0, 0x300400, 7, 0x300400 },
	{ 4, 4, 0x0e, 0, 0x300800, 11, 0x300800 },
	{ 4, 4, 0x0f, 0, 0x300c00, 15, 0x300c00 },
	{ 4, 4, 0x10, 0, 0x400000, 16, 0x400000 },
	{ 4, 4, 0x11, 0, 0x400500, 20, 0x400500 },
	{ 4, 4, 0x12, 0, 0x400b00, 24, 0x400b00 },
	{ 4, 4, 0x13, 0, 0x400e00, 28, 0x400e00 },
	{ 4, 4, 0x14, 0, 0x500000, 17, 0x500000 },
	{ 4, 4, 0x15, 0, 0x500500, 21, 0x500500 },
	{ 4, 4, 0x16, 0, 0x500b00, 25, 0x500b00 },
	{ 4, 4, 0x17, 0, 0x500e00, 29, 0x500e00 },
	{ 4, 4, 0x18, 0, 0x600000, 18, 0x600000 },
	{ 4, 4, 0x19, 0, 0x600500, 22, 0x600500 },
	{ 4, 4, 0x1a, 0, 0x600b00, 26, 0x600b00 },
	{ 4, 4, 0x1b, 0, 0x600e00, 30, 0x600e00 },
	{ 4, 4, 0x1c, 0, 0x700000, 19, 0x700000 },
	{ 4, 4, 0x1d, 0, 0x700500, 23, 0x700500 },
	{ 4, 4, 0x1e, 0, 0x700b00, 27, 0x700b00 },
	{ 4, 4, 0x1f, 0, 0x700e00, 31, 0x700e00 },
	{ 4, 5, 0x00, 0, 0x100, 0, 0x100 },
	{ 4, 5, 0x01, 0, 0x500, 4, 0x500 },
	{ 4, 5, 0x02, 0, 0x900, 8, 0x900 },
	{ 4, 5, 0x03, 0, 0xd00, 12, 0xd00 },
	{ 4, 5, 0x04, 0, 0x100100, 1, 0x100100 },
	{ 4, 5, 0x05, 0, 0x100500, 5, 0x100500 },
	{ 4, 5, 0x06, 0, 0x100900, 9, 0x100900 },
	{ 4, 5, 0x07, 0, 0x100d00, 13, 0x100d00 },
	{ 4, 5, 0x08, 0, 0x200100, 2, 0x200100 },
	{ 4, 5, 0x09, 0, 0x200500, 6, 0x200500 },
	{ 4, 5, 0x0a, 0, 0x200900, 10, 0x200900 },
	{ 4, 5, 0x0b, 0, 0x200d00, 14, 0x200d00 },
	{ 4, 5, 0x0c, 0, 0x300100, 3, 0x300100 },
	{ 4, 5, 0x0d, 0, 0x300500, 7, 0x300500 },
	{ 4, 5, 0x0e, 0, 0x300900, 11, 0x300900 },
	{ 4, 5, 0x0f, 0, 0x300d00, 15, 0x300d00 },
	{ 4, 5, 0x10, 0, 0x400100, 16, 0x400100 },
	{ 4, 5, 0x11, 0, 0x400400, 20, 0x400400 },
	{ 4, 5, 0x12, 0, 0x400a00, 24, 0x400a00 },
	{ 4, 5, 0x13, 0, 0x400f00, 28, 0x400f00 },
	{ 4, 5, 0x14, 0, 0x500100, 17, 0x500100 },
	{ 4, 5, 0x15, 0, 0x500400, 21, 0x500400 },
	{ 4, 5, 0x16, 0, 0x500a00, 25, 0x500a00 },
	{ 4, 5, 0x17, 0, 0x500f00, 29, 0x500f00 },
	{ 4, 5, 0x18, 0, 0x600100, 18, 0x600100 },
	{ 4, 5, 0x19, 0, 0x600400, 22, 0x600400 },
	{ 4, 5, 0x1a, 0, 0x600a00, 26, 0x600a00 },
	{ 4, 5, 0x1b, 0, 0x600f00, 30, 0x600f00 },
	{ 4, 5, 0x1c, 0, 0x700100, 19, 0x700100 },
	{ 4, 5, 0x1d, 0, 0x700400, 23, 0x700400 },
	{ 4, 5, 0x1e, 0, 0x700a00, 27, 0x700a00 },
	{ 4, 5, 0x1f, 0, 0x700f00, 31, 0x700f00 },
	{ 4, 6, 0x00, 0, 0x200, 0, 0x200 },
	{ 4, 6, 0x01, 0, 0x600, 4, 0x600 },
	{ 4, 6, 0x02, 0, 0xa00, 8, 0xa00 },
	{ 4, 6, 0x03, 0, 0xe00, 12, 0xe00 },
	{ 4, 6, 0x04, 0, 0x100200, 1, 0x100200 },
	{ 4, 6, 0x05, 0, 0x100600, 5, 0x100600 },
	{ 4, 6, 0x06, 0, 0x100a00, 9, 0x100a00 },
	{ 4, 6, 0x07, 0, 0x100e00, 13, 0x100e00 },
	{ 4, 6, 0x08, 0, 0x200200, 2, 0x200200 },
	{ 4, 6, 0x09, 0, 0x200600, 6, 0x200600 },
	{ 4, 6, 0x0a, 0, 0x200a00, 10, 0x200a00 },
	{ 4, 6, 0x0b, 0, 0x200e00, 14, 0x200e00 },
	{ 4, 6, 0x0c, 0, 0x300200, 3, 0x300200 },
	{ 4, 6, 0x0d, 0, 0x300600, 7, 0x300600 },
	{ 4, 6, 0x0e, 0, 0x300a00, 11, 0x300a00 },
	{ 4, 6, 0x0f, 0, 0x300e00, 15, 0x300e00 },
	{ 4, 6, 0x10, 0, 0x400200, 16, 0x400200 },
	{ 4, 6, 0x11, 0, 0x400700, 20, 0x400700 },
	{ 4, 6, 0x12, 0, 0x400900, 24, 0x400900 },
	{ 4, 6, 0x13, 0, 0x400c00, 28, 0x400c00 },
	{ 4, 6, 0x14, 0, 0x500200, 17, 0x500200 },
	{ 4, 6, 0x15, 0, 0x500700, 21, 0x500700 },
	{ 4, 6, 0x16, 0, 0x500900, 25, 0x500900 },
	{ 4, 6, 0x17, 0, 0x500c00, 29, 0x500c00 },
	{ 4, 6, 0x18, 0, 0x600200, 18, 0x600200 },
	{ 4, 6, 0x19, 0, 0x600700, 22, 0x600700 },
	{ 4, 6, 0x1a, 0, 0x600900, 26, 0x600900 },
	{ 4, 6, 0x1b, 0, 0x600c00, 30, 0x600c00 },
	{ 4, 6, 0x1c, 0, 0x700200, 19, 0x700200 },
	{ 4, 6, 0x1d, 0, 0x700700, 23, 0x700700 },
	{ 4, 6, 0x1e, 0, 0x700900, 27, 0x700900 },
	{ 4, 6, 0x1f, 0, 0x700c00, 31, 0x700c00 },
	{ 4, 7, 0x00, 0, 0x300, 0, 0x300 },
	{ 4, 7, 0x01, 0, 0x700, 4, 0x700 },
	{ 4, 7, 0x02, 0, 0xb00, 8, 0xb00 },
	{ 4, 7, 0x03, 0, 0xf00, 12, 0xf00 },
	{ 4, 7, 0x04, 0, 0x100300, 1, 0x100300 },
	{ 4, 7, 0x05, 0, 0x100700, 5, 0x100700 },
	{ 4, 7, 0x06, 0, 0x100b00, 9, 0x100b00 },
	{ 4, 7, 0x07, 0, 0x100f00, 13, 0x100f00 },
	{ 4, 7, 0x08, 0, 0x200300, 2, 0x200300 },
	{ 4, 7, 0x09, 0, 0x200700, 6, 0x200700 },
	{ 4, 7, 0x0a, 0, 0x200b00, 10, 0x200b00 },
	{ 4, 7, 0x0b, 0, 0x200f00, 14, 0x200f00 },
	{ 4, 7, 0x0c, 0, 0x300300, 3, 0x300300 },
	{ 4, 7, 0x0d, 0, 0x300700, 7, 0x300700 },
	{ 4, 7, 0x0e, 0, 0x300b00, 11, 0x300b00 },
	{ 4, 7, 0x0f, 0, 0x300f00, 15, 0x300f00 },
	{ 4, 7, 0x10, 0, 0x400300, 16, 0x400300 },
	{ 4, 7, 0x11, 0, 0x400600, 20, 0x400600 },
	{ 4, 7, 0x12, 0, 0x400800, 24, 0x400800 },
	{ 4, 7, 0x13, 0, 0x400d00, 28, 0x400d00 },
	{ 4, 7, 0x14, 0, 0x500300, 17, 0x500300 },
	{ 4, 7, 0x15, 0, 0x500600, 21, 0x500600 },
	{ 4, 7, 0x16, 0, 0x500800, 25, 0x500800 },
	{ 4, 7, 0x17, 0, 0x500d00, 29, 0x500d00 },
	{ 4, 7, 0x18, 0, 0x600300, 18, 0x600300 },
	{ 4, 7, 0x19, 0, 0x600600, 22, 0x600600 },
	{ 4, 7, 0x1a, 0, 0x600800, 26, 0x600800 },
	{ 4, 7, 0x1b, 0, 0x600d00, 30, 0x600d00 },
	{ 4, 7, 0x1c, 0, 0x700300, 19, 0x700300 },
	{ 4, 7, 0x1d, 0, 0x700600, 23, 0x700600 },
	{ 4, 7, 0x1e, 0, 0x700800, 27, 0x700800 },
	{ 4, 7, 0x1f, 0, 0x700d00, 31, 0x700d00 }
};

